@@ -4,17 +4,22 @@
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
 #include "nsXULAppAPI.h"
-#include "mozilla/CmdLineAndEnvUtils.h"
 #include "mozilla/XREAppData.h"
+#include "XREChildData.h"
 #include "XREShellData.h"
 #include "application.ini.h"
 #include "mozilla/Bootstrap.h"
+#include "mozilla/ProcessType.h"
+#include "mozilla/RuntimeExceptionModule.h"
+#include "mozilla/ScopeExit.h"
+#include "BrowserDefines.h"
 #if defined(XP_WIN)
 #  include <windows.h>
 #  include <stdlib.h>
 #elif defined(XP_UNIX)
 #  include <sys/resource.h>
 #  include <unistd.h>
+#  include <fcntl.h>
 #endif
 
 #include <stdio.h>
@@ -28,14 +33,18 @@
 #  include "freestanding/SharedSection.h"
 #  include "LauncherProcessWin.h"
 #  include "mozilla/GeckoArgs.h"
+#  include "mozilla/mscom/ProcessRuntime.h"
 #  include "mozilla/WindowsDllBlocklist.h"
 #  include "mozilla/WindowsDpiInitialization.h"
 #  include "mozilla/WindowsProcessMitigations.h"
 
 #  define XRE_WANT_ENVIRON
+#  include "nsWindowsWMain.cpp"
+
 #  define strcasecmp _stricmp
 #  ifdef MOZ_SANDBOX
 #    include "mozilla/sandboxing/SandboxInitialization.h"
+#    include "mozilla/sandboxing/sandboxLogging.h"
 #  endif
 #endif
 #include "BinaryPath.h"
@@ -83,8 +92,7 @@ __attribute__((constructor)) static void SSE2Check() {
   // Using write() in order to avoid jemalloc-based buffering. Ignoring return
   // values, since there isn't much we could do on failure and there is no
   // point in trying to recover from errors.
-  MOZ_UNUSED(
-      write(STDERR_FILENO, sSSE2Message, MOZ_ARRAY_LENGTH(sSSE2Message) - 1));
+  MOZ_UNUSED(write(STDERR_FILENO, sSSE2Message, std::size(sSSE2Message) - 1));
   // _exit() instead of exit() to avoid running the usual "at exit" code.
   _exit(255);
 }
@@ -92,14 +100,10 @@ __attribute__((constructor)) static void SSE2Check() {
 
 #if !defined(MOZ_WIDGET_COCOA) && !defined(MOZ_WIDGET_ANDROID)
 #  define MOZ_BROWSER_CAN_BE_CONTENTPROC
-#  include "../../ipc/contentproc/plugin-container.cpp"
 #endif
 
 using namespace mozilla;
 
-#ifdef XP_MACOSX
-#  define kOSXResourcesFolder "Resources"
-#endif
 #define kDesktopFolder "browser"
 
 static MOZ_FORMAT_PRINTF(1, 2) void Output(const char* fmt, ...) {
@@ -151,7 +155,7 @@ static bool IsArg(const char* arg, const char* s) {
   return false;
 }
 
-Bootstrap::UniquePtr gBootstrap;
+MOZ_RUNINIT Bootstrap::UniquePtr gBootstrap;
 
 static int do_main(int argc, char* argv[], char* envp[]) {
   // Allow firefox.exe to launch XULRunner apps via -app <application.ini>
@@ -187,6 +191,9 @@ static int do_main(int argc, char* argv[], char* envp[]) {
 #ifdef LIBFUZZER
     shellData.fuzzerDriver = fuzzer::FuzzerDriver;
 #endif
+#ifdef AFLFUZZ
+    shellData.fuzzerDriver = afl_interface_raw;
+#endif
 
     return gBootstrap->XRE_XPCShellMain(--argc, argv, envp, &shellData);
   }
@@ -205,14 +212,11 @@ static int do_main(int argc, char* argv[], char* envp[]) {
 #if defined(XP_WIN) && defined(MOZ_SANDBOX)
   sandbox::BrokerServices* brokerServices =
       sandboxing::GetInitializedBrokerServices();
-  sandboxing::PermissionsService* permissionsService =
-      sandboxing::GetPermissionsService();
   if (!brokerServices) {
     Output("Couldn't initialize the broker services.\n");
     return 255;
   }
   config.sandboxBrokerServices = brokerServices;
-  config.sandboxPermissionsService = permissionsService;
 #endif
 
 #ifdef LIBFUZZER
@@ -220,9 +224,7 @@ static int do_main(int argc, char* argv[], char* envp[]) {
     gBootstrap->XRE_LibFuzzerSetDriver(fuzzer::FuzzerDriver);
 #endif
 
-  // Note: keep in sync with LauncherProcessWin.
-  const char* acceptableParams[] = {"url", "private-window", nullptr};
-  EnsureCommandlineSafe(argc, argv, acceptableParams);
+  EnsureBrowserCommandlineSafe(argc, argv);
 
   return gBootstrap->XRE_main(argc, argv, config);
 }
@@ -258,32 +260,84 @@ static nsresult InitXPCOMGlue(LibLoadingStrategy aLibLoadingStrategy) {
 uint32_t gBlocklistInitFlags = eDllBlocklistInitFlagDefault;
 #endif
 
-int main(int argc, char* argv[], char* envp[]) {
-#if defined(MOZ_ENABLE_FORKSERVER)
-  if (strcmp(argv[argc - 1], "forkserver") == 0) {
-    nsresult rv = InitXPCOMGlue(LibLoadingStrategy::NoReadAhead);
-    if (NS_FAILED(rv)) {
-      return 255;
-    }
-
-    // Run a fork server in this process, single thread.  When it
-    // returns, it means the fork server have been stopped or a new
-    // content process is created.
-    //
-    // For the later case, XRE_ForkServer() will return false, running
-    // in a content process just forked from the fork server process.
-    // argc & argv will be updated with the values passing from the
-    // chrome process.  With the new values, this function
-    // continues the reset of the code acting as a content process.
-    if (gBootstrap->XRE_ForkServer(&argc, &argv)) {
-      // Return from the fork server in the fork server process.
-      // Stop the fork server.
-      gBootstrap->NS_LogTerm();
-      return 0;
-    }
-    // In a content process forked from the fork server.
-    // Start acting as a content process.
+#if defined(XP_UNIX)
+static void ReserveDefaultFileDescriptors() {
+  // Reserve the lower positions of the file descriptors to make sure
+  // we don't reuse stdin/stdout/stderr in case they were closed
+  // before launch.
+  // Otherwise code explicitly writing to fd 1 or 2 might accidentally
+  // write to something else, like in bug 1820896 where FD 1 is
+  // reused for the X server display connection.
+  int fd = open("/dev/null", O_RDONLY);
+  for (int i = 0; i < 2; i++) {
+    mozilla::Unused << dup(fd);
   }
+}
+#endif
+
+#ifdef XP_LINUX
+// Linux performance hack: when the fd table expands to the next power
+// of two, in a multithreaded process it blocks for 30-50ms due to
+// RCU, and this applies separately to each process, so it can add up.
+// But, for a single-threaded process it's basically free, so we can
+// pre-expand early in startup to a value that will usually be enough.
+// The table takes one machine word per entry, so it's cheap in memory.
+//
+// Idea from https://chromium-review.googlesource.com/c/chromium/src/+/6845921
+static void ExpandFileDescriptorTable() {
+  // Expand the table to size 512 by creating a fd with the first
+  // unused number greater than 255 (unlike dup2, this won't overwrite
+  // an existing fd).  Empirically, 512 seems to be enough for our
+  // content processes in most cases.
+  mozilla::UniqueFileHandle fdTableExpander(fcntl(0, F_DUPFD, 256));
+  // The fd is immediately closed (if it was created; we ignore errors
+  // because this is just an optimization).
+}
+#endif
+
+int main(int argc, char* argv[], char* envp[]) {
+#if defined(XP_UNIX)
+  ReserveDefaultFileDescriptors();
+#endif
+
+#ifdef MOZ_BROWSER_CAN_BE_CONTENTPROC
+  if (argc > 1 && IsArg(argv[1], "contentproc")) {
+    // Set the process type and gecko child id.
+    SetGeckoProcessType(argv[--argc]);
+    SetGeckoChildID(argv[--argc]);
+
+#  if defined(MOZ_ENABLE_FORKSERVER)
+    if (GetGeckoProcessType() == GeckoProcessType_ForkServer) {
+      nsresult rv = InitXPCOMGlue(LibLoadingStrategy::NoReadAhead);
+      if (NS_FAILED(rv)) {
+        return 255;
+      }
+
+      // Run a fork server in this process, single thread. When it returns, it
+      // means the fork server have been stopped or a new child process is
+      // created.
+      //
+      // For the latter case, XRE_ForkServer() will return false, running in a
+      // child process just forked from the fork server process. argc & argv
+      // will be updated with the values passing from the chrome process, as
+      // will GeckoProcessType and GeckoChildID. With the new values, this
+      // function continues the reset of the code acting as a child process.
+      if (gBootstrap->XRE_ForkServer(&argc, &argv)) {
+        // Return from the fork server in the fork server process.
+        // Stop the fork server.
+        // InitXPCOMGlue calls NS_LogInit, so we need to balance it here.
+        gBootstrap->NS_LogTerm();
+        return 0;
+      }
+    }
+#  endif
+  }
+#endif
+
+#ifdef XP_LINUX
+  // Do this as early as possible but after the fork server hook,
+  // because forking resets the fd table size.
+  ExpandFileDescriptorTable();
 #endif
 
   mozilla::TimeStamp start = mozilla::TimeStamp::Now();
@@ -291,24 +345,38 @@ int main(int argc, char* argv[], char* envp[]) {
   AUTO_BASE_PROFILER_INIT;
   AUTO_BASE_PROFILER_LABEL("nsBrowserApp main", OTHER);
 
+  // Register an external module to report on otherwise uncatchable exceptions.
+  // Note that in child processes this must be called after Gecko process type
+  // has been set.
+  CrashReporter::RegisterRuntimeExceptionModule();
+
+  // Make sure we unregister the runtime exception module before returning.
+  auto unregisterRuntimeExceptionModule =
+      MakeScopeExit([] { CrashReporter::UnregisterRuntimeExceptionModule(); });
+
 #ifdef MOZ_BROWSER_CAN_BE_CONTENTPROC
   // We are launching as a content process, delegate to the appropriate
   // main
-  if (argc > 1 && IsArg(argv[1], "contentproc")) {
-#  ifdef HAS_DLL_BLOCKLIST
-    DllBlocklist_Initialize(gBlocklistInitFlags |
-                            eDllBlocklistInitFlagIsChildProcess);
-#  endif
+  if (GetGeckoProcessType() != GeckoProcessType_Default) {
 #  if defined(XP_WIN) && defined(MOZ_SANDBOX)
     // We need to set whether our process is supposed to have win32k locked down
-    // from the command line setting before GetInitializedTargetServices and
-    // WindowsDpiInitialization.
+    // from the command line setting before DllBlocklist_Initialize,
+    // GetInitializedTargetServices and WindowsDpiInitialization.
     Maybe<bool> win32kLockedDown =
         mozilla::geckoargs::sWin32kLockedDown.Get(argc, argv);
     if (win32kLockedDown.isSome() && *win32kLockedDown) {
       mozilla::SetWin32kLockedDownInPolicy();
     }
+#  endif
 
+#  ifdef HAS_DLL_BLOCKLIST
+    uint32_t initFlags =
+        gBlocklistInitFlags | eDllBlocklistInitFlagIsChildProcess;
+    SetDllBlocklistProcessTypeFlags(initFlags, GetGeckoProcessType());
+    DllBlocklist_Initialize(initFlags);
+#  endif  // HAS_DLL_BLOCKLIST
+
+#  if defined(XP_WIN) && defined(MOZ_SANDBOX)
     // We need to initialize the sandbox TargetServices before InitXPCOMGlue
     // because we might need the sandbox broker to give access to some files.
     if (IsSandboxedProcess() && !sandboxing::GetInitializedTargetServices()) {
@@ -335,7 +403,21 @@ int main(int argc, char* argv[], char* envp[]) {
       return 255;
     }
 
-    int result = content_process_main(gBootstrap.get(), argc, argv);
+    XREChildData childData;
+
+#  if defined(XP_WIN) && defined(MOZ_SANDBOX)
+    if (IsSandboxedProcess()) {
+      childData.sandboxTargetServices =
+          mozilla::sandboxing::GetInitializedTargetServices();
+      if (!childData.sandboxTargetServices) {
+        return 1;
+      }
+
+      childData.ProvideLogFunction = mozilla::sandboxing::ProvideLogFunction;
+    }
+#  endif
+
+    rv = gBootstrap->XRE_InitChildProcess(argc, argv, &childData);
 
 #  if defined(DEBUG) && defined(HAS_DLL_BLOCKLIST)
     DllBlocklist_Shutdown();
@@ -344,7 +426,7 @@ int main(int argc, char* argv[], char* envp[]) {
     // InitXPCOMGlue calls NS_LogInit, so we need to balance it here.
     gBootstrap->NS_LogTerm();
 
-    return result;
+    return NS_FAILED(rv) ? 1 : 0;
   }
 #endif
 
@@ -387,7 +469,6 @@ int main(int argc, char* argv[], char* envp[]) {
   // a writable section handle because all dependent modules have been
   // loaded.
   mozilla::freestanding::gSharedSection.ConvertToReadOnly();
-  ::RtlRunOnceInitialize(&mozilla::freestanding::gK32ExportsResolveOnce);
 
   mozilla::CreateAndStorePreXULSkeletonUI(GetModuleHandle(nullptr), argc, argv);
 #endif
