@@ -4,8 +4,6 @@
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at https://mozilla.org/MPL/2.0/. */
 
-#define MOZ_USE_LAUNCHER_ERROR
-
 #include "LauncherProcessWin.h"
 
 #include <string.h>
@@ -15,7 +13,9 @@
 #include "mozilla/DebugOnly.h"
 #include "mozilla/DynamicallyLinkedFunctionPtr.h"
 #include "mozilla/glue/Debug.h"
+#include "mozilla/GeckoArgs.h"
 #include "mozilla/Maybe.h"
+#include "mozilla/NativeNt.h"
 #include "mozilla/SafeMode.h"
 #include "mozilla/UniquePtr.h"
 #include "mozilla/WindowsConsole.h"
@@ -30,12 +30,24 @@
 #include "ErrorHandler.h"
 #include "LaunchUnelevated.h"
 #include "ProcThreadAttributes.h"
+#include "../BrowserDefines.h"
 
 #if defined(MOZ_LAUNCHER_PROCESS)
 #  include "mozilla/LauncherRegistryInfo.h"
 #  include "SameBinary.h"
 #endif  // defined(MOZ_LAUNCHER_PROCESS)
 
+#if defined(MOZ_SANDBOX)
+#  include "mozilla/sandboxing/SandboxInitialization.h"
+#endif
+
+namespace mozilla {
+// "const" because nothing in this process modifies it.
+// "volatile" because something in another process may.
+const volatile DeelevationStatus gDeelevationStatus =
+    DeelevationStatus::DefaultStaticValue;
+}  // namespace mozilla
+
 /**
  * At this point the child process has been created in a suspended state. Any
  * additional startup work (eg, blocklist setup) should go here.
@@ -44,9 +56,59 @@
  */
 static mozilla::LauncherVoidResult PostCreationSetup(
     const wchar_t* aFullImagePath, HANDLE aChildProcess,
-    HANDLE aChildMainThread, const bool aIsSafeMode) {
-  return mozilla::InitializeDllBlocklistOOPFromLauncher(aFullImagePath,
-                                                        aChildProcess);
+    HANDLE aChildMainThread, mozilla::DeelevationStatus aDStatus,
+    const bool aIsSafeMode, const bool aDisableDynamicBlocklist,
+    mozilla::Maybe<std::wstring> aBlocklistFileName) {
+  /* scope for txManager */ {
+    mozilla::nt::CrossExecTransferManager txManager(aChildProcess);
+    if (!txManager) {
+      return LAUNCHER_ERROR_FROM_WIN32(ERROR_BAD_EXE_FORMAT);
+    }
+
+    using mozilla::gDeelevationStatus;
+
+    void* targetAddress = (LPVOID)&gDeelevationStatus;
+
+    auto const guard = txManager.Protect(
+        targetAddress, sizeof(gDeelevationStatus), PAGE_READWRITE);
+
+    mozilla::LauncherVoidResult result =
+        txManager.Transfer(targetAddress, &aDStatus, sizeof(aDStatus));
+    if (result.isErr()) {
+      return result;
+    }
+  }
+
+  return mozilla::InitializeDllBlocklistOOPFromLauncher(
+      aFullImagePath, aChildProcess, aDisableDynamicBlocklist,
+      aBlocklistFileName);
+}
+
+/**
+ * Create a new Job object and assign |aProcess| to it.  If something fails
+ * in this function, we return nullptr but continue without recording
+ * a launcher failure because it's not a critical problem to launch
+ * the browser process.
+ */
+static nsReturnRef<HANDLE> CreateJobAndAssignProcess(HANDLE aProcess) {
+  nsAutoHandle empty;
+  nsAutoHandle job(::CreateJobObjectW(nullptr, nullptr));
+
+  // Set JOB_OBJECT_LIMIT_SILENT_BREAKAWAY_OK to put only browser process
+  // into a job without putting children of browser process into the job.
+  JOBOBJECT_EXTENDED_LIMIT_INFORMATION jobInfo = {};
+  jobInfo.BasicLimitInformation.LimitFlags =
+      JOB_OBJECT_LIMIT_KILL_ON_JOB_CLOSE | JOB_OBJECT_LIMIT_SILENT_BREAKAWAY_OK;
+  if (!::SetInformationJobObject(job.get(), JobObjectExtendedLimitInformation,
+                                 &jobInfo, sizeof(jobInfo))) {
+    return empty.out();
+  }
+
+  if (!::AssignProcessToJobObject(job.get(), aProcess)) {
+    return empty.out();
+  }
+
+  return job.out();
 }
 
 #if !defined( \
@@ -60,12 +122,6 @@ static mozilla::LauncherVoidResult PostCreationSetup(
     (0x00000002ULL << 40)
 #endif  // !defined(PROCESS_CREATION_MITIGATION_POLICY_CONTROL_FLOW_GUARD_ALWAYS_OFF)
 
-#if (_WIN32_WINNT < 0x0602)
-BOOL WINAPI
-SetProcessMitigationPolicy(PROCESS_MITIGATION_POLICY aMitigationPolicy,
-                           PVOID aBuffer, SIZE_T aBufferLen);
-#endif  // (_WIN32_WINNT >= 0x0602)
-
 /**
  * Any mitigation policies that should be set on the browser process should go
  * here.
@@ -89,28 +145,31 @@ static void SetMitigationPolicies(mozilla::ProcThreadAttributes& aAttrs,
 static mozilla::LauncherFlags ProcessCmdLine(int& aArgc, wchar_t* aArgv[]) {
   mozilla::LauncherFlags result = mozilla::LauncherFlags::eNone;
 
-  if (mozilla::CheckArg(aArgc, aArgv, L"wait-for-browser",
-                        static_cast<const wchar_t**>(nullptr),
+  if (mozilla::CheckArg(aArgc, aArgv, "wait-for-browser", nullptr,
                         mozilla::CheckArgFlag::RemoveArg) ==
           mozilla::ARG_FOUND ||
-      mozilla::CheckArg(aArgc, aArgv, L"marionette",
-                        static_cast<const wchar_t**>(nullptr),
+      mozilla::CheckArg(aArgc, aArgv, "marionette", nullptr,
                         mozilla::CheckArgFlag::None) == mozilla::ARG_FOUND ||
-      mozilla::CheckArg(aArgc, aArgv, L"backgroundtask",
-                        static_cast<const wchar_t**>(nullptr),
+      mozilla::CheckArg(aArgc, aArgv, "backgroundtask", nullptr,
                         mozilla::CheckArgFlag::None) == mozilla::ARG_FOUND ||
-      mozilla::CheckArg(aArgc, aArgv, L"headless",
-                        static_cast<const wchar_t**>(nullptr),
+      mozilla::CheckArg(aArgc, aArgv, "headless", nullptr,
+                        mozilla::CheckArgFlag::None) == mozilla::ARG_FOUND ||
+      mozilla::CheckArg(aArgc, aArgv, "remote-debugging-port", nullptr,
                         mozilla::CheckArgFlag::None) == mozilla::ARG_FOUND ||
       mozilla::EnvHasValue("MOZ_AUTOMATION") ||
       mozilla::EnvHasValue("MOZ_HEADLESS")) {
     result |= mozilla::LauncherFlags::eWaitForBrowser;
   }
 
-  if (mozilla::CheckArg(aArgc, aArgv, L"no-deelevate") == mozilla::ARG_FOUND) {
+  if (mozilla::CheckArg(aArgc, aArgv, "no-deelevate") == mozilla::ARG_FOUND) {
     result |= mozilla::LauncherFlags::eNoDeelevate;
   }
 
+  if (mozilla::CheckArg(aArgc, aArgv, ATTEMPTING_DEELEVATION_FLAG) ==
+      mozilla::ARG_FOUND) {
+    result |= mozilla::LauncherFlags::eDeelevating;
+  }
+
   return result;
 }
 
@@ -155,9 +214,9 @@ static bool DoLauncherProcessChecks(int& argc, wchar_t** argv) {
     result = true;
   }
 
-  result |= mozilla::CheckArg(
-                argc, argv, L"launcher", static_cast<const wchar_t**>(nullptr),
-                mozilla::CheckArgFlag::RemoveArg) == mozilla::ARG_FOUND;
+  result |=
+      mozilla::CheckArg(argc, argv, "launcher", nullptr,
+                        mozilla::CheckArgFlag::RemoveArg) == mozilla::ARG_FOUND;
 
   return result;
 }
@@ -168,22 +227,12 @@ static mozilla::Maybe<bool> RunAsLauncherProcess(
 #else
 static mozilla::Maybe<bool> RunAsLauncherProcess(int& argc, wchar_t** argv) {
 #endif  // defined(MOZ_LAUNCHER_PROCESS)
-  // return fast when we're a child process.
-  // (The remainder of this function has some side effects that are
-  // undesirable for content processes)
-  if (mozilla::CheckArg(argc, argv, L"contentproc",
-                        static_cast<const wchar_t**>(nullptr),
-                        mozilla::CheckArgFlag::None) == mozilla::ARG_FOUND) {
-    return mozilla::Some(false);
-  }
-
   bool runAsLauncher = DoLauncherProcessChecks(argc, argv);
 
 #if defined(MOZ_LAUNCHER_PROCESS)
   bool forceLauncher =
       runAsLauncher &&
-      mozilla::CheckArg(argc, argv, L"force-launcher",
-                        static_cast<const wchar_t**>(nullptr),
+      mozilla::CheckArg(argc, argv, "force-launcher", nullptr,
                         mozilla::CheckArgFlag::RemoveArg) == mozilla::ARG_FOUND;
 
   mozilla::LauncherRegistryInfo::ProcessType desiredType =
@@ -217,25 +266,29 @@ static mozilla::Maybe<bool> RunAsLauncherProcess(int& argc, wchar_t** argv) {
 
 namespace mozilla {
 
-Maybe<int> LauncherMain(int& argc, wchar_t* argv[],
-                        const StaticXREAppData& aAppData) {
-  // Note: keep in sync with nsBrowserApp.
-  const wchar_t* acceptableParams[] = {L"url", nullptr};
-  EnsureCommandlineSafe(argc, argv, acceptableParams);
+Maybe<int> LauncherMain(int& argc, wchar_t* argv[]) {
+  EnsureBrowserCommandlineSafe(argc, argv);
 
-  SetLauncherErrorAppData(aAppData);
-
-  if (CheckArg(argc, argv, L"log-launcher-error",
-               static_cast<const wchar_t**>(nullptr),
-               mozilla::CheckArgFlag::RemoveArg) == ARG_FOUND) {
-    SetLauncherErrorForceEventLog();
+  // return fast when we're a child process.
+  // (The remainder of this function has some side effects that are
+  // undesirable for content processes)
+  if (mozilla::CheckArg(argc, argv, "contentproc", nullptr,
+                        mozilla::CheckArgFlag::None) == mozilla::ARG_FOUND) {
+    // A child process should not instantiate LauncherRegistryInfo.
+    return Nothing();
   }
 
 #if defined(MOZ_LAUNCHER_PROCESS)
   LauncherRegistryInfo regInfo;
   Maybe<bool> runAsLauncher = RunAsLauncherProcess(regInfo, argc, argv);
+  LauncherResult<std::wstring> blocklistFileNameResult =
+      regInfo.GetBlocklistFileName();
+  Maybe<std::wstring> blocklistFileName =
+      blocklistFileNameResult.isOk() ? Some(blocklistFileNameResult.unwrap())
+                                     : Nothing();
 #else
   Maybe<bool> runAsLauncher = RunAsLauncherProcess(argc, argv);
+  Maybe<std::wstring> blocklistFileName = Nothing();
 #endif  // defined(MOZ_LAUNCHER_PROCESS)
   if (!runAsLauncher || !runAsLauncher.value()) {
 #if defined(MOZ_LAUNCHER_PROCESS)
@@ -264,6 +317,11 @@ Maybe<int> LauncherMain(int& argc, wchar_t* argv[],
     }
   }
 
+#if defined(MOZ_SANDBOX)
+  // Ensure the relevant mitigations are enforced.
+  mozilla::sandboxing::ApplyParentProcessMitigations();
+#endif
+
   mozilla::UseParentConsole();
 
   if (!SetArgv0ToFullBinaryPath(argv)) {
@@ -281,21 +339,50 @@ Maybe<int> LauncherMain(int& argc, wchar_t* argv[],
     return Nothing();
   }
 
-  // If we're elevated, we should relaunch ourselves as a normal user.
-  // Note that we only call LaunchUnelevated when we don't need to wait for the
-  // browser process.
-  if (elevationState.unwrap() == ElevationState::eElevated &&
-      !(flags &
-        (LauncherFlags::eWaitForBrowser | LauncherFlags::eNoDeelevate)) &&
-      !mediumIlToken.get()) {
-    LauncherVoidResult launchedUnelevated = LaunchUnelevated(argc, argv);
-    bool failed = launchedUnelevated.isErr();
-    if (failed) {
-      HandleLauncherError(launchedUnelevated);
-      return Nothing();
+  // Distill deelevation status, and/or attempt to perform launcher deelevation
+  // via an indirect relaunch.
+  DeelevationStatus deelevationStatus = DeelevationStatus::Unknown;
+  if (mediumIlToken.get()) {
+    // Rather than indirectly relaunch the launcher, we'll attempt to directly
+    // launch the main process with a reduced-privilege security token.
+    deelevationStatus = DeelevationStatus::PartiallyDeelevated;
+  } else if (elevationState.unwrap() == ElevationState::eElevated) {
+    if (flags & LauncherFlags::eWaitForBrowser) {
+      // An indirect relaunch won't provide a process-handle to block on,
+      // so we have to continue onwards with this process.
+      deelevationStatus = DeelevationStatus::DeelevationProhibited;
+    } else if (flags & LauncherFlags::eNoDeelevate) {
+      // Our invoker (hopefully, the user) has explicitly requested that the
+      // launcher not deelevate itself.
+      deelevationStatus = DeelevationStatus::DeelevationProhibited;
+    } else if (flags & LauncherFlags::eDeelevating) {
+      // We've already tried to deelevate, to no effect. Continue onward.
+      deelevationStatus = DeelevationStatus::UnsuccessfullyDeelevated;
+    } else {
+      // Otherwise, attempt to relaunch the launcher process itself via the
+      // shell, which hopefully will not be elevated. (But see bug 1733821.)
+      LauncherVoidResult launchedUnelevated = LaunchUnelevated(argc, argv);
+      if (launchedUnelevated.isErr()) {
+        // On failure, don't even try for a launcher process. Continue onwards
+        // in this one. (TODO: why? This isn't technically fatal...)
+        HandleLauncherError(launchedUnelevated);
+        return Nothing();
+      }
+      // Otherwise, tell our caller to exit with a success code.
+      return Some(0);
     }
-
-    return Some(0);
+  } else if (elevationState.unwrap() == ElevationState::eNormalUser) {
+    if (flags & LauncherFlags::eDeelevating) {
+      // Deelevation appears to have been successful!
+      deelevationStatus = DeelevationStatus::SuccessfullyDeelevated;
+    } else {
+      // We haven't done anything and we don't need to.
+      deelevationStatus = DeelevationStatus::StartedUnprivileged;
+    }
+  } else {
+    // Some other elevation state with no medium-integrity token.
+    // (This should probably not happen.)
+    deelevationStatus = DeelevationStatus::Unknown;
   }
 
 #if defined(MOZ_LAUNCHER_PROCESS)
@@ -357,7 +444,7 @@ Maybe<int> LauncherMain(int& argc, wchar_t* argv[],
   }
 
   // Pass on the path of the shortcut used to launch this process, if any.
-  STARTUPINFOW currentStartupInfo;
+  STARTUPINFOW currentStartupInfo = {.cb = sizeof(STARTUPINFOW)};
   GetStartupInfoW(&currentStartupInfo);
   if ((currentStartupInfo.dwFlags & STARTF_TITLEISLINKNAME) &&
       currentStartupInfo.lpTitle) {
@@ -387,8 +474,19 @@ Maybe<int> LauncherMain(int& argc, wchar_t* argv[],
   nsAutoHandle process(pi.hProcess);
   nsAutoHandle mainThread(pi.hThread);
 
+  nsAutoHandle job;
+  if (flags & LauncherFlags::eWaitForBrowser) {
+    job = CreateJobAndAssignProcess(process.get());
+  }
+
+  bool disableDynamicBlocklist = IsDynamicBlocklistDisabled(
+      isSafeMode.value(),
+      mozilla::CheckArg(
+          argc, argv, mozilla::geckoargs::sDisableDynamicDllBlocklist.sMatch,
+          nullptr, mozilla::CheckArgFlag::None) == mozilla::ARG_FOUND);
   LauncherVoidResult setupResult = PostCreationSetup(
-      argv[0], process.get(), mainThread.get(), isSafeMode.value());
+      argv[0], process.get(), mainThread.get(), deelevationStatus,
+      isSafeMode.value(), disableDynamicBlocklist, blocklistFileName);
   if (setupResult.isErr()) {
     HandleLauncherError(setupResult);
     ::TerminateProcess(process.get(), 1);
