@@ -2,12 +2,6 @@
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
-ChromeUtils.defineModuleGetter(
-  this,
-  "SearchUIUtils",
-  "resource:///modules/SearchUIUtils.jsm"
-);
-
 var BrowserPageActions = {
   _panelNode: null,
   /**
@@ -346,9 +340,9 @@ var BrowserPageActions = {
 
     let anchorNode = this.panelAnchorNodeForAction(action);
     PanelMultiView.openPopup(panelNode, anchorNode, {
-      position: "bottomcenter topright",
+      position: "bottomright topright",
       triggerEvent: event,
-    }).catch(Cu.reportError);
+    }).catch(console.error);
   },
 
   _makeActivatedActionPanelForAction(action) {
@@ -450,21 +444,19 @@ var BrowserPageActions = {
     }
 
     // Try each of the following nodes in order, using the first that's visible.
-    let potentialAnchorNodeIDs = [
-      action && action.anchorIDOverride,
-      action && this.urlbarButtonNodeIDForActionID(action.id),
-      this.mainButtonNode.id,
-      "identity-icon",
-      "urlbar-search-button",
+    let potentialAnchorNodes = [
+      document.getElementById(action?.anchorIDOverride),
+      document.getElementById(
+        action && this.urlbarButtonNodeIDForActionID(action.id)
+      ),
+      document.getElementById(this.mainButtonNode.id),
+      document.getElementById("identity-icon"),
     ];
-    for (let id of potentialAnchorNodeIDs) {
-      if (id) {
-        let node = document.getElementById(id);
-        if (node && !node.hidden) {
-          let bounds = window.windowUtils.getBoundsWithoutFlushing(node);
-          if (bounds.height > 0 && bounds.width > 0) {
-            return node;
-          }
+    for (let node of potentialAnchorNodes) {
+      if (node && !node.hidden) {
+        let bounds = window.windowUtils.getBoundsWithoutFlushing(node);
+        if (bounds.height > 0 && bounds.width > 0) {
+          return node;
         }
       }
     }
@@ -533,7 +525,7 @@ var BrowserPageActions = {
 
   _makeUrlbarButtonNode(action) {
     let buttonNode = document.createXULElement("hbox");
-    buttonNode.classList.add("urlbar-icon-wrapper", "urlbar-page-action");
+    buttonNode.classList.add("urlbar-page-action");
     if (action.extensionID) {
       buttonNode.classList.add("urlbar-addon-page-action");
     }
@@ -923,9 +915,9 @@ var BrowserPageActions = {
   showPanel(event = null) {
     this.panelNode.hidden = false;
     PanelMultiView.openPopup(this.panelNode, this.mainButtonNode, {
-      position: "bottomcenter topright",
+      position: "bottomright topright",
       triggerEvent: event,
-    }).catch(Cu.reportError);
+    }).catch(console.error);
   },
 
   /**
@@ -971,14 +963,8 @@ var BrowserPageActions = {
     let action = this._contextAction;
     this._contextAction = null;
 
-    AMTelemetry.recordActionEvent({
-      object: "pageAction",
-      action: "manage",
-      extra: { addonId: action.extensionID },
-    });
-
     let viewID = "addons://detail/" + encodeURIComponent(action.extensionID);
-    window.BrowserOpenAddonsMgr(viewID);
+    window.BrowserAddonUI.openAddonsMgr(viewID);
   },
 
   /**
@@ -1016,7 +1002,7 @@ BrowserPageActions.bookmark = {
     }
   },
 
-  onCommand(event, buttonNode) {
+  onCommand(event) {
     PanelMultiView.hidePopup(BrowserPageActions.panelNode);
     BookmarkingUI.onStarCommand(event);
   },
