@@ -6,7 +6,6 @@
 /* eslint-env mozilla/browser-window */
 
 var gSafeBrowsing = {
-
   setReportPhishingMenu() {
     // In order to detect whether or not we're at the phishing warning
     // page, we have to check the documentURI instead of the currentURI.
@@ -18,30 +17,33 @@ var gSafeBrowsing = {
       docURI && docURI.spec.startsWith("about:blocked?e=deceptiveBlocked");
 
     // Show/hide the appropriate menu item.
-    document.getElementById("menu_HelpPopup_reportPhishingtoolmenu")
-            .hidden = isPhishingPage;
-    document.getElementById("menu_HelpPopup_reportPhishingErrortoolmenu")
-            .hidden = !isPhishingPage;
+    const reportMenu = document.getElementById(
+      "menu_HelpPopup_reportPhishingtoolmenu"
+    );
+    reportMenu.hidden = isPhishingPage;
+    const reportErrorMenu = document.getElementById(
+      "menu_HelpPopup_reportPhishingErrortoolmenu"
+    );
+    reportErrorMenu.hidden = !isPhishingPage;
 
     // Now look at the currentURI to learn which page we were trying
     // to browse to.
     const uri = gBrowser.currentURI;
-    const isReportablePage = uri && (uri.schemeIs("http") || uri.schemeIs("https"));
+    const isReportablePage =
+      uri && (uri.schemeIs("http") || uri.schemeIs("https"));
 
     const disabledByPolicy = !Services.policies.isAllowed("feedbackCommands");
 
-    const reportBroadcaster = document.getElementById("reportPhishingBroadcaster");
     if (disabledByPolicy || isPhishingPage || !isReportablePage) {
-      reportBroadcaster.setAttribute("disabled", "true");
+      reportMenu.setAttribute("disabled", "true");
     } else {
-      reportBroadcaster.removeAttribute("disabled");
+      reportMenu.removeAttribute("disabled");
     }
 
-    const reportErrorBroadcaster = document.getElementById("reportPhishingErrorBroadcaster");
     if (disabledByPolicy || !isPhishingPage || !isReportablePage) {
-      reportErrorBroadcaster.setAttribute("disabled", "true");
+      reportErrorMenu.setAttribute("disabled", "true");
     } else {
-      reportErrorBroadcaster.removeAttribute("disabled");
+      reportErrorMenu.removeAttribute("disabled");
     }
   },
 
@@ -59,17 +61,57 @@ var gSafeBrowsing = {
   getReportURL(name, info) {
     let reportInfo = info;
     if (!reportInfo) {
-      let pageUri = gBrowser.currentURI.clone();
+      let pageUri = gBrowser.currentURI;
 
       // Remove the query to avoid including potentially sensitive data
       if (pageUri instanceof Ci.nsIURL) {
-        pageUri = pageUri.mutate()
-                         .setQuery("")
-                         .finalize();
+        pageUri = pageUri.mutate().setQuery("").finalize();
       }
 
       reportInfo = { uri: pageUri.asciiSpec };
     }
     return SafeBrowsing.getReportURL(name, reportInfo);
-  }
+  },
+
+  reportFalseDeceptiveSite() {
+    let contextsToVisit = [gBrowser.selectedBrowser.browsingContext];
+    while (contextsToVisit.length) {
+      let currentContext = contextsToVisit.pop();
+      let global = currentContext.currentWindowGlobal;
+
+      if (!global) {
+        continue;
+      }
+      let docURI = global.documentURI;
+      // Ensure the page is an about:blocked pagae before handling.
+      if (
+        docURI &&
+        docURI.spec.startsWith("about:blocked?e=deceptiveBlocked")
+      ) {
+        let actor = global.getActor("BlockedSite");
+        actor.sendQuery("DeceptiveBlockedDetails").then(data => {
+          let reportUrl = gSafeBrowsing.getReportURL(
+            "PhishMistake",
+            data.blockedInfo
+          );
+          if (reportUrl) {
+            openTrustedLinkIn(reportUrl, "tab");
+          } else {
+            let bundle = Services.strings.createBundle(
+              "chrome://browser/locale/safebrowsing/safebrowsing.properties"
+            );
+            Services.prompt.alert(
+              window,
+              bundle.GetStringFromName("errorReportFalseDeceptiveTitle"),
+              bundle.formatStringFromName("errorReportFalseDeceptiveMessage", [
+                data.blockedInfo.provider,
+              ])
+            );
+          }
+        });
+      }
+
+      contextsToVisit.push(...currentContext.children);
+    }
+  },
 };
