@@ -26,18 +26,19 @@
 
 ToolbarKeyboardNavigator = {
   // Toolbars we want to be keyboard navigable.
-  kToolbars: Services.prefs.getBoolPref("browser.tabs.firefox-view")
-    ? [
-        CustomizableUI.AREA_TABSTRIP,
-        CustomizableUI.AREA_NAVBAR,
-        CustomizableUI.AREA_BOOKMARKS,
-      ]
-    : [CustomizableUI.AREA_NAVBAR, CustomizableUI.AREA_BOOKMARKS],
+  kToolbars: [
+    CustomizableUI.AREA_TABSTRIP,
+    CustomizableUI.AREA_NAVBAR,
+    CustomizableUI.AREA_BOOKMARKS,
+  ],
   // Delay (in ms) after which to clear any search text typed by the user if
   // the user hasn't typed anything further.
   kSearchClearTimeout: 1000,
 
   _isButton(aElem) {
+    if (aElem.getAttribute("keyNav") === "false") {
+      return false;
+    }
     return (
       aElem.tagName == "toolbarbutton" || aElem.getAttribute("role") == "button"
     );
@@ -65,20 +66,26 @@ ToolbarKeyboardNavigator = {
         return NodeFilter.FILTER_REJECT;
       }
 
-      // Skip invisible or disabled elements.
-      if (
-        aNode.hidden ||
-        aNode.disabled ||
-        aNode.style.visibility == "hidden"
-      ) {
+      // Skip disabled elements.
+      if (aNode.disabled) {
         return NodeFilter.FILTER_REJECT;
       }
-      // This width check excludes the overflow button when there's no overflow.
-      let bounds = window.windowUtils.getBoundsWithoutFlushing(aNode);
-      if (bounds.width == 0) {
+
+      // Skip invisible elements.
+      const visible = aNode.checkVisibility({
+        checkVisibilityCSS: true,
+        flush: false,
+      });
+      if (!visible) {
         return NodeFilter.FILTER_REJECT;
       }
 
+      // This width check excludes the overflow button when there's no overflow.
+      const bounds = window.windowUtils.getBoundsWithoutFlushing(aNode);
+      if (bounds.width == 0) {
+        return NodeFilter.FILTER_SKIP;
+      }
+
       if (this._isButton(aNode)) {
         return NodeFilter.FILTER_ACCEPT;
       }
@@ -130,7 +137,7 @@ ToolbarKeyboardNavigator = {
   },
 
   // CustomizableUI event handler
-  onWidgetAdded(aWidgetId, aArea, aPosition) {
+  onWidgetAdded(aWidgetId, aArea) {
     if (!this.kToolbars.includes(aArea)) {
       return;
     }
@@ -193,16 +200,13 @@ ToolbarKeyboardNavigator = {
     let button = walker.nextNode();
     if (!button || !this._isButton(button)) {
       // If we think we're moving backward, and focus came from outside the
-      // toolbox, we might actually have wrapped around. This currently only
-      // happens in popup windows (because in normal windows, focus first
-      // goes to the tabstrip, where we don't have tabstops). In this case,
-      // the event target was the first tabstop. If we can't find a button,
-      // e.g. because we're in a popup where most buttons are hidden, we
+      // toolbox, we might actually have wrapped around. In this case, the
+      // event target was the first tabstop. If we can't find a button, e.g.
+      // because we're in a popup where most buttons are hidden, we
       // should ensure focus keeps moving forward:
       if (
-        oldFocus &&
         this._isFocusMovingBackward &&
-        !gNavToolbox.contains(oldFocus)
+        (!oldFocus || !gNavToolbox.contains(oldFocus))
       ) {
         let allStops = Array.from(
           gNavToolbox.querySelectorAll("toolbartabstop")
@@ -212,12 +216,9 @@ ToolbarKeyboardNavigator = {
         // Then work out if any of the earlier ones are in a visible
         // toolbar:
         while (earlierVisibleStopIndex >= 0) {
-          let stopToolbar = allStops[earlierVisibleStopIndex].closest(
-            "toolbar"
-          );
-          if (
-            window.windowUtils.getBoundsWithoutFlushing(stopToolbar).height > 0
-          ) {
+          let stopToolbar =
+            allStops[earlierVisibleStopIndex].closest("toolbar");
+          if (!stopToolbar.collapsed) {
             break;
           }
           earlierVisibleStopIndex--;
@@ -387,27 +388,32 @@ ToolbarKeyboardNavigator = {
 
     if (focus.getAttribute("type") == "menu") {
       focus.open = true;
-    } else {
-      // Several buttons specifically don't use command events; e.g. because
-      // they want to activate for middle click. Therefore, simulate a
-      // click event.
-      // If this button does handle command events, that won't trigger here.
-      // Command events have their own keyboard handling: keypress for enter
-      // and keyup for space. We rely on that behavior, since there's no way
-      // for us to reliably know what events a button handles.
-      focus.dispatchEvent(
-        new MouseEvent("click", {
-          bubbles: true,
-          ctrlKey: aEvent.ctrlKey,
-          altKey: aEvent.altKey,
-          shiftKey: aEvent.shiftKey,
-          metaKey: aEvent.metaKey,
-        })
-      );
+      return;
     }
-    // We deliberately don't call aEvent.preventDefault() here so that enter
-    // will trigger a command event handler if appropriate.
-    aEvent.stopPropagation();
+
+    // Several buttons specifically don't use command events; e.g. because
+    // they want to activate for middle click. Therefore, simulate a click
+    // event if we know they handle click explicitly and don't handle
+    // commands.
+    const usesClickInsteadOfCommand = (() => {
+      if (focus.tagName != "toolbarbutton") {
+        return true;
+      }
+      return !focus.hasAttribute("oncommand") && focus.hasAttribute("onclick");
+    })();
+
+    if (!usesClickInsteadOfCommand) {
+      return;
+    }
+    focus.dispatchEvent(
+      new PointerEvent("click", {
+        bubbles: true,
+        ctrlKey: aEvent.ctrlKey,
+        altKey: aEvent.altKey,
+        shiftKey: aEvent.shiftKey,
+        metaKey: aEvent.metaKey,
+      })
+    );
   },
 
   handleEvent(aEvent) {
