@@ -3,28 +3,14 @@
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
-const { Services } = ChromeUtils.import("resource://gre/modules/Services.jsm");
-
 const appStartup = Services.startup;
 
-const { ResetProfile } = ChromeUtils.import(
-  "resource://gre/modules/ResetProfile.jsm"
+const { ResetProfile } = ChromeUtils.importESModule(
+  "resource://gre/modules/ResetProfile.sys.mjs"
 );
 
 var defaultToReset = false;
 
-function restartApp() {
-  appStartup.quit(appStartup.eForceQuit | appStartup.eRestart);
-}
-
-function resetProfile() {
-  // Set the reset profile environment variable.
-  let env = Cc["@mozilla.org/process/environment;1"].getService(
-    Ci.nsIEnvironment
-  );
-  env.set("MOZ_RESET_PROFILE_RESTART", "1");
-}
-
 function showResetDialog() {
   // Prompt the user to confirm the reset.
   let retVals = {
@@ -39,8 +25,8 @@ function showResetDialog() {
   if (!retVals.reset) {
     return;
   }
-  resetProfile();
-  restartApp();
+
+  ResetProfile.doReset();
 }
 
 function onDefaultButton(event) {
@@ -48,8 +34,7 @@ function onDefaultButton(event) {
     // Prevent starting into safe mode while restarting.
     event.preventDefault();
     // Restart to reset the profile.
-    resetProfile();
-    restartApp();
+    ResetProfile.doReset();
   }
   // Dialog will be closed by default Event handler.
   // Continue in safe mode. No restart needed.
@@ -68,7 +53,7 @@ function onExtra1() {
   showResetDialog();
 }
 
-function onLoad() {
+window.addEventListener("load", () => {
   const dialog = document.getElementById("safeModeDialog");
   if (appStartup.automaticSafeModeNecessary) {
     document.getElementById("autoSafeMode").hidden = false;
@@ -87,4 +72,4 @@ function onLoad() {
   document.addEventListener("dialogaccept", onDefaultButton);
   document.addEventListener("dialogcancel", onCancel);
   document.addEventListener("dialogextra1", onExtra1);
-}
+});
