@@ -14,13 +14,13 @@ const ALERT_SERVICE = Cc["@mozilla.org/alerts-service;1"]
   .QueryInterface(Ci.nsIAlertsDoNotDisturb);
 
 const PAGE =
-  "http://example.org/browser/browser/base/content/test/alerts/file_dom_notifications.html";
+  "https://example.org/browser/browser/base/content/test/alerts/file_dom_notifications.html";
 
 // The amount of time in seconds that we will wait for a notification
 // to show up before we decide that it's not coming.
 const NOTIFICATION_TIMEOUT_SECS = 2000;
 
-add_task(async function setup() {
+add_setup(async function () {
   await addNotificationPermission(PAGE);
 });
 
