@@ -1,7 +1,7 @@
 "use strict";
 
 var notificationURL =
-  "http://example.org/browser/browser/base/content/test/alerts/file_dom_notifications.html";
+  "https://example.org/browser/browser/base/content/test/alerts/file_dom_notifications.html";
 var expectedURL = "about:preferences#privacy";
 
 add_task(async function test_settingsOpen_observer() {
@@ -13,7 +13,7 @@ add_task(async function test_settingsOpen_observer() {
       gBrowser,
       url: "about:robots",
     },
-    async function dummyTabTask(aBrowser) {
+    async function dummyTabTask() {
       // Ensure preferences is loaded before removing the tab.
       let syncPaneLoadedPromise = TestUtils.topicObserved(
         "sync-pane-loaded",
@@ -22,7 +22,7 @@ add_task(async function test_settingsOpen_observer() {
       let tabPromise = BrowserTestUtils.waitForNewTab(gBrowser, expectedURL);
       info("simulate a notifications-open-settings notification");
       let uri = NetUtil.newURI("https://example.com");
-      let principal = Services.scriptSecurityManager.createCodebasePrincipal(
+      let principal = Services.scriptSecurityManager.createContentPrincipal(
         uri,
         {}
       );
@@ -45,12 +45,6 @@ add_task(async function test_settingsOpen_button() {
       url: notificationURL,
     },
     async function tabTask(aBrowser) {
-      // Ensure preferences is loaded before removing the tab.
-      let syncPaneLoadedPromise = TestUtils.topicObserved(
-        "sync-pane-loaded",
-        () => true
-      );
-
       info("Waiting for notification");
       await openNotification(aBrowser, "showNotification2");
 
@@ -61,6 +55,11 @@ add_task(async function test_settingsOpen_button() {
         return;
       }
 
+      // Ensure preferences is loaded before removing the tab.
+      let syncPaneLoadedPromise = TestUtils.topicObserved(
+        "sync-pane-loaded",
+        () => true
+      );
       let closePromise = promiseWindowClosed(alertWindow);
       let tabPromise = BrowserTestUtils.waitForNewTab(gBrowser, expectedURL);
       let openSettingsMenuItem = alertWindow.document.getElementById(
