@@ -6,24 +6,19 @@ SELECT +=
   '  <option selected="true">{"end": "true"}</option>' +
   "</select></body></html>";
 
-add_setup(async function() {
+add_setup(async function () {
   await SpecialPowers.pushPrefEnv({
-    set: [["dom.forms.selectSearch", true]],
+    set: [
+      ["test.wait300msAfterTabSwitch", true],
+      ["dom.forms.selectSearch", true],
+    ],
   });
 });
 
 add_task(async function test_focus_on_search_shouldnt_close_popup() {
   const pageUrl = "data:text/html," + escape(SELECT);
   let tab = await BrowserTestUtils.openNewForegroundTab(gBrowser, pageUrl);
-
-  let popupShownPromise = BrowserTestUtils.waitForSelectPopupShown(window);
-
-  await BrowserTestUtils.synthesizeMouseAtCenter(
-    "#one",
-    { type: "mousedown" },
-    gBrowser.selectedBrowser
-  );
-  let selectPopup = await popupShownPromise;
+  let selectPopup = await openSelectPopup("mousedown");
 
   let searchInput = selectPopup.querySelector(
     ".contentSelectDropdown-searchbox"
