@@ -4,7 +4,7 @@ async function test() {
   waitForExplicitFinish();
 
   BrowserTestUtils.openNewForegroundTab(gBrowser, "about:home", true).then(
-    function(tab) {
+    function (tab) {
       ourTab = tab;
       ok(
         !document.querySelector(".printPreviewBrowser"),
@@ -32,7 +32,7 @@ async function openPrintPreview() {
   document.getElementById("cmd_print").doCommand();
   await BrowserTestUtils.waitForCondition(() => {
     let preview = document.querySelector(".printPreviewBrowser");
-    return preview && BrowserTestUtils.is_visible(preview);
+    return preview && BrowserTestUtils.isVisible(preview);
   });
 }
 
