@@ -12,7 +12,7 @@ const kDevPanelID = "PanelUI-developer-tools";
 function waitForLocationChange() {
   let promise = new Promise(resolve => {
     let wpl = {
-      onLocationChange(aWebProgress, aRequest, aLocation) {
+      onLocationChange() {
         gBrowser.removeProgressListener(wpl);
         resolve();
       },
@@ -24,7 +24,10 @@ function waitForLocationChange() {
 
 add_task(async function setPref() {
   await SpecialPowers.pushPrefEnv({
-    set: [["browser.toolbars.keyboard_navigation", true]],
+    set: [
+      ["test.wait300msAfterTabSwitch", true],
+      ["browser.toolbars.keyboard_navigation", true],
+    ],
   });
 });
 
@@ -32,13 +35,12 @@ add_task(async function setPref() {
 // The app menu should appear and focus should move inside it.
 add_task(async function testAppMenuButtonPress() {
   let button = document.getElementById("PanelUI-menu-button");
-  forceFocus(button);
   let focused = BrowserTestUtils.waitForEvent(
     window.PanelUI.mainView,
     "focus",
     true
   );
-  EventUtils.synthesizeKey(" ");
+  await focusAndActivateElement(button, () => EventUtils.synthesizeKey(" "));
   await focused;
   ok(true, "Focus inside app menu after toolbar button pressed");
   let hidden = BrowserTestUtils.waitForEvent(
@@ -53,8 +55,9 @@ add_task(async function testAppMenuButtonPress() {
 // pressed .
 add_task(async function testAppMenuButtonWrongKey() {
   let button = document.getElementById("PanelUI-menu-button");
-  forceFocus(button);
-  EventUtils.synthesizeKey("KEY_Tab");
+  await focusAndActivateElement(button, () =>
+    EventUtils.synthesizeKey("KEY_Tab")
+  );
   await TestUtils.waitForTick();
   is(window.PanelUI.panel.state, "closed", "App menu is closed after tab");
 });
@@ -64,8 +67,7 @@ add_task(async function testAppMenuButtonWrongKey() {
 add_task(async function testLibraryButtonPress() {
   CustomizableUI.addWidgetToArea("library-button", "nav-bar");
   let button = document.getElementById("library-button");
-  forceFocus(button);
-  EventUtils.synthesizeKey(" ");
+  await focusAndActivateElement(button, () => EventUtils.synthesizeKey(" "));
   let view = document.getElementById("appMenu-libraryView");
   let focused = BrowserTestUtils.waitForEvent(view, "focus", true);
   await focused;
@@ -85,8 +87,7 @@ add_task(async function testDeveloperButtonPress() {
     CustomizableUI.AREA_NAVBAR
   );
   let button = document.getElementById("developer-button");
-  forceFocus(button);
-  EventUtils.synthesizeKey(" ");
+  await focusAndActivateElement(button, () => EventUtils.synthesizeKey(" "));
   let view = document.getElementById(kDevPanelID);
   let focused = BrowserTestUtils.waitForEvent(view, "focus", true);
   await focused;
@@ -105,8 +106,9 @@ add_task(async function testDeveloperButtonWrongKey() {
     CustomizableUI.AREA_NAVBAR
   );
   let button = document.getElementById("developer-button");
-  forceFocus(button);
-  EventUtils.synthesizeKey("KEY_Tab");
+  await focusAndActivateElement(button, () =>
+    EventUtils.synthesizeKey("KEY_Tab")
+  );
   await TestUtils.waitForTick();
   let panel = document.getElementById(kDevPanelID).closest("panel");
   ok(!panel || panel.state == "closed", "Developer menu not open after tab");
@@ -122,10 +124,9 @@ add_task(async function testPageActionsButtonPress() {
   registerCleanupFunction(() => {
     BrowserPageActions.mainButtonNode.style.removeProperty("visibility");
   });
-  await BrowserTestUtils.withNewTab("https://example.com", async function() {
+  await BrowserTestUtils.withNewTab("https://example.com", async function () {
     let button = document.getElementById("pageActionButton");
-    forceFocus(button);
-    EventUtils.synthesizeKey(" ");
+    await focusAndActivateElement(button, () => EventUtils.synthesizeKey(" "));
     let view = document.getElementById("pageActionPanelMainView");
     let focused = BrowserTestUtils.waitForEvent(view, "focus", true);
     await focused;
@@ -138,85 +139,125 @@ add_task(async function testPageActionsButtonPress() {
 
 // Test activation of the Back and Forward buttons from the keyboard.
 add_task(async function testBackForwardButtonPress() {
-  await BrowserTestUtils.withNewTab("https://example.com/1", async function(
-    aBrowser
-  ) {
-    BrowserTestUtils.loadURI(aBrowser, "https://example.com/2");
+  await BrowserTestUtils.withNewTab(
+    "https://example.com/1",
+    async function (aBrowser) {
+      BrowserTestUtils.startLoadingURIString(aBrowser, "https://example.com/2");
 
-    await BrowserTestUtils.browserLoaded(aBrowser);
-    let backButton = document.getElementById("back-button");
-    forceFocus(backButton);
-    let onLocationChange = waitForLocationChange();
-    EventUtils.synthesizeKey(" ");
-    await onLocationChange;
-    ok(true, "Location changed after back button pressed");
+      await BrowserTestUtils.browserLoaded(aBrowser);
+      let backButton = document.getElementById("back-button");
+      let onLocationChange = waitForLocationChange();
+      await focusAndActivateElement(backButton, () =>
+        EventUtils.synthesizeKey(" ")
+      );
+      await onLocationChange;
+      ok(true, "Location changed after back button pressed");
 
-    let forwardButton = document.getElementById("forward-button");
-    forceFocus(forwardButton);
-    onLocationChange = waitForLocationChange();
-    EventUtils.synthesizeKey(" ");
-    await onLocationChange;
-    ok(true, "Location changed after forward button pressed");
-  });
+      let forwardButton = document.getElementById("forward-button");
+      onLocationChange = waitForLocationChange();
+      await focusAndActivateElement(forwardButton, () =>
+        EventUtils.synthesizeKey(" ")
+      );
+      await onLocationChange;
+      ok(true, "Location changed after forward button pressed");
+    }
+  );
 });
 
 // Test activation of the Reload button from the keyboard.
 // This is a toolbarbutton with a click handler and no command handler, but
 // the toolbar keyboard navigation code should handle keyboard activation.
 add_task(async function testReloadButtonPress() {
-  await BrowserTestUtils.withNewTab("https://example.com/1", async function(
-    aBrowser
-  ) {
-    let button = document.getElementById("reload-button");
-    info("Waiting for button to be enabled.");
-    await TestUtils.waitForCondition(() => !button.disabled);
-    let loaded = BrowserTestUtils.browserLoaded(aBrowser);
-    info("Focusing button");
-    forceFocus(button);
-    info("Pressing space on the button");
-    EventUtils.synthesizeKey(" ");
-    info("Waiting for load.");
-    await loaded;
-    ok(true, "Page loaded after Reload button pressed");
-  });
+  await BrowserTestUtils.withNewTab(
+    "https://example.com/1",
+    async function (aBrowser) {
+      info("Waiting for button to be enabled.");
+      let button = document.getElementById("reload-button");
+      await TestUtils.waitForCondition(() => !button.disabled);
+      let loaded = BrowserTestUtils.browserLoaded(aBrowser);
+      info("Focusing button");
+      await focusAndActivateElement(button, () => {
+        info("Pressing space on the button");
+        EventUtils.synthesizeKey(" ");
+      });
+      info("Waiting for load.");
+      await loaded;
+      ok(true, "Page loaded after Reload button pressed");
+    }
+  );
 });
 
 // Test activation of the Sidebars button from the keyboard.
 // This is a toolbarbutton with a command handler.
 add_task(async function testSidebarsButtonPress() {
-  CustomizableUI.addWidgetToArea("sidebar-button", "nav-bar");
+  const { SidebarController } = window;
+  let sidebarRevampEnabled = Services.prefs.getBoolPref(
+    "sidebar.revamp",
+    false
+  );
+  let sidebar, sidebarBox;
+  if (!sidebarRevampEnabled) {
+    CustomizableUI.addWidgetToArea("sidebar-button", "nav-bar");
+  } else {
+    // Expanded is only available with vertical tabs enabled
+    await SpecialPowers.pushPrefEnv({
+      set: [["sidebar.verticalTabs", true]],
+    });
+    await SidebarController.initializeUIState({ launcherExpanded: false });
+  }
   let button = document.getElementById("sidebar-button");
   ok(!button.checked, "Sidebars button not checked at start of test");
-  let sidebarBox = document.getElementById("sidebar-box");
-  ok(sidebarBox.hidden, "Sidebar hidden at start of test");
-  forceFocus(button);
-  EventUtils.synthesizeKey(" ");
-  await TestUtils.waitForCondition(() => button.checked);
-  ok(true, "Sidebars button checked after press");
-  ok(!sidebarBox.hidden, "Sidebar visible after press");
+  if (!sidebarRevampEnabled) {
+    sidebarBox = document.getElementById("sidebar-box");
+    ok(sidebarBox.hidden, "Sidebar hidden at start of test");
+  } else {
+    sidebar = document.querySelector("sidebar-main");
+    ok(!sidebar.expanded, "Sidebar collapsed at start of test");
+  }
+  await focusAndActivateElement(button, () => EventUtils.synthesizeKey(" "));
+  if (!sidebarRevampEnabled) {
+    await TestUtils.waitForCondition(() => button.checked);
+    ok(true, "Sidebars button checked after press");
+    ok(!sidebarBox.hidden, "Sidebar visible after press");
+  } else {
+    await TestUtils.waitForCondition(
+      () => sidebar.expanded,
+      "Sidebar expanded after press"
+    );
+    ok(sidebar.expanded, "Sidebar expanded after press");
+  }
   // Make sure the sidebar is fully loaded before we hide it.
   // Otherwise, the unload event might call JS which isn't loaded yet.
   // We can't use BrowserTestUtils.browserLoaded because it fails on non-tab
   // docs. Instead, wait for something in the JS script.
-  let sidebarWin = document.getElementById("sidebar").contentWindow;
-  await TestUtils.waitForCondition(() => sidebarWin.PlacesUIUtils);
-  forceFocus(button);
-  EventUtils.synthesizeKey(" ");
-  await TestUtils.waitForCondition(() => !button.checked);
-  ok(true, "Sidebars button not checked after press");
-  ok(sidebarBox.hidden, "Sidebar hidden after press");
-  CustomizableUI.removeWidgetFromArea("sidebar-button");
+  if (!sidebarRevampEnabled) {
+    let sidebarWin = document.getElementById("sidebar").contentWindow;
+    await TestUtils.waitForCondition(() => sidebarWin.PlacesUIUtils);
+  } else {
+    await sidebar.updateComplete;
+  }
+  await focusAndActivateElement(button, () => EventUtils.synthesizeKey(" "));
+  if (!sidebarRevampEnabled) {
+    await TestUtils.waitForCondition(() => !button.checked);
+    ok(true, "Sidebars button not checked after press");
+    ok(sidebarBox.hidden, "Sidebar hidden after press");
+    CustomizableUI.removeWidgetFromArea("sidebar-button");
+  } else {
+    await TestUtils.waitForCondition(
+      () => !sidebar.expanded,
+      "Sidebar not expanded after press"
+    );
+    ok(!sidebar.expanded, "Sidebar not expanded after press");
+    await SpecialPowers.popPrefEnv();
+  }
 });
 
 // Test activation of the Bookmark this page button from the keyboard.
 // This is an image with a click handler on its parent and no command handler,
 // but the toolbar keyboard navigation code should handle keyboard activation.
 add_task(async function testBookmarkButtonPress() {
-  await BrowserTestUtils.withNewTab("https://example.com", async function(
-    aBrowser
-  ) {
+  await BrowserTestUtils.withNewTab("https://example.com", async function () {
     let button = document.getElementById("star-button-box");
-    forceFocus(button);
     StarUI._createPanelIfNeeded();
     let panel = document.getElementById("editBookmarkPanel");
     let focused = BrowserTestUtils.waitForEvent(panel, "focus", true);
@@ -225,7 +266,7 @@ add_task(async function testBookmarkButtonPress() {
     await TestUtils.waitForCondition(
       () => BookmarkingUI.status != BookmarkingUI.STATUS_UPDATING
     );
-    EventUtils.synthesizeKey(" ");
+    await focusAndActivateElement(button, () => EventUtils.synthesizeKey(" "));
     await focused;
     ok(true, "Focus inside edit bookmark panel after Bookmark button pressed");
     let hidden = BrowserTestUtils.waitForEvent(panel, "popuphidden");
@@ -243,10 +284,9 @@ add_task(async function testBookmarksmenuButtonPress() {
     CustomizableUI.AREA_NAVBAR
   );
   let button = document.getElementById("bookmarks-menu-button");
-  forceFocus(button);
   let menu = document.getElementById("BMB_bookmarksPopup");
   let shown = BrowserTestUtils.waitForEvent(menu, "popupshown");
-  EventUtils.synthesizeKey(" ");
+  await focusAndActivateElement(button, () => EventUtils.synthesizeKey(" "));
   await shown;
   ok(true, "Bookmarks Menu shown after toolbar button pressed");
   let hidden = BrowserTestUtils.waitForEvent(menu, "popuphidden");
@@ -264,10 +304,9 @@ add_task(async function testOverflowButtonPress() {
     CustomizableUI.AREA_FIXED_OVERFLOW_PANEL
   );
   let button = document.getElementById("nav-bar-overflow-button");
-  forceFocus(button);
   let view = document.getElementById("widget-overflow-mainView");
   let focused = BrowserTestUtils.waitForEvent(view, "focus", true);
-  EventUtils.synthesizeKey(" ");
+  await focusAndActivateElement(button, () => EventUtils.synthesizeKey(" "));
   await focused;
   ok(true, "Focus inside overflow menu after toolbar button pressed");
   let panel = document.getElementById("widget-overflow");
@@ -282,10 +321,9 @@ add_task(async function testOverflowButtonPress() {
 add_task(async function testDownloadsButtonPress() {
   DownloadsButton.unhide();
   let button = document.getElementById("downloads-button");
-  forceFocus(button);
   let panel = document.getElementById("downloadsPanel");
   let focused = BrowserTestUtils.waitForEvent(panel, "focus", true);
-  EventUtils.synthesizeKey(" ");
+  await focusAndActivateElement(button, () => EventUtils.synthesizeKey(" "));
   await focused;
   ok(true, "Focus inside Downloads panel after toolbar button pressed");
   let hidden = BrowserTestUtils.waitForEvent(panel, "popuphidden");
@@ -293,33 +331,3 @@ add_task(async function testDownloadsButtonPress() {
   await hidden;
   DownloadsButton.hide();
 });
-
-// Test activation of the Save to Pocket button from the keyboard.
-// This is a customizable widget button which shows an popup panel
-// with a browser element to embed the pocket UI into it.
-// The Pocket panel should appear and focus should move inside it.
-add_task(async function testPocketButtonPress() {
-  await BrowserTestUtils.withNewTab("https://example.com", async function(
-    aBrowser
-  ) {
-    let button = document.getElementById("save-to-pocket-button");
-    forceFocus(button);
-    // The panel is created on the fly, so we can't simply wait for focus
-    // inside it.
-    let showing = BrowserTestUtils.waitForEvent(document, "popupshowing", true);
-    EventUtils.synthesizeKey(" ");
-    let event = await showing;
-    let panel = event.target;
-    is(panel.id, "customizationui-widget-panel");
-    let focused = BrowserTestUtils.waitForEvent(panel, "focus", true);
-    await focused;
-    is(
-      document.activeElement.tagName,
-      "browser",
-      "Focus inside Pocket panel after Bookmark button pressed"
-    );
-    let hidden = BrowserTestUtils.waitForEvent(panel, "popuphidden");
-    EventUtils.synthesizeKey("KEY_Escape");
-    await hidden;
-  });
-});
