@@ -1,20 +1,5 @@
-var { XPCOMUtils } = ChromeUtils.import(
-  "resource://gre/modules/XPCOMUtils.jsm"
-);
-
-ChromeUtils.defineModuleGetter(
-  this,
-  "PlacesUtils",
-  "resource://gre/modules/PlacesUtils.jsm"
-);
-ChromeUtils.defineModuleGetter(
-  this,
-  "PromiseUtils",
-  "resource://gre/modules/PromiseUtils.jsm"
-);
-
-XPCOMUtils.defineLazyServiceGetters(this, {
-  uuidGen: ["@mozilla.org/uuid-generator;1", "nsIUUIDGenerator"],
+ChromeUtils.defineESModuleGetters(this, {
+  PlacesUtils: "resource://gre/modules/PlacesUtils.sys.mjs",
 });
 
 // Various tests in this directory may define gTestBrowser, to use as the
@@ -68,7 +53,7 @@ function promiseTabLoadEvent(tab, url) {
   let loaded = BrowserTestUtils.browserLoaded(tab.linkedBrowser, false, handle);
 
   if (url) {
-    BrowserTestUtils.loadURI(tab.linkedBrowser, url);
+    BrowserTestUtils.startLoadingURIString(tab.linkedBrowser, url);
   }
 
   return loaded;
@@ -78,7 +63,7 @@ function waitForCondition(condition, nextTest, errorMsg, aTries, aWait) {
   let tries = 0;
   let maxTries = aTries || 100; // 100 tries
   let maxWait = aWait || 100; // 100 msec x 100 tries = ten seconds
-  let interval = setInterval(function() {
+  let interval = setInterval(function () {
     if (tries >= maxTries) {
       ok(false, errorMsg);
       moveOn();
@@ -95,7 +80,7 @@ function waitForCondition(condition, nextTest, errorMsg, aTries, aWait) {
     }
     tries++;
   }, maxWait);
-  let moveOn = function() {
+  let moveOn = function () {
     clearInterval(interval);
     nextTest();
   };
@@ -117,7 +102,7 @@ function promiseForCondition(aConditionFn, aMessage, aTries, aWait) {
 // Returns a promise for nsIObjectLoadingContent props data.
 function promiseForPluginInfo(aId, aBrowser) {
   let browser = aBrowser || gTestBrowser;
-  return SpecialPowers.spawn(browser, [aId], async function(contentId) {
+  return SpecialPowers.spawn(browser, [aId], async function (contentId) {
     let plugin = content.document.getElementById(contentId);
     if (!(plugin instanceof Ci.nsIObjectLoadingContent)) {
       throw new Error("no plugin found");
@@ -162,14 +147,13 @@ function promiseWaitForFocus(aWindow) {
  * @return Promise
  */
 function waitForNotificationBar(notificationID, browser, callback) {
-  return new Promise((resolve, reject) => {
+  return new Promise(resolve => {
     let notification;
     let notificationBox = gBrowser.getNotificationBox(browser);
     waitForCondition(
       () =>
-        (notification = notificationBox.getNotificationWithValue(
-          notificationID
-        )),
+        (notification =
+          notificationBox.getNotificationWithValue(notificationID)),
       () => {
         ok(
           notification,
@@ -205,7 +189,7 @@ function waitForNotificationShown(notification, callback) {
   }
   PopupNotifications.panel.addEventListener(
     "popupshown",
-    function(e) {
+    function () {
       callback();
     },
     { once: true }
