@@ -11,10 +11,6 @@ function test() {
   setup();
 }
 
-const FALLBACK_ANCHOR = gURLBar.searchButton
-  ? "urlbar-search-button"
-  : "identity-icon";
-
 var tests = [
   // Test that popupnotifications are anchored to the fallback anchor on
   // about:blank, where anchor icons are hidden.
@@ -28,7 +24,7 @@ var tests = [
       this.notifyObj.anchorID = "geo-notification-icon";
       this.notification = showNotification(this.notifyObj);
     },
-    onShown(popup) {
+    async onShown(popup) {
       checkPopup(popup, this.notifyObj);
       is(
         document.getElementById("geo-notification-icon").getBoundingClientRect()
@@ -36,14 +32,10 @@ var tests = [
         0,
         "geo anchor shouldn't be visible"
       );
-      is(
-        popup.anchorNode.id,
-        FALLBACK_ANCHOR,
-        "notification anchored to fallback anchor"
-      );
+      assertFallbackAnchorNode(popup.anchorNode);
       dismissNotification(popup);
     },
-    onHidden(popup) {
+    onHidden() {
       this.notification.remove();
       gBrowser.removeTab(gBrowser.selectedTab);
       gBrowser.selectedTab = this.oldSelectedTab;
@@ -57,6 +49,7 @@ var tests = [
       this.oldSelectedTab = gBrowser.selectedTab;
       await BrowserTestUtils.openNewForegroundTab(
         gBrowser,
+        // eslint-disable-next-line @microsoft/sdl/no-insecure-url
         "http://example.com/"
       );
 
@@ -77,14 +70,10 @@ var tests = [
         0,
         "geo anchor shouldn't be visible"
       );
-      is(
-        popup.anchorNode.id,
-        FALLBACK_ANCHOR,
-        "notification anchored to fallback anchor"
-      );
+      assertFallbackAnchorNode(popup.anchorNode);
       dismissNotification(popup);
     },
-    onHidden(popup) {
+    onHidden() {
       this.notification.remove();
       gBrowser.removeTab(gBrowser.selectedTab);
       gBrowser.selectedTab = this.oldSelectedTab;
@@ -113,6 +102,7 @@ var tests = [
         "geo anchor shouldn't be visible"
       );
 
+      // eslint-disable-next-line @microsoft/sdl/no-insecure-url
       await promiseTabLoadEvent(gBrowser.selectedTab, "http://example.com/");
 
       isnot(
@@ -133,7 +123,7 @@ var tests = [
       checkPopup(popup, this.notifyObj);
       dismissNotification(popup);
     },
-    onHidden(popup) {
+    onHidden() {
       this.notification.remove();
       gBrowser.removeTab(gBrowser.selectedTab);
       gBrowser.selectedTab = this.oldSelectedTab;
@@ -177,11 +167,7 @@ var tests = [
         EventUtils.synthesizeKey("KEY_Tab");
         await shown;
 
-        is(
-          PopupNotifications.panel.anchorNode.id,
-          FALLBACK_ANCHOR,
-          "notification anchored to fallback anchor"
-        );
+        assertFallbackAnchorNode(PopupNotifications.panel.anchorNode);
 
         // Moving focus to the location bar should hide the notification again.
         hidden = waitForNotificationPanelHidden();
@@ -259,6 +245,7 @@ var tests = [
       this.oldSelectedTab = gBrowser.selectedTab;
       await BrowserTestUtils.openNewForegroundTab(
         gBrowser,
+        // eslint-disable-next-line @microsoft/sdl/no-insecure-url
         "http://example.com/"
       );
       await hidden;
@@ -283,3 +270,15 @@ var tests = [
     },
   },
 ];
+
+function assertFallbackAnchorNode(anchorNode) {
+  if (anchorNode.classList.contains("searchmode-switcher-icon")) {
+    Assert.ok(true, "The anchor is searchmode-switcher-icon");
+  } else if (anchorNode.id == "identity-icon") {
+    Assert.ok(true, "The anchor is identity-icon");
+  } else if (anchorNode.id == "remote-control-icon") {
+    Assert.ok(true, "The anchor is remote-control-icon");
+  } else {
+    Assert.ok(false, "The anchor is unexpected element");
+  }
+}
