@@ -9,16 +9,18 @@ add_task(async function test_fetch() {
   await BrowserTestUtils.withNewTab(
     { gBrowser, url: URL },
     async function (newTabBrowser) {
+      const win = newTabBrowser.ownerGlobal;
+      await openProtectionsPanel(false, win);
       let contentBlockingEvent = waitForContentBlockingEvent();
       await SpecialPowers.spawn(newTabBrowser, [], async function () {
         await content.wrappedJSObject
           .test_fetch()
-          .then(response => Assert.ok(false, "should have denied the request"))
+          .then(() => Assert.ok(false, "should have denied the request"))
           .catch(e => Assert.ok(true, `Caught exception: ${e}`));
       });
       await contentBlockingEvent;
 
-      let gProtectionsHandler = newTabBrowser.ownerGlobal.gProtectionsHandler;
+      const gProtectionsHandler = win.gProtectionsHandler;
       ok(gProtectionsHandler, "got CB object");
 
       ok(
@@ -30,8 +32,10 @@ add_task(async function test_fetch() {
         "icon box is active"
       );
       is(
-        gProtectionsHandler._trackingProtectionIconTooltipLabel.textContent,
-        gNavigatorBundle.getString("trackingProtection.icon.activeTooltip2"),
+        gProtectionsHandler._trackingProtectionIconTooltipLabel.getAttribute(
+          "data-l10n-id"
+        ),
+        "tracking-protection-icon-active",
         "correct tooltip"
       );
     }
