@@ -3,10 +3,11 @@
  */
 
 const PREF = "privacy.trackingprotection.enabled";
-const DTSCBN_PREF = "dom.testing.sync-content-blocking-notifications";
 const BENIGN_PAGE =
+  // eslint-disable-next-line @microsoft/sdl/no-insecure-url
   "http://tracking.example.org/browser/browser/base/content/test/protectionsUI/benignPage.html";
 const TRACKING_PAGE =
+  // eslint-disable-next-line @microsoft/sdl/no-insecure-url
   "http://tracking.example.org/browser/browser/base/content/test/protectionsUI/trackingPage.html";
 
 /**
@@ -14,11 +15,10 @@ const TRACKING_PAGE =
  */
 var oldCanRecord = Services.telemetry.canRecordExtended;
 Services.telemetry.canRecordExtended = true;
-registerCleanupFunction(function() {
+registerCleanupFunction(function () {
   UrlClassifierTestUtils.cleanupTestTrackers();
   Services.telemetry.canRecordExtended = oldCanRecord;
   Services.prefs.clearUserPref(PREF);
-  Services.prefs.clearUserPref(DTSCBN_PREF);
 });
 
 function getShieldHistogram() {
@@ -29,9 +29,8 @@ function getShieldCounts() {
   return getShieldHistogram().snapshot().values;
 }
 
-add_setup(async function() {
+add_setup(async function () {
   await UrlClassifierTestUtils.addTestTrackers();
-  Services.prefs.setBoolPref(DTSCBN_PREF, true);
 
   let TrackingProtection =
     gBrowser.ownerGlobal.gProtectionsHandler.blockers.TrackingProtection;
