@@ -1,7 +1,3 @@
-var { XPCOMUtils } = ChromeUtils.import(
-  "resource://gre/modules/XPCOMUtils.jsm"
-);
-
 const REFERRER_URL_BASE = "/browser/browser/base/content/test/referrer/";
 const REFERRER_POLICYSERVER_URL =
   "test1.example.com" + REFERRER_URL_BASE + "file_referrer_policyserver.sjs";
@@ -25,12 +21,16 @@ var _referrerTests = [
   // 1. Normal cases - no referrer policy, no special attributes.
   //    We expect a full referrer normally, and no referrer on downgrade.
   {
+    // eslint-disable-next-line @microsoft/sdl/no-insecure-url
     fromScheme: "http://",
+    // eslint-disable-next-line @microsoft/sdl/no-insecure-url
     toScheme: "http://",
+    // eslint-disable-next-line @microsoft/sdl/no-insecure-url
     result: "http://test1.example.com/browser", // full referrer
   },
   {
     fromScheme: "https://",
+    // eslint-disable-next-line @microsoft/sdl/no-insecure-url
     toScheme: "http://",
     result: "", // no referrer when downgrade
   },
@@ -38,12 +38,14 @@ var _referrerTests = [
   //    even on downgrade.  But rel=noreferrer trumps this.
   {
     fromScheme: "https://",
+    // eslint-disable-next-line @microsoft/sdl/no-insecure-url
     toScheme: "http://",
     policy: "origin",
     result: "https://test1.example.com/", // origin, even on downgrade
   },
   {
     fromScheme: "https://",
+    // eslint-disable-next-line @microsoft/sdl/no-insecure-url
     toScheme: "http://",
     policy: "origin",
     rel: "noreferrer",
@@ -60,6 +62,7 @@ var _referrerTests = [
     result: "", // same origin https://test1.example.com/browser
   },
   {
+    // eslint-disable-next-line @microsoft/sdl/no-insecure-url
     fromScheme: "http://",
     toScheme: "https://",
     policy: "no-referrer",
@@ -134,7 +137,7 @@ function clickTheLink(aWindow, aLinkId, aOptions) {
  * @resolves When extacted, with the text of the (trimmed) referrer.
  */
 function referrerResultExtracted(aWindow) {
-  return SpecialPowers.spawn(aWindow.gBrowser.selectedBrowser, [], function() {
+  return SpecialPowers.spawn(aWindow.gBrowser.selectedBrowser, [], function () {
     return content.document.getElementById("testdiv").textContent;
   });
 }
@@ -146,7 +149,7 @@ function referrerResultExtracted(aWindow) {
  * @resolves When the window is loaded.
  */
 function delayedStartupFinished(aWindow) {
-  return new Promise(function(resolve) {
+  return new Promise(function (resolve) {
     Services.obs.addObserver(function observer(aSubject, aTopic) {
       if (aWindow == aSubject) {
         Services.obs.removeObserver(observer, aTopic);
@@ -162,7 +165,7 @@ function delayedStartupFinished(aWindow) {
  * @return {Promise}
  * @resolves With the tab once it's loaded.
  */
-function someTabLoaded(aWindow) {
+function someTabLoaded() {
   return BrowserTestUtils.waitForNewTab(gTestWindow.gBrowser, null, true);
 }
 
@@ -254,7 +257,7 @@ function checkReferrerAndStartNextTest(
   aStartTestCase,
   aParams = {}
 ) {
-  referrerResultExtracted(aNewWindow || gTestWindow).then(function(result) {
+  referrerResultExtracted(aNewWindow || gTestWindow).then(function (result) {
     // Compare the actual result against the expected one.
     let test = getReferrerTest(aTestNumber);
     let desc = getReferrerTestDescription(aTestNumber);
@@ -269,13 +272,13 @@ function checkReferrerAndStartNextTest(
     // Move on to the next test.  Or finish if we're done.
     var nextTestNumber = aTestNumber + 1;
     if (getReferrerTest(nextTestNumber)) {
-      referrerTestCaseLoaded(nextTestNumber, aParams).then(function() {
+      referrerTestCaseLoaded(nextTestNumber, aParams).then(function () {
         aStartTestCase(nextTestNumber);
       });
     } else if (rounds == 0) {
       nextTestNumber = 0;
       rounds = 1;
-      referrerTestCaseLoaded(nextTestNumber, aParams).then(function() {
+      referrerTestCaseLoaded(nextTestNumber, aParams).then(function () {
         aStartTestCase(nextTestNumber);
       });
     } else {
@@ -295,13 +298,13 @@ function startReferrerTest(aStartTestCase, params = {}) {
 
   // Open the window where we'll load the source URLs.
   gTestWindow = openDialog(location, "", "chrome,all,dialog=no", "about:blank");
-  registerCleanupFunction(function() {
+  registerCleanupFunction(function () {
     gTestWindow && gTestWindow.close();
   });
 
   // Load and start the first test.
-  delayedStartupFinished(gTestWindow).then(function() {
-    referrerTestCaseLoaded(0, params).then(function() {
+  delayedStartupFinished(gTestWindow).then(function () {
+    referrerTestCaseLoaded(0, params).then(function () {
       aStartTestCase(0);
     });
   });
