@@ -22,9 +22,6 @@ ChromeUtils.defineESModuleGetters(this, {
   Timer: "resource://gre/modules/Timer.sys.mjs",
 });
 
-const kMsecPerMin = 60 * 1000;
-const kUsecPerMin = 60 * 1000000;
-
 /**
  * Ensures that the specified URIs are either cleared or not.
  *
@@ -53,6 +50,10 @@ add_setup(async function () {
     await blankSlate();
     await PlacesTestUtils.promiseAsyncUpdates();
   });
+
+  await SpecialPowers.pushPrefEnv({
+    set: [["privacy.sanitize.useOldClearHistoryDialog", true]],
+  });
 });
 
 /**
@@ -578,7 +579,7 @@ DialogHelper.prototype = {
    */
   _checkAllCheckboxesCustom(check) {
     var cb = this.win.document.querySelectorAll("checkbox[preference]");
-    ok(cb.length > 1, "found checkboxes for preferences");
+    Assert.greater(cb.length, 1, "found checkboxes for preferences");
     for (var i = 0; i < cb.length; ++i) {
       var pref = this.win.Preferences.get(cb[i].getAttribute("preference"));
       if (!!pref.value ^ check) {
@@ -690,10 +691,6 @@ DialogHelper.prototype = {
   },
 };
 
-function promiseSanitizationComplete() {
-  return TestUtils.topicObserved("sanitizer-sanitization-complete");
-}
-
 /**
  * Adds a download to history.
  *
@@ -747,21 +744,6 @@ async function formNameExists(name) {
   return !!(await FormHistory.count({ fieldname: name }));
 }
 
-/**
- * Removes all history visits, downloads, and form entries.
- */
-async function blankSlate() {
-  let publicList = await Downloads.getList(Downloads.PUBLIC);
-  let downloads = await publicList.getAll();
-  for (let download of downloads) {
-    await publicList.remove(download);
-    await download.finalize(true);
-  }
-
-  await FormHistory.update({ op: "remove" });
-  await PlacesUtils.history.clear();
-}
-
 /**
  * Ensures that the given pref is the expected value.
  *
