@@ -5,14 +5,14 @@
  * during the initial browser startup - but it would be hard to do with a mochitest. */
 
 registerCleanupFunction(() => {
-  SidebarUI.hide();
+  SidebarController.hide();
 });
 
 function failIfSidebarFocusedFires() {
   ok(false, "This event shouldn't have fired");
 }
 
-add_task(function setup() {
+add_setup(function () {
   CustomizableUI.addWidgetToArea("sidebar-button", "nav-bar");
   registerCleanupFunction(() =>
     CustomizableUI.removeWidgetFromArea("sidebar-button")
@@ -26,7 +26,7 @@ add_task(async function testAdoptedTwoWindows() {
   info("Ensure that sidebar state is adopted only from the opener");
 
   let win1 = await BrowserTestUtils.openNewBrowserWindow();
-  await win1.SidebarUI.show("viewBookmarksSidebar");
+  await win1.SidebarController.show("viewBookmarksSidebar");
   await BrowserTestUtils.closeWindow(win1);
 
   let win2 = await BrowserTestUtils.openNewBrowserWindow();
@@ -34,7 +34,7 @@ add_task(async function testAdoptedTwoWindows() {
     !win2.document.getElementById("sidebar-button").hasAttribute("checked"),
     "Sidebar button isn't checked"
   );
-  ok(!win2.SidebarUI.isOpen, "Sidebar is closed");
+  ok(!win2.SidebarController.isOpen, "Sidebar is closed");
   await BrowserTestUtils.closeWindow(win2);
 });
 
@@ -46,7 +46,7 @@ add_task(async function testEventsReceivedInMainWindow() {
   let initialShown = BrowserTestUtils.waitForEvent(window, "SidebarShown");
   let initialFocus = BrowserTestUtils.waitForEvent(window, "SidebarFocused");
 
-  await SidebarUI.show("viewBookmarksSidebar");
+  await SidebarController.show("viewBookmarksSidebar");
   await initialShown;
   await initialFocus;
 
@@ -63,7 +63,7 @@ add_task(async function testEventReceivedInNewWindow() {
 
   let adoptedShown = BrowserTestUtils.waitForEvent(win, "SidebarShown");
   win.addEventListener("SidebarFocused", failIfSidebarFocusedFires);
-  registerCleanupFunction(async function() {
+  registerCleanupFunction(async function () {
     win.removeEventListener("SidebarFocused", failIfSidebarFocusedFires);
     await BrowserTestUtils.closeWindow(win);
   });
