@@ -119,6 +119,17 @@ var gExceptionPaths = [
   "resource://builtin-addons/newtab/",
   "resource://newtab/",
   "chrome://newtab/",
+
+  // UniFFI test files.
+  "moz-src:///toolkit/components/uniffi-bindgen-gecko-js/tests/generated/",
+
+  // Used for Market suggestions on the urlbar. This is specified from Remote
+  // Settings.
+  "chrome://browser/skin/illustrations/market-opt-in.svg",
+
+  // Used for Yelp realtime suggestions on the urlbar. This is specified from
+  // Remote Settings.
+  "chrome://browser/skin/illustrations/yelpRealtime-opt-in.svg",
 ];
 
 // These are not part of the omni.ja file, so we find them only when running
@@ -171,9 +182,6 @@ var allowlist = [
     isFromDevTools: true,
   },
 
-  // used by devtools/client/memory/index.xhtml
-  { file: "chrome://global/content/third_party/d3/d3.js" },
-
   // SpiderMonkey parser API, currently unused in browser/ and toolkit/
   { file: "resource://gre/modules/reflect.sys.mjs" },
 
@@ -192,7 +200,6 @@ var allowlist = [
   { file: "resource://gre/greprefs.js" },
 
   // layout/mathml/nsMathMLChar.cpp
-  { file: "resource://gre/res/fonts/mathfontSTIXGeneral.properties" },
   { file: "resource://gre/res/fonts/mathfontUnicode.properties" },
 
   // toolkit/mozapps/extensions/AddonContentPolicy.cpp
@@ -243,18 +250,15 @@ var allowlist = [
   { file: "resource://pdf.js/web/debugger.mjs" },
   { file: "resource://pdf.js/web/debugger.css" },
 
+  // File from the ipp-activator add-on
+  { file: "resource://builtin-addons/ipp-activator/breakages/tab.json" },
+
   // Starting from here, files in the allowlist are bugs that need fixing.
   // Bug 1339424 (wontfix?)
   {
     file: "chrome://browser/locale/taskbar.properties",
     platforms: ["linux", "macosx"],
   },
-  // Bug 1344267
-  { file: "chrome://remote/content/marionette/test_dialog.properties" },
-  { file: "chrome://remote/content/marionette/test_dialog.xhtml" },
-  { file: "chrome://remote/content/marionette/test_menupopup.xhtml" },
-  { file: "chrome://remote/content/marionette/test_no_xul.xhtml" },
-  { file: "chrome://remote/content/marionette/test.xhtml" },
   // Bug 1348559
   { file: "chrome://pippki/content/resetpassword.xhtml" },
   // Bug 1337345
@@ -316,12 +320,6 @@ var allowlist = [
   // toolkit/xre/MacRunFromDmgUtils.mm
   { file: "resource://gre/localization/en-US/toolkit/global/run-from-dmg.ftl" },
 
-  // Referenced by screenshots extension
-  { file: "chrome://browser/content/screenshots/cancel.svg" },
-  { file: "chrome://browser/content/screenshots/copy.svg" },
-  { file: "chrome://browser/content/screenshots/download.svg" },
-  { file: "chrome://browser/content/screenshots/download-white.svg" },
-
   // Referenced programmatically
   { file: "chrome://browser/content/backup/BackupManifest.1.schema.json" },
   { file: "chrome://browser/content/backup/ArchiveJSONBlock.1.schema.json" },
@@ -331,8 +329,17 @@ var allowlist = [
     file: "resource://gre/localization/en-US/netwerk/necko.ftl",
   },
 
+  // dom/xslt/xslt/txMozillaXSLTProcessor.cpp
+  { file: "resource://gre/localization/en-US/dom/xslt.ftl" },
+
   // A QA and dev debug tool.
   { file: "chrome://browser/content/places/interactionsViewer.html" },
+
+  // Bug 1984409: We're doing backups to cloud-synced locations first. We'll do local backups eventually,
+  // and this file will be needed for that.
+  {
+    file: "resource://app/modules/backup/CookiesBackupResource.sys.mjs",
+  },
 ];
 
 if (AppConstants.NIGHTLY_BUILD) {
@@ -651,7 +658,7 @@ function parseCodeFile(fileUri) {
       );
 
       if (!urls) {
-        urls = line.match(/["']moz-src:\/\/\/[^"']+["']/g);
+        urls = line.match(/["']moz-src:\/\/[^"']+["']/g);
       }
 
       if (!urls) {
@@ -883,19 +890,18 @@ add_task(async function checkAllTheFiles() {
   const libxul = await IOUtils.read(PathUtils.xulLibraryPath);
   findChromeUrlsFromArray(libxul, "chrome://");
   findChromeUrlsFromArray(libxul, "resource://");
-  findChromeUrlsFromArray(libxul, "moz-src:///");
+  findChromeUrlsFromArray(libxul, "moz-src://");
   // Handle NS_LITERAL_STRING.
   let uint16 = new Uint16Array(libxul.buffer);
   findChromeUrlsFromArray(uint16, "chrome://");
   findChromeUrlsFromArray(uint16, "resource://");
-  findChromeUrlsFromArray(uint16, "moz-src:///");
+  findChromeUrlsFromArray(uint16, "moz-src://");
 
   const kCodeExtensions = [
     ".xml",
     ".xsl",
     ".mjs",
     ".js",
-    ".jsm",
     ".json",
     ".html",
     ".xhtml",
@@ -1021,7 +1027,8 @@ add_task(async function checkAllTheFiles() {
         if (isDevtools) {
           if (
             ref.startsWith("resource://app/components/") ||
-            (file.startsWith("chrome://") && ref.startsWith("resource://"))
+            (file.startsWith("chrome://") &&
+              (ref.startsWith("resource://") || ref.startsWith("moz-src://")))
           ) {
             return false;
           }
