@@ -85,6 +85,14 @@ if (!Services.prefs.getBoolPref("dom.viewTransitions.enabled")) {
   });
 }
 
+if (!Services.prefs.getBoolPref("mathml.math_shift.enabled")) {
+  ignoreList.push({
+    sourceName: /\bmathml\.css$/i,
+    errorMessage: /Unknown property.*math-shift/i,
+    isFromDevTools: false,
+  });
+}
+
 let propNameAllowlist = [
   // These custom properties are retrieved directly from CSSOM
   // in videocontrols.xml to get pre-defined style instead of computed
@@ -175,8 +183,13 @@ let propNameAllowlist = [
   /* Allow design tokens in devtools without all variables being used there */
   { sourceName: /\/design-system\/tokens-.*\.css$/, isFromDevTools: true },
 
-  // Bug 1908535 to refactor form components to use this token
-  { propName: "--input-space-block", isFromDevTools: false },
+  // Ignore token properties that follow the pattern --color-[name]-[number]
+  // This enables us to provide our full color palette for developers.
+  { propName: /--color-[a-z]+-\d+/, isFromDevTools: false },
+
+  // Design system border radius tokens that are defined but not yet used
+  // these should be removed once they are used in the codebase.
+  { propName: "--border-radius-xsmall", isFromDevTools: false },
 ];
 
 // Add suffix to stylesheets' URI so that we always load them here and
@@ -442,6 +455,13 @@ function shouldIgnorePropSource(item, prop) {
     .some(f => item.sourceName.test(f));
 }
 
+function shouldIgnorePropPattern(item, prop) {
+  if (!item.propName || !(item.propName instanceof RegExp)) {
+    return false;
+  }
+  return item.propName.test(prop);
+}
+
 add_task(async function checkAllTheCSS() {
   // Since we later in this test use Services.console.getMessageArray(),
   // better to not have some messages from previous tests in the array.
@@ -567,7 +587,9 @@ add_task(async function checkAllTheCSS() {
       for (let item of propNameAllowlist) {
         if (
           isDevtools == item.isFromDevTools &&
-          (item.propName == prop || shouldIgnorePropSource(item, prop))
+          (item.propName == prop ||
+            shouldIgnorePropPattern(item, prop) ||
+            shouldIgnorePropSource(item, prop))
         ) {
           item.used = true;
           if (
