@@ -3,7 +3,7 @@
 const PAGE =
   "data:text/html,<html><body>A%20regular,%20everyday,%20normal%20page.";
 
-add_task(async function setup() {
+add_setup(async function () {
   prepareNoDump();
 });
 
@@ -16,13 +16,13 @@ add_task(async function test_without_dump() {
       gBrowser,
       url: PAGE,
     },
-    async function(browser) {
+    async function (browser) {
       let tab = gBrowser.getTabForBrowser(browser);
       await BrowserTestUtils.crashFrame(browser);
 
       let tabClosingPromise = BrowserTestUtils.waitForTabClosing(tab);
 
-      await SpecialPowers.spawn(browser, [], async function() {
+      await SpecialPowers.spawn(browser, [], async function () {
         let doc = content.document;
         Assert.ok(
           !doc.documentElement.classList.contains("crashDumpAvailable"),
