@@ -1,15 +1,5 @@
-const { AppConstants } = ChromeUtils.import(
-  "resource://gre/modules/AppConstants.jsm"
-);
-
-var { XPCOMUtils } = ChromeUtils.import(
-  "resource://gre/modules/XPCOMUtils.jsm"
-);
-var { SitePermissions } = ChromeUtils.import(
-  "resource:///modules/SitePermissions.jsm"
-);
-var { PermissionTestUtils } = ChromeUtils.import(
-  "resource://testing-common/PermissionTestUtils.jsm"
+var { PermissionTestUtils } = ChromeUtils.importESModule(
+  "resource://testing-common/PermissionTestUtils.sys.mjs"
 );
 
 const PREF_PERMISSION_FAKE = "media.navigator.permission.fake";
@@ -21,11 +11,6 @@ const PREF_FOCUS_SOURCE = "media.getusermedia.window.focus_source.enabled";
 const STATE_CAPTURE_ENABLED = Ci.nsIMediaManagerService.STATE_CAPTURE_ENABLED;
 const STATE_CAPTURE_DISABLED = Ci.nsIMediaManagerService.STATE_CAPTURE_DISABLED;
 
-const USING_LEGACY_INDICATOR = Services.prefs.getBoolPref(
-  "privacy.webrtc.legacyGlobalIndicator",
-  false
-);
-
 const ALLOW_SILENCING_NOTIFICATIONS = Services.prefs.getBoolPref(
   "privacy.webrtc.allowSilencingNotifications",
   false
@@ -36,9 +21,19 @@ const SHOW_GLOBAL_MUTE_TOGGLES = Services.prefs.getBoolPref(
   false
 );
 
-const INDICATOR_PATH = USING_LEGACY_INDICATOR
-  ? "chrome://browser/content/webrtcLegacyIndicator.xhtml"
-  : "chrome://browser/content/webrtcIndicator.xhtml";
+const SHOW_ALWAYS_ASK = Services.prefs.getBoolPref(
+  "permissions.media.show_always_ask.enabled",
+  false
+);
+
+let IsIndicatorDisabled =
+  AppConstants.isPlatformAndVersionAtLeast("macosx", 14.0) &&
+  !Services.prefs.getBoolPref(
+    "privacy.webrtc.showIndicatorsOnMacos14AndAbove",
+    false
+  );
+
+const INDICATOR_PATH = "chrome://browser/content/webrtcIndicator.xhtml";
 
 const IS_MAC = AppConstants.platform == "macosx";
 
@@ -71,18 +66,13 @@ function whenDelayedStartupFinished(aWindow) {
 }
 
 function promiseIndicatorWindow() {
-  let startTime = performance.now();
-
-  // We don't show the legacy indicator window on Mac.
-  if (USING_LEGACY_INDICATOR && IS_MAC) {
-    return Promise.resolve();
-  }
+  let startTime = ChromeUtils.now();
 
   return new Promise(resolve => {
     Services.obs.addObserver(function obs(win) {
       win.addEventListener(
         "load",
-        function() {
+        function () {
           if (win.location.href !== INDICATOR_PATH) {
             info("ignoring a window with this url: " + win.location.href);
             return;
@@ -104,7 +94,9 @@ function promiseIndicatorWindow() {
 }
 
 async function assertWebRTCIndicatorStatus(expected) {
-  let ui = ChromeUtils.import("resource:///modules/webrtcUI.jsm", {}).webrtcUI;
+  let ui = ChromeUtils.importESModule(
+    "resource:///modules/webrtcUI.sys.mjs"
+  ).webrtcUI;
   let expectedState = expected ? "visible" : "hidden";
   let msg = "WebRTC indicator " + expectedState;
   if (!expected && ui.showGlobalIndicator) {
@@ -120,7 +112,7 @@ async function assertWebRTCIndicatorStatus(expected) {
   let expectVideo = false,
     expectAudio = false,
     expectScreen = "";
-  if (expected) {
+  if (expected && !IsIndicatorDisabled) {
     if (expected.video) {
       expectVideo = true;
     }
@@ -156,14 +148,10 @@ async function assertWebRTCIndicatorStatus(expected) {
     );
   }
 
-  if (USING_LEGACY_INDICATOR && IS_MAC) {
-    return;
-  }
-
   if (!expected) {
     let win = Services.wm.getMostRecentWindow("Browser:WebRTCGlobalIndicator");
     if (win) {
-      await new Promise((resolve, reject) => {
+      await new Promise(resolve => {
         win.addEventListener("unload", function listener(e) {
           if (e.target == win.document) {
             win.removeEventListener("unload", listener);
@@ -200,11 +188,7 @@ async function assertWebRTCIndicatorStatus(expected) {
       });
     }
 
-    if (
-      !USING_LEGACY_INDICATOR &&
-      expected.screen &&
-      expected.screen.startsWith("Window")
-    ) {
+    if (expected.screen && expected.screen.startsWith("Window")) {
       // These tests were originally written to express window sharing by
       // having expected.screen start with "Window". This meant that the
       // legacy indicator is expected to have the "sharingscreen" attribute
@@ -218,7 +202,7 @@ async function assertWebRTCIndicatorStatus(expected) {
       expected.window = true;
     }
 
-    if (!USING_LEGACY_INDICATOR && !SHOW_GLOBAL_MUTE_TOGGLES) {
+    if (!SHOW_GLOBAL_MUTE_TOGGLES) {
       expected.video = false;
       expected.audio = false;
 
@@ -234,11 +218,7 @@ async function assertWebRTCIndicatorStatus(expected) {
     for (let item of ["video", "audio", "screen", "window", "browserwindow"]) {
       let expectedValue;
 
-      if (USING_LEGACY_INDICATOR) {
-        expectedValue = expected && expected[item] ? "true" : "";
-      } else {
-        expectedValue = expected && expected[item] ? "true" : null;
-      }
+      expectedValue = expected && expected[item] ? "true" : null;
 
       is(
         docElt.getAttribute("sharing" + item),
@@ -333,7 +313,7 @@ function expectObserverCalledOnClose(
       {
         topic: aTopic,
         count: 1,
-        filterFunctionSource: ((subject, topic, data) => {
+        filterFunctionSource: ((subject, topic) => {
           Services.cpmm.sendAsyncMessage("WebRTCTest:ObserverCalled", {
             topic,
           });
@@ -364,24 +344,25 @@ function promiseMessage(
   aCount = 1,
   browser = gBrowser.selectedBrowser
 ) {
-  let startTime = performance.now();
-  let promise = ContentTask.spawn(browser, [aMessage, aCount], async function([
-    expectedMessage,
-    expectedCount,
-  ]) {
-    return new Promise(resolve => {
-      function listenForMessage({ data }) {
-        if (
-          (!expectedMessage || data == expectedMessage) &&
-          --expectedCount == 0
-        ) {
-          content.removeEventListener("message", listenForMessage);
-          resolve(data);
+  let startTime = ChromeUtils.now();
+  let promise = ContentTask.spawn(
+    browser,
+    [aMessage, aCount],
+    async function ([expectedMessage, expectedCount]) {
+      return new Promise(resolve => {
+        function listenForMessage({ data }) {
+          if (
+            (!expectedMessage || data == expectedMessage) &&
+            --expectedCount == 0
+          ) {
+            content.removeEventListener("message", listenForMessage);
+            resolve(data);
+          }
         }
-      }
-      content.addEventListener("message", listenForMessage);
-    });
-  });
+        content.addEventListener("message", listenForMessage);
+      });
+    }
+  );
   if (aAction) {
     aAction();
   }
@@ -396,14 +377,11 @@ function promiseMessage(
 }
 
 function promisePopupNotificationShown(aName, aAction, aWindow = window) {
-  let startTime = performance.now();
+  let startTime = ChromeUtils.now();
   return new Promise(resolve => {
-    // In case the global webrtc indicator has stolen focus (bug 1421724)
-    aWindow.focus();
-
     aWindow.PopupNotifications.panel.addEventListener(
       "popupshown",
-      function() {
+      function () {
         ok(
           !!aWindow.PopupNotifications.getNotification(aName),
           aName + " notification shown"
@@ -450,10 +428,19 @@ const kActionAlways = 1;
 const kActionDeny = 2;
 const kActionNever = 3;
 
-function activateSecondaryAction(aAction) {
+async function activateSecondaryAction(aAction) {
   let notification = PopupNotifications.panel.firstElementChild;
   switch (aAction) {
     case kActionNever:
+      if (notification.notification.secondaryActions.length > 1) {
+        // "Always Block" is the first (and only) item in the menupopup.
+        await Promise.all([
+          BrowserTestUtils.waitForEvent(notification.menupopup, "popupshown"),
+          notification.menubutton.click(),
+        ]);
+        notification.menupopup.querySelector("menuitem").click();
+        return;
+      }
       if (!notification.checkbox.checked) {
         notification.checkbox.click();
       }
@@ -471,7 +458,7 @@ function activateSecondaryAction(aAction) {
 }
 
 async function getMediaCaptureState() {
-  let startTime = performance.now();
+  let startTime = ChromeUtils.now();
 
   function gatherBrowsingContexts(aBrowsingContext) {
     let list = [aBrowsingContext];
@@ -509,7 +496,7 @@ async function getMediaCaptureState() {
   for (let bc of gatherBrowsingContexts(
     gBrowser.selectedBrowser.browsingContext
   )) {
-    let state = await SpecialPowers.spawn(bc, [], async function() {
+    let state = await SpecialPowers.spawn(bc, [], async function () {
       let mediaManagerService = Cc[
         "@mozilla.org/mediaManagerService;1"
       ].getService(Ci.nsIMediaManagerService);
@@ -559,9 +546,9 @@ async function getMediaCaptureState() {
   if (screen != Ci.nsIMediaManagerService.STATE_NOCAPTURE) {
     result.screen = "Screen";
   } else if (window != Ci.nsIMediaManagerService.STATE_NOCAPTURE) {
-    result.screen = "Window";
+    result.window = true;
   } else if (browser != Ci.nsIMediaManagerService.STATE_NOCAPTURE) {
-    result.screen = "Browser";
+    result.browserwindow = true;
   }
 
   ChromeUtils.addProfilerMarker("getMediaCaptureState", {
@@ -693,7 +680,7 @@ async function promiseRequestDevice(
   return SpecialPowers.spawn(
     bc,
     [{ aRequestAudio, aRequestVideo, aType, aBadDevice }],
-    async function(args) {
+    async function (args) {
       let global = content.wrappedJSObject;
       global.requestDevice(
         args.aRequestAudio,
@@ -705,12 +692,12 @@ async function promiseRequestDevice(
   );
 }
 
-async function promiseRequestAudioOutput() {
+async function promiseRequestAudioOutput(options) {
   info("requesting audio output");
   const bc = gBrowser.selectedBrowser;
-  return SpecialPowers.spawn(bc, [], async function() {
+  return SpecialPowers.spawn(bc, [options], async function (opts) {
     const global = content.wrappedJSObject;
-    global.requestAudioOutput();
+    global.requestAudioOutput(Cu.cloneInto(opts, content));
   });
 }
 
@@ -752,7 +739,7 @@ async function stopTracks(
   }
 
   info(`Stopping all ${aKind} tracks`);
-  await SpecialPowers.spawn(frameBC, [aKind], async function(kind) {
+  await SpecialPowers.spawn(frameBC, [aKind], async function (kind) {
     content.wrappedJSObject.stopTracks(kind);
   });
 
@@ -802,7 +789,7 @@ async function closeStream(
   }
 
   info("closing the stream");
-  await SpecialPowers.spawn(frameBC, [], async function() {
+  await SpecialPowers.spawn(frameBC, [], async function () {
     content.wrappedJSObject.closeStream();
   });
 
@@ -861,14 +848,18 @@ function checkDeviceSelectors(aExpectedTypes, aWindow = window) {
   }
   let document = aWindow.document;
 
-  for (let type of ["Microphone", "Camera", "Speaker"]) {
+  let expectedDescribedBy = "webRTC-shareDevices-notification-description";
+  for (let type of ["Camera", "Microphone", "Speaker"]) {
     let selector = document.getElementById(`webRTC-select${type}`);
     if (!aExpectedTypes.includes(type.toLowerCase())) {
       ok(selector.hidden, `${type} selector hidden`);
       continue;
     }
     ok(!selector.hidden, `${type} selector visible`);
-    let selectorList = document.getElementById(`webRTC-select${type}-menulist`);
+    let tagName = type == "Speaker" ? "richlistbox" : "menulist";
+    let selectorList = document.getElementById(
+      `webRTC-select${type}-${tagName}`
+    );
     let label = document.getElementById(
       `webRTC-select${type}-single-device-label`
     );
@@ -877,16 +868,25 @@ function checkDeviceSelectors(aExpectedTypes, aWindow = window) {
     if (selectorList.itemCount == 1) {
       ok(selectorList.hidden, `${type} selector list should be hidden.`);
       ok(!label.hidden, `${type} selector label should not be hidden.`);
+      let itemLabel =
+        tagName == "richlistbox"
+          ? selectorList.selectedItem.firstElementChild.getAttribute("value")
+          : selectorList.selectedItem.getAttribute("label");
       is(
         label.value,
-        selectorList.selectedItem.getAttribute("label"),
+        itemLabel,
         `${type} label should be showing the lone device label.`
       );
+      expectedDescribedBy += ` webRTC-select${type}-icon webRTC-select${type}-single-device-label`;
     } else {
       ok(!selectorList.hidden, `${type} selector list should not be hidden.`);
       ok(label.hidden, `${type} selector label should be hidden.`);
     }
   }
+  let ariaDescribedby =
+    aWindow.PopupNotifications.panel.getAttribute("aria-describedby");
+  is(ariaDescribedby, expectedDescribedBy, "aria-describedby");
+
   let screenSelector = document.getElementById("webRTC-selectWindowOrScreen");
   if (aExpectedTypes.includes("screen")) {
     ok(!screenSelector.hidden, "screen selector visible");
@@ -921,18 +921,28 @@ async function checkSharingUI(
   // First check the icon above the control center (i) icon.
   let permissionBox = doc.getElementById("identity-permission-box");
   let webrtcSharingIcon = doc.getElementById("webrtc-sharing-icon");
-  ok(webrtcSharingIcon.hasAttribute("sharing"), "sharing attribute is set");
+  let expectOn = aExpected.audio || aExpected.video || aExpected.screen;
+  if (expectOn) {
+    ok(webrtcSharingIcon.hasAttribute("sharing"), "sharing attribute is set");
+  } else {
+    ok(
+      !webrtcSharingIcon.hasAttribute("sharing"),
+      "sharing attribute is not set"
+    );
+  }
   let sharing = webrtcSharingIcon.getAttribute("sharing");
-  if (aExpected.screen) {
-    is(sharing, "screen", "showing screen icon in the identity block");
-  } else if (aExpected.video == STATE_CAPTURE_ENABLED) {
-    is(sharing, "camera", "showing camera icon in the identity block");
-  } else if (aExpected.audio == STATE_CAPTURE_ENABLED) {
-    is(sharing, "microphone", "showing mic icon in the identity block");
-  } else if (aExpected.video) {
-    is(sharing, "camera", "showing camera icon in the identity block");
-  } else if (aExpected.audio) {
-    is(sharing, "microphone", "showing mic icon in the identity block");
+  if (!IsIndicatorDisabled) {
+    if (aExpected.screen) {
+      is(sharing, "screen", "showing screen icon in the identity block");
+    } else if (aExpected.video == STATE_CAPTURE_ENABLED) {
+      is(sharing, "camera", "showing camera icon in the identity block");
+    } else if (aExpected.audio == STATE_CAPTURE_ENABLED) {
+      is(sharing, "microphone", "showing mic icon in the identity block");
+    } else if (aExpected.video) {
+      is(sharing, "camera", "showing camera icon in the identity block");
+    } else if (aExpected.audio) {
+      is(sharing, "microphone", "showing mic icon in the identity block");
+    }
   }
 
   let allStreamsPaused = Object.values(aExpected).every(isPaused);
@@ -1008,6 +1018,13 @@ async function checkSharingUI(
         true,
         "should not show " + id + " state label in the permission panel"
       );
+      if (state != SitePermissions.PROMPT || SHOW_ALWAYS_ASK) {
+        isnot(
+          scope,
+          SitePermissions.SCOPE_PERSISTENT,
+          "persistent permission not shown"
+        );
+      }
     } else {
       // This will happen if there are persistent permissions set.
       ok(
@@ -1016,6 +1033,21 @@ async function checkSharingUI(
       );
       is(item.length, 1, "should not show more than 1 " + id + " item");
       is(icon.length, 1, "should not show more than 1 " + id + " icon");
+
+      // Note: To pass, this one needs state and/or scope passed into
+      // checkSharingUI() for values other than ALLOW and SCOPE_TEMPORARY
+      is(
+        stateLabel?.textContent,
+        SitePermissions.getCurrentStateLabel(state, id, scope),
+        "should show correct item label for " + id
+      );
+      if (!SHOW_ALWAYS_ASK) {
+        isnot(
+          state,
+          state == SitePermissions.PROMPT,
+          "always ask permission should be hidden"
+        );
+      }
     }
   }
   aWin.gPermissionPanel._permissionPopup.hidePopup();
@@ -1025,7 +1057,9 @@ async function checkSharingUI(
   );
 
   // Check the global indicators.
-  await assertWebRTCIndicatorStatus(aExpectedGlobal || aExpected);
+  if (expectOn) {
+    await assertWebRTCIndicatorStatus(aExpectedGlobal || aExpected);
+  }
 }
 
 async function checkNotSharing() {
@@ -1066,7 +1100,7 @@ async function promiseReloadFrame(aFrameId, aBrowsingContext) {
   let loadedPromise = BrowserTestUtils.browserLoaded(
     gBrowser.selectedBrowser,
     true,
-    arg => {
+    () => {
       return true;
     }
   );
@@ -1076,7 +1110,7 @@ async function promiseReloadFrame(aFrameId, aBrowsingContext) {
       gBrowser.selectedBrowser.browsingContext,
       aFrameId
     ));
-  await SpecialPowers.spawn(bc, [], async function() {
+  await SpecialPowers.spawn(bc, [], async function () {
     content.location.reload();
   });
   return loadedPromise;
@@ -1086,7 +1120,7 @@ function promiseChangeLocationFrame(aFrameId, aNewLocation) {
   return SpecialPowers.spawn(
     gBrowser.selectedBrowser.browsingContext,
     [{ aFrameId, aNewLocation }],
-    async function(args) {
+    async function (args) {
       let frame = content.wrappedJSObject.document.getElementById(
         args.aFrameId
       );
@@ -1197,7 +1231,7 @@ async function runTests(tests, options = {}) {
   gObserveSubFrames = SpecialPowers.useRemoteSubframes ? options.subFrames : {};
 
   for (let testCase of tests) {
-    let startTime = performance.now();
+    let startTime = ChromeUtils.now();
     info(testCase.desc);
     if (
       !testCase.skipObserverVerification &&
