@@ -1,7 +1,7 @@
 /* Any copyright is dedicated to the Public Domain.
  * http://creativecommons.org/publicdomain/zero/1.0/ */
 
-add_task(async function setup() {
+add_setup(async function () {
   let aboutLoginsTab = await BrowserTestUtils.openNewForegroundTab({
     gBrowser,
     url: "about:logins",
@@ -16,16 +16,19 @@ add_task(async function test_create_login() {
   let browser = gBrowser.selectedBrowser;
   await SpecialPowers.spawn(browser, [], async () => {
     let loginList = Cu.waiveXrays(content.document.querySelector("login-list"));
-    ok(!loginList._selectedGuid, "should not be a selected guid by default");
-    ok(
+    Assert.ok(
+      !loginList._selectedGuid,
+      "should not be a selected guid by default"
+    );
+    Assert.ok(
       content.document.documentElement.classList.contains("no-logins"),
       "Should initially be in no logins view"
     );
-    ok(
+    Assert.ok(
       loginList.classList.contains("no-logins"),
       "login-list should initially be in no logins view"
     );
-    is(
+    Assert.equal(
       loginList._loginGuidsSortedOrder.length,
       0,
       "login list should be empty"
@@ -51,76 +54,96 @@ add_task(async function test_create_login() {
       (_, data) => data == "addLogin"
     );
 
-    await SpecialPowers.spawn(
-      browser,
-      [[originTuple, i]],
-      async ([aOriginTuple, index]) => {
-        let loginList = Cu.waiveXrays(
-          content.document.querySelector("login-list")
-        );
-        let createButton = loginList._createLoginButton;
-        ok(
-          ContentTaskUtils.is_hidden(loginList._blankLoginListItem),
-          "the blank login list item should be hidden initially"
-        );
-        ok(
-          !createButton.disabled,
-          "Create button should not be disabled initially"
-        );
+    await SpecialPowers.spawn(browser, [originTuple], async aOriginTuple => {
+      let loginList = Cu.waiveXrays(
+        content.document.querySelector("login-list")
+      );
+      let createButton = loginList._createLoginButton;
+      Assert.ok(
+        ContentTaskUtils.isHidden(loginList._blankLoginListItem),
+        "the blank login list item should be hidden initially"
+      );
+      Assert.ok(
+        !createButton.disabled,
+        "Create button should not be disabled initially"
+      );
 
-        let loginItem = Cu.waiveXrays(
-          content.document.querySelector("login-item")
-        );
-        let usernameInput = loginItem.shadowRoot.querySelector(
-          "input[name='username']"
-        );
-        usernameInput.placeholder = "dummy placeholder";
+      let loginItem = Cu.waiveXrays(
+        content.document.querySelector("login-item")
+      );
+      let usernameInput = loginItem.shadowRoot.querySelector(
+        "input[name='username']"
+      );
+      usernameInput.placeholder = "dummy placeholder";
 
-        createButton.click();
+      createButton.click();
 
-        ok(
-          ContentTaskUtils.is_visible(loginList._blankLoginListItem),
-          "the blank login list item should be visible after clicking on the create button"
-        );
-        ok(
-          createButton.disabled,
-          "Create button should be disabled after being clicked"
-        );
+      Assert.ok(
+        ContentTaskUtils.isVisible(loginList._blankLoginListItem),
+        "the blank login list item should be visible after clicking on the create button"
+      );
+      Assert.ok(
+        createButton.disabled,
+        "Create button should be disabled after being clicked"
+      );
 
-        let cancelButton = loginItem.shadowRoot.querySelector(".cancel-button");
-        is(
-          ContentTaskUtils.is_hidden(cancelButton),
-          index == 0,
-          "cancel button should be hidden in create mode with no logins saved"
-        );
+      let cancelButton = loginItem.shadowRoot.querySelector(".cancel-button");
+      Assert.ok(
+        ContentTaskUtils.isVisible(cancelButton),
+        "cancel button should be visible in create mode with no logins saved"
+      );
 
-        let originInput = loginItem.shadowRoot.querySelector(
-          "input[name='origin']"
-        );
-        let passwordInput = loginItem.shadowRoot.querySelector(
-          "input[name='password']"
-        );
+      let originInput = loginItem.shadowRoot.querySelector(
+        "input[name='origin']"
+      );
+      let passwordInput = loginItem.shadowRoot.querySelector(
+        "input[name='password']"
+      );
 
-        is(
-          content.document.l10n.getAttributes(usernameInput).id,
-          null,
-          "there should be no placeholder id on the username input in edit mode"
-        );
-        is(
-          usernameInput.placeholder,
-          "",
-          "there should be no placeholder on the username input in edit mode"
-        );
-        originInput.value = aOriginTuple[0];
-        usernameInput.value = "testuser1";
-        passwordInput.value = "testpass1";
+      // Upon clicking create-login-button, the origin input field is automatically focused.
+      Assert.ok(
+        ContentTaskUtils.isVisible(loginItem._originWarning),
+        "The origin warning should be visible"
+      );
 
-        let saveChangesButton = loginItem.shadowRoot.querySelector(
-          ".save-changes-button"
-        );
-        saveChangesButton.click();
-      }
-    );
+      // At this moment, the password input field is not focused so no warning should be displayed.
+      Assert.ok(
+        ContentTaskUtils.isHidden(loginItem._passwordWarning),
+        "The password warning should not be visible if the password input field is not focused"
+      );
+
+      Assert.equal(
+        content.document.l10n.getAttributes(usernameInput).id,
+        null,
+        "there should be no placeholder id on the username input in edit mode"
+      );
+      Assert.equal(
+        usernameInput.placeholder,
+        "",
+        "there should be no placeholder on the username input in edit mode"
+      );
+
+      originInput.value = aOriginTuple[0];
+      usernameInput.value = "testuser1";
+
+      passwordInput.focus();
+      Assert.ok(
+        ContentTaskUtils.isVisible(loginItem._passwordWarning),
+        "The password warning should not visible"
+      );
+      passwordInput.value = "testpass1";
+
+      // Since the password field is focused, the origin warning should not be displayed.
+      Assert.ok(
+        ContentTaskUtils.isHidden(loginItem._originWarning),
+        "The origin warning should not be visible if the origin input field is not focused"
+      );
+
+      let saveChangesButton = loginItem.shadowRoot.querySelector(
+        ".save-changes-button"
+      );
+      saveChangesButton.click();
+    });
 
     info("waiting for login to get added to storage");
     await storageChangedPromised;
@@ -139,22 +162,22 @@ add_task(async function test_create_login() {
           "no-logins"
         );
       }, "waiting for no-logins view to exit");
-      ok(
+      Assert.ok(
         !content.document.documentElement.classList.contains("no-logins"),
         "Should no longer be in no logins view"
       );
       let loginList = Cu.waiveXrays(
         content.document.querySelector("login-list")
       );
-      ok(
+      Assert.ok(
         !loginList.classList.contains("no-logins"),
         "login-list should no longer be in no logins view"
       );
-      ok(
-        ContentTaskUtils.is_hidden(loginList._blankLoginListItem),
+      Assert.ok(
+        ContentTaskUtils.isHidden(loginList._blankLoginListItem),
         "the blank login list item should be hidden after adding new login"
       );
-      ok(
+      Assert.ok(
         !loginList._createLoginButton.disabled,
         "Create button shouldn't be disabled after exiting create login view"
       );
@@ -164,29 +187,29 @@ add_task(async function test_create_login() {
           guid => loginList._logins[guid].login.origin == aOriginTuple[1]
         );
       }, "Waiting for login to be displayed");
-      ok(loginGuid, "Expected login found in login-list");
+      Assert.ok(loginGuid, "Expected login found in login-list");
 
       let loginItem = Cu.waiveXrays(
         content.document.querySelector("login-item")
       );
-      is(loginItem._login.guid, loginGuid, "login-item should match");
+      Assert.equal(loginItem._login.guid, loginGuid, "login-item should match");
 
       let { login, listItem } = loginList._logins[loginGuid];
-      ok(
+      Assert.ok(
         listItem.classList.contains("selected"),
         "list item should be selected"
       );
-      is(
+      Assert.equal(
         login.origin,
         aOriginTuple[1],
         "Stored login should only include the origin of the URL provided during creation"
       );
-      is(
+      Assert.equal(
         login.username,
         "testuser1",
         "Stored login should have username provided during creation"
       );
-      is(
+      Assert.equal(
         login.password,
         "testpass1",
         "Stored login should have password provided during creation"
@@ -199,7 +222,7 @@ add_task(async function test_create_login() {
         () => usernameInput.placeholder,
         "waiting for placeholder to get set"
       );
-      ok(
+      Assert.ok(
         usernameInput.placeholder,
         "there should be a placeholder on the username input when not in edit mode"
       );
@@ -209,21 +232,24 @@ add_task(async function test_create_login() {
       continue;
     }
 
-    let reauthObserved = forceAuthTimeoutAndWaitForOSKeyStoreLogin({
-      loginResult: true,
-    });
-    await SpecialPowers.spawn(browser, [originTuple], async aOriginTuple => {
+    let reauthObserved = Promise.resolve();
+    if (OSKeyStore.canReauth()) {
+      reauthObserved = forceAuthTimeoutAndWaitForOSKeyStoreLogin({
+        loginResult: true,
+      });
+    }
+    await SpecialPowers.spawn(browser, [], async () => {
       let loginItem = Cu.waiveXrays(
         content.document.querySelector("login-item")
       );
-      let editButton = loginItem.shadowRoot.querySelector(".edit-button");
+      let editButton = loginItem.shadowRoot.querySelector("edit-button");
       info("clicking on edit button");
       editButton.click();
     });
     info("waiting for oskeystore auth");
     await reauthObserved;
 
-    await SpecialPowers.spawn(browser, [originTuple], async aOriginTuple => {
+    await SpecialPowers.spawn(browser, [], async () => {
       let loginItem = Cu.waiveXrays(
         content.document.querySelector("login-item")
       );
@@ -237,6 +263,10 @@ add_task(async function test_create_login() {
         "input[name='username']"
       );
       let passwordInput = loginItem.shadowRoot.querySelector(
+        "input[type='password']"
+      );
+      passwordInput.focus();
+      passwordInput = loginItem.shadowRoot.querySelector(
         "input[name='password']"
       );
       usernameInput.value = "testuser2";
@@ -269,17 +299,17 @@ add_task(async function test_create_login() {
           login.password == "testpass2"
         );
       }, "waiting for the login to get updated");
-      is(
+      Assert.equal(
         login.origin,
         aOriginTuple[1],
         "Stored login should only include the origin of the URL provided during creation"
       );
-      is(
+      Assert.equal(
         login.username,
         "testuser2",
         "Stored login should have modified username"
       );
-      is(
+      Assert.equal(
         login.password,
         "testpass2",
         "Stored login should have modified password"
@@ -287,46 +317,38 @@ add_task(async function test_create_login() {
     });
   }
 
-  await SpecialPowers.spawn(
-    browser,
-    [testCases.length],
-    async testCasesLength => {
-      let loginList = Cu.waiveXrays(
-        content.document.querySelector("login-list")
-      );
-      is(
-        loginList._loginGuidsSortedOrder.length,
-        5,
-        "login list should have a login per testcase"
-      );
-    }
-  );
+  await SpecialPowers.spawn(browser, [], async () => {
+    let loginList = Cu.waiveXrays(content.document.querySelector("login-list"));
+    Assert.equal(
+      loginList._loginGuidsSortedOrder.length,
+      5,
+      "login list should have a login per testcase"
+    );
+  });
 });
 
 add_task(async function test_cancel_create_login() {
   let browser = gBrowser.selectedBrowser;
   await SpecialPowers.spawn(browser, [], async () => {
     let loginList = Cu.waiveXrays(content.document.querySelector("login-list"));
-    ok(
+    Assert.ok(
       loginList._selectedGuid,
       "there should be a selected guid before create mode"
     );
-    ok(
-      ContentTaskUtils.is_hidden(loginList._blankLoginListItem),
+    Assert.ok(
+      ContentTaskUtils.isHidden(loginList._blankLoginListItem),
       "the blank login list item should be hidden before create mode"
     );
 
-    let createButton = content.document
-      .querySelector("login-list")
-      .shadowRoot.querySelector(".create-login-button");
+    let createButton = loginList._createLoginButton;
     createButton.click();
 
-    ok(
+    Assert.ok(
       !loginList._selectedGuid,
       "there should be no selected guid when in create mode"
     );
-    ok(
-      ContentTaskUtils.is_visible(loginList._blankLoginListItem),
+    Assert.ok(
+      ContentTaskUtils.isVisible(loginList._blankLoginListItem),
       "the blank login list item should be visible in create mode"
     );
 
@@ -334,12 +356,12 @@ add_task(async function test_cancel_create_login() {
     let cancelButton = loginItem.shadowRoot.querySelector(".cancel-button");
     cancelButton.click();
 
-    ok(
+    Assert.ok(
       loginList._selectedGuid,
       "there should be a selected guid after canceling create mode"
     );
-    ok(
-      ContentTaskUtils.is_hidden(loginList._blankLoginListItem),
+    Assert.ok(
+      ContentTaskUtils.isHidden(loginList._blankLoginListItem),
       "the blank login list item should be hidden after canceling create mode"
     );
   });
@@ -347,25 +369,25 @@ add_task(async function test_cancel_create_login() {
 
 add_task(
   async function test_cancel_create_login_with_filter_showing_one_login() {
-    let browser = gBrowser.selectedBrowser;
+    const browser = gBrowser.selectedBrowser;
     await SpecialPowers.spawn(browser, [], async () => {
-      let loginList = Cu.waiveXrays(
+      const loginList = Cu.waiveXrays(
         content.document.querySelector("login-list")
       );
 
-      let loginFilter = Cu.waiveXrays(
-        content.document.querySelector("login-filter")
+      const loginFilter = Cu.waiveXrays(
+        loginList.shadowRoot.querySelector("login-filter")
       );
       loginFilter.value = "bugzilla.mozilla.org";
-      is(
+      Assert.equal(
         loginList._list.querySelectorAll(
-          ".login-list-item[data-guid]:not([hidden])"
+          "login-list-item[data-guid]:not([hidden])"
         ).length,
         1,
         "filter should have one login showing"
       );
       let visibleLoginGuid = loginList.shadowRoot.querySelectorAll(
-        ".login-list-item[data-guid]:not([hidden])"
+        "login-list-item[data-guid]:not([hidden])"
       )[0].dataset.guid;
 
       let createButton = loginList._createLoginButton;
@@ -375,20 +397,20 @@ add_task(
         content.document.querySelector("login-item")
       );
       let cancelButton = loginItem.shadowRoot.querySelector(".cancel-button");
-      ok(
-        ContentTaskUtils.is_visible(cancelButton),
+      Assert.ok(
+        ContentTaskUtils.isVisible(cancelButton),
         "cancel button should be visible in create mode with one login showing"
       );
       cancelButton.click();
 
-      is(
+      Assert.equal(
         loginFilter.value,
         "bugzilla.mozilla.org",
         "login-filter should not be cleared if there was a login in the list"
       );
-      is(
+      Assert.equal(
         loginList.shadowRoot.querySelectorAll(
-          ".login-list-item[data-guid]:not([hidden])"
+          "login-list-item[data-guid]:not([hidden])"
         )[0].dataset.guid,
         visibleLoginGuid,
         "the same login should still be visible"
@@ -398,17 +420,19 @@ add_task(
 );
 
 add_task(async function test_cancel_create_login_with_logins_filtered_out() {
-  let browser = gBrowser.selectedBrowser;
+  const browser = gBrowser.selectedBrowser;
   await SpecialPowers.spawn(browser, [], async () => {
-    let loginFilter = Cu.waiveXrays(
-      content.document.querySelector("login-filter")
+    const loginList = Cu.waiveXrays(
+      content.document.querySelector("login-list")
+    );
+    const loginFilter = Cu.waiveXrays(
+      loginList.shadowRoot.querySelector("login-filter")
     );
     loginFilter.value = "XXX-no-logins-should-match-this-XXX";
     await Promise.resolve();
-    let loginList = Cu.waiveXrays(content.document.querySelector("login-list"));
-    is(
+    Assert.equal(
       loginList._list.querySelectorAll(
-        ".login-list-item[data-guid]:not([hidden])"
+        "login-list-item[data-guid]:not([hidden])"
       ).length,
       0,
       "filter should have no logins showing"
@@ -419,27 +443,27 @@ add_task(async function test_cancel_create_login_with_logins_filtered_out() {
 
     let loginItem = Cu.waiveXrays(content.document.querySelector("login-item"));
     let cancelButton = loginItem.shadowRoot.querySelector(".cancel-button");
-    ok(
-      ContentTaskUtils.is_visible(cancelButton),
+    Assert.ok(
+      ContentTaskUtils.isVisible(cancelButton),
       "cancel button should be visible in create mode with no logins showing"
     );
     cancelButton.click();
     await Promise.resolve();
 
-    is(
+    Assert.equal(
       loginFilter.value,
       "",
       "login-filter should be cleared if there were no logins in the list"
     );
     let visibleLoginItems = loginList.shadowRoot.querySelectorAll(
-      ".login-list-item[data-guid]:not([hidden])"
+      "login-list-item[data-guid]:not([hidden])"
     );
-    is(
+    Assert.equal(
       visibleLoginItems.length,
       5,
       "all logins should be visible with blank filter"
     );
-    is(
+    Assert.equal(
       loginList._selectedGuid,
       visibleLoginItems[0].dataset.guid,
       "the first item in the list should be selected"
@@ -489,7 +513,7 @@ add_task(async function test_create_duplicate_login() {
         v.login.origin == EXISTING_ORIGIN &&
         v.login.username == EXISTING_USERNAME
     ).login.guid;
-    is(
+    Assert.equal(
       loginItem._errorMessageLink.dataset.errorGuid,
       duplicatedGuid,
       "Error message has GUID of existing duplicated login set on it"
@@ -498,18 +522,17 @@ add_task(async function test_create_duplicate_login() {
     let confirmationDialog = Cu.waiveXrays(
       content.document.querySelector("confirmation-dialog")
     );
-    ok(
+    Assert.ok(
       confirmationDialog.hidden,
       "the discard-changes dialog should be hidden before clicking the error-message-text"
     );
     loginItem._errorMessageLink.querySelector("a").click();
-    ok(
+    Assert.ok(
       !confirmationDialog.hidden,
       "the discard-changes dialog should be visible"
     );
-    let discardChangesButton = confirmationDialog.shadowRoot.querySelector(
-      ".confirm-button"
-    );
+    let discardChangesButton =
+      confirmationDialog.shadowRoot.querySelector(".confirm-button");
     discardChangesButton.click();
 
     await ContentTaskUtils.waitForCondition(
@@ -518,7 +541,7 @@ add_task(async function test_create_duplicate_login() {
         loginItem._login.guid == duplicatedGuid,
       "waiting until the existing duplicated login is selected"
     );
-    is(
+    Assert.equal(
       loginList._selectedGuid,
       duplicatedGuid,
       "the duplicated login should be selected in the list"
