@@ -4,7 +4,7 @@
 // See Bug 1270998.
 requestLongerTimeout(2);
 
-add_task(async function() {
+add_task(async function () {
   let aboutURLs = [];
 
   // List of about: URLs that may cause problem, so we skip them in this test.
@@ -14,9 +14,10 @@ add_task(async function() {
     // This is due to a fetch request that has the default user context. Since
     // the fetch request omits credentials, the user context doesn't matter.
     "addons",
-    // about:credits and about:logins will initiate network request.
+    // about:credits, about:logins, and about:rights will initiate network request.
     "credits",
     "logins",
+    "rights",
     // about:telemetry will fetch Telemetry asynchronously and takes longer,
     // so we skip this for now.
     "telemetry",
@@ -28,6 +29,12 @@ add_task(async function() {
     // about:protections uses RPM to send a message as soon as the page loads,
     // the page is destoryed before getting a response.
     "protections",
+
+    // These pages are disabled when profile management is disabled.
+    "profilemanager",
+    "editprofile",
+    "deleteprofile",
+    "newprofile",
   ];
 
   for (let cid in Cc) {
