@@ -1,9 +1,13 @@
 "use strict";
 
-var overflowPanel = document.getElementById("widget-overflow");
+var overflowPanel, originalWindowWidth;
 
-var originalWindowWidth;
-registerCleanupFunction(function() {
+add_setup(function () {
+  overflowPanel = document.getElementById("widget-overflow");
+  originalWindowWidth = ensureToolbarOverflow(window);
+});
+
+registerCleanupFunction(function () {
   overflowPanel.removeAttribute("animate");
   window.resizeTo(originalWindowWidth, window.outerHeight);
   let navbar = document.getElementById(CustomizableUI.AREA_NAVBAR);
@@ -12,20 +16,19 @@ registerCleanupFunction(function() {
 
 // Right-click on an item within the overflow panel should
 // show a context menu with options to move it.
-add_task(async function() {
+add_task(async function () {
   overflowPanel.setAttribute("animate", "false");
   let fxaButton = document.getElementById("fxa-toolbar-menu-button");
-  if (BrowserTestUtils.is_hidden(fxaButton)) {
+  if (BrowserTestUtils.isHidden(fxaButton)) {
     // FxA button is likely hidden since the user is logged out.
     let initialFxaStatus = document.documentElement.getAttribute("fxastatus");
     document.documentElement.setAttribute("fxastatus", "signed_in");
     registerCleanupFunction(() =>
       document.documentElement.setAttribute("fxastatus", initialFxaStatus)
     );
-    ok(BrowserTestUtils.is_visible(fxaButton), "FxA button is now visible");
+    ok(BrowserTestUtils.isVisible(fxaButton), "FxA button is now visible");
   }
 
-  originalWindowWidth = window.outerWidth;
   let navbar = document.getElementById(CustomizableUI.AREA_NAVBAR);
   ok(
     !navbar.hasAttribute("overflowing"),
@@ -75,9 +78,10 @@ add_task(async function() {
   let hiddenPromise = promisePanelElementHidden(window, overflowPanel);
   let moveToPanel = contextMenu.querySelector(".customize-context-moveToPanel");
   if (moveToPanel) {
-    moveToPanel.click();
+    contextMenu.activateItem(moveToPanel);
+  } else {
+    contextMenu.hidePopup();
   }
-  contextMenu.hidePopup();
   await hiddenContextPromise;
   await hiddenPromise;
 
@@ -91,6 +95,7 @@ add_task(async function() {
     "FxA button should be pinned now"
   );
   CustomizableUI.reset();
+  ensureToolbarOverflow(window, false);
 
   // In some cases, it can take a tick for the navbar to overflow again. Wait for it:
   await TestUtils.waitForCondition(() =>
