@@ -5,14 +5,14 @@
 "use strict";
 
 // Attempting to drag the menubar to the navbar shouldn't work.
-add_task(async function() {
+add_task(async function () {
   await startCustomizing();
   let menuItems = document.getElementById("menubar-items");
   let navbar = document.getElementById("nav-bar");
   let menubar = document.getElementById("toolbar-menubar");
   // Force the menu to be shown.
   const kAutohide = menubar.getAttribute("autohide");
-  menubar.setAttribute("autohide", "false");
+  menubar.removeAttribute("autohide");
   simulateItemDrag(menuItems, CustomizableUI.getCustomizationTarget(navbar));
 
   is(
