@@ -7,9 +7,6 @@
  * Test the keyboard behavior of PanelViews.
  */
 
-const { PanelMultiView } = ChromeUtils.import(
-  "resource:///modules/PanelMultiView.jsm"
-);
 const kEmbeddedDocUrl =
   'data:text/html,<textarea id="docTextarea">value</textarea><button id="docButton"></button>';
 
@@ -25,6 +22,8 @@ let gMainTextbox;
 let gMainButton2;
 let gMainButton3;
 let gCheckbox;
+let gNamespacedLink;
+let gLink;
 let gMainTabOrder;
 let gMainArrowOrder;
 let gSubView;
@@ -34,10 +33,15 @@ let gBrowserView;
 let gBrowserBrowser;
 let gIframeView;
 let gIframeIframe;
+let gToggle;
+let gComponentView;
+let gShadowRoot;
+let gShadowRootButtonA;
+let gShadowRootButtonB;
 
 async function openPopup() {
   let shown = BrowserTestUtils.waitForEvent(gMainView, "ViewShown");
-  PanelMultiView.openPopup(gPanel, gAnchor, "bottomcenter topright");
+  PanelMultiView.openPopup(gPanel, gAnchor, "bottomright topright");
   await shown;
 }
 
@@ -70,7 +74,7 @@ async function expectFocusAfterKey(aKey, aFocus) {
   ok(true, aFocus.id + " focused after " + aKey + " pressed");
 }
 
-add_setup(async function() {
+add_setup(async function () {
   // This shouldn't be necessary - but it is, because we use same-process frames.
   // https://bugzilla.mozilla.org/show_bug.cgi?id=1565276 covers improving this.
   await SpecialPowers.pushPrefEnv({
@@ -133,6 +137,27 @@ add_setup(async function() {
   gCheckbox = document.createXULElement("checkbox");
   gCheckbox.id = "gCheckbox";
   gMainView.appendChild(gCheckbox);
+
+  // moz-support-links in XUL documents are created with the
+  // <html:a> tag and so we need to test this separately from
+  // <a> tags.
+  gNamespacedLink = document.createElementNS(
+    "http://www.w3.org/1999/xhtml",
+    "html:a"
+  );
+  gNamespacedLink.href = "www.mozilla.org";
+  gNamespacedLink.innerText = "gNamespacedLink";
+  gNamespacedLink.id = "gNamespacedLink";
+  gMainView.appendChild(gNamespacedLink);
+  gLink = document.createElement("a");
+  gLink.href = "www.mozilla.org";
+  gLink.innerText = "gLink";
+  gLink.id = "gLink";
+  gMainView.appendChild(gLink);
+  gToggle = document.createElement("moz-toggle");
+  gToggle.label = "Test label";
+  gMainView.appendChild(gToggle);
+
   gMainTabOrder = [
     gMainButton1,
     gMainMenulist,
@@ -141,8 +166,19 @@ add_setup(async function() {
     gMainButton2,
     gMainButton3,
     gCheckbox,
+    gNamespacedLink,
+    gLink,
+    gToggle,
+  ];
+  gMainArrowOrder = [
+    gMainButton1,
+    gMainButton2,
+    gMainButton3,
+    gCheckbox,
+    gNamespacedLink,
+    gLink,
+    gToggle,
   ];
-  gMainArrowOrder = [gMainButton1, gMainButton2, gMainButton3, gCheckbox];
 
   gSubView = document.createXULElement("panelview");
   gSubView.id = "testSubView";
@@ -164,8 +200,7 @@ add_setup(async function() {
   gBrowserBrowser.id = "GBrowserBrowser";
   gBrowserBrowser.setAttribute("type", "content");
   gBrowserBrowser.setAttribute("src", kEmbeddedDocUrl);
-  gBrowserBrowser.setAttribute("width", 100);
-  gBrowserBrowser.setAttribute("height", 100);
+  gBrowserBrowser.style.minWidth = gBrowserBrowser.style.minHeight = "100px";
   gBrowserView.appendChild(gBrowserBrowser);
 
   gIframeView = document.createXULElement("panelview");
@@ -176,6 +211,24 @@ add_setup(async function() {
   gIframeIframe.setAttribute("src", kEmbeddedDocUrl);
   gIframeView.appendChild(gIframeIframe);
 
+  gComponentView = document.createXULElement("panelview");
+  gComponentView.id = "testComponentView";
+  gPanelMultiView.appendChild(gComponentView);
+  // Shadow root that delegates focus with multiple buttons
+  gShadowRoot = document.createElement("section");
+  gShadowRoot.id = "gShadowRoot";
+  gShadowRoot.dataset.navigableWithTabOnly = "true";
+  gShadowRoot.attachShadow({ mode: "open", delegatesFocus: true });
+  gShadowRootButtonA = document.createElement("moz-button");
+  gShadowRootButtonA.id = "gShadowRootButtonA";
+  gShadowRootButtonA.label = "Button A";
+  gShadowRootButtonB = document.createElement("moz-button");
+  gShadowRootButtonB.id = "gShadowRootButtonB";
+  gShadowRootButtonB.label = "Button B";
+  gShadowRoot.shadowRoot.appendChild(gShadowRootButtonA);
+  gShadowRoot.shadowRoot.appendChild(gShadowRootButtonB);
+  gComponentView.appendChild(gShadowRoot);
+
   registerCleanupFunction(() => {
     gAnchor.remove();
     gPanel.remove();
@@ -291,14 +344,11 @@ add_task(async function testTabOpenMenulist() {
   await shown;
   ok(gMainMenulist.open, "menulist open");
   let menuHidden = BrowserTestUtils.waitForEvent(popup, "popuphidden");
-  let panelHidden = BrowserTestUtils.waitForEvent(gPanel, "popuphidden");
   EventUtils.synthesizeKey("KEY_Tab");
   await menuHidden;
   ok(!gMainMenulist.open, "menulist closed after Tab");
-  // Tab in an open menulist closes the menulist, but also dismisses the panel
-  // above it (bug 1566673). So, we just wait for the panel to hide rather than
-  // using hidePopup().
-  await panelHidden;
+  is(gPanel.state, "open", "Panel should be open");
+  await hidePopup();
 });
 
 if (AppConstants.platform == "macosx") {
@@ -328,14 +378,11 @@ if (AppConstants.platform == "macosx") {
     );
 
     let menuHidden = BrowserTestUtils.waitForEvent(popup, "popuphidden");
-    let panelHidden = BrowserTestUtils.waitForEvent(gPanel, "popuphidden");
     EventUtils.synthesizeKey("KEY_Tab");
     await menuHidden;
     ok(!gMainMenulist.open, "menulist closed after Tab");
-    // Tab in an open menulist closes the menulist, but also dismisses the panel
-    // above it (bug 1566673). So, we just wait for the panel to hide rather than
-    // using hidePopup().
-    await panelHidden;
+    is(gPanel.state, "open", "Panel should be open");
+    await hidePopup();
   });
 }
 
@@ -414,7 +461,7 @@ add_task(async function testDynamicButton() {
 add_task(async function testActivation() {
   function checkActivated(elem, activationFn, reason) {
     let activated = false;
-    elem.onclick = function() {
+    elem.onclick = function () {
       activated = true;
     };
     activationFn();
@@ -448,7 +495,7 @@ add_task(async function testActivationMousedown() {
   await openPopup();
   await expectFocusAfterKey("ArrowDown", gMainButton1);
   let activated = false;
-  gMainButton1.onmousedown = function() {
+  gMainButton1.onmousedown = function () {
     activated = true;
   };
   EventUtils.synthesizeKey(" ");
@@ -515,7 +562,7 @@ add_task(async function testArowsContext() {
   await expectFocusAfterKey("ArrowDown", gMainButton1);
   let shown = BrowserTestUtils.waitForEvent(gMainContext, "popupshown");
   // There's no cross-platform way to open a context menu from the keyboard.
-  gMainContext.openPopup();
+  gMainContext.openPopup(gMainButton1);
   await shown;
   let item = gMainContext.children[0];
   ok(
@@ -539,3 +586,44 @@ add_task(async function testArowsContext() {
   await hidden;
   await hidePopup();
 });
+
+add_task(async function testMozToggle() {
+  await openPopup();
+  is(gToggle.pressed, false, "The toggle is not pressed initially.");
+  // Focus the toggle via keyboard navigation.
+  while (document.activeElement !== gToggle) {
+    EventUtils.synthesizeKey("KEY_Tab");
+  }
+  EventUtils.synthesizeKey(" ");
+  await gToggle.updateComplete;
+  is(gToggle.pressed, true, "Toggle pressed state changes via spacebar.");
+  EventUtils.synthesizeKey("KEY_Enter");
+  await gToggle.updateComplete;
+  is(gToggle.pressed, false, "Toggle pressed state changes via enter.");
+  await hidePopup();
+});
+
+// Test that tab key is not overridden in elements that capture focus.
+add_task(async function testTabCapturesFocus() {
+  await openPopup();
+  await showSubView(gComponentView);
+
+  let backButton = gComponentView.querySelector(".subviewbutton-back");
+  backButton.id = "shadowBack";
+  await expectFocusAfterKey("Tab", backButton);
+
+  // Only Button A can be navigated to before looping to back button.
+  await expectFocusAfterKey("Tab", gShadowRootButtonA);
+
+  await expectFocusAfterKey("Tab", backButton);
+
+  gShadowRoot.dataset.capturesFocus = "true";
+
+  // Both buttons can be focused before looping.
+  await expectFocusAfterKey("Tab", gShadowRootButtonA);
+  await expectFocusAfterKey("Tab", gShadowRootButtonB);
+
+  await expectFocusAfterKey("Tab", backButton);
+
+  await hidePopup();
+});
