@@ -31,46 +31,28 @@
 
 "use strict";
 
-var { XPCOMUtils } = ChromeUtils.import(
-  "resource://gre/modules/XPCOMUtils.jsm"
-);
-var { Services } = ChromeUtils.import("resource://gre/modules/Services.jsm");
-
-ChromeUtils.defineModuleGetter(
-  this,
-  "DownloadsViewUI",
-  "resource:///modules/DownloadsViewUI.jsm"
-);
-ChromeUtils.defineModuleGetter(
-  this,
-  "DownloadsSubview",
-  "resource:///modules/DownloadsSubview.jsm"
-);
-ChromeUtils.defineModuleGetter(
-  this,
-  "FileUtils",
-  "resource://gre/modules/FileUtils.jsm"
-);
-ChromeUtils.defineModuleGetter(
-  this,
-  "NetUtil",
-  "resource://gre/modules/NetUtil.jsm"
-);
-ChromeUtils.defineModuleGetter(
-  this,
-  "PlacesUtils",
-  "resource://gre/modules/PlacesUtils.jsm"
+var { XPCOMUtils } = ChromeUtils.importESModule(
+  "resource://gre/modules/XPCOMUtils.sys.mjs"
 );
 
-const { Integration } = ChromeUtils.import(
-  "resource://gre/modules/Integration.jsm"
+ChromeUtils.defineESModuleGetters(this, {
+  DownloadsViewUI:
+    "moz-src:///browser/components/downloads/DownloadsViewUI.sys.mjs",
+  FileUtils: "resource://gre/modules/FileUtils.sys.mjs",
+  NetUtil: "resource://gre/modules/NetUtil.sys.mjs",
+  PlacesUtils: "resource://gre/modules/PlacesUtils.sys.mjs",
+  PrivateBrowsingUtils: "resource://gre/modules/PrivateBrowsingUtils.sys.mjs",
+});
+
+const { Integration } = ChromeUtils.importESModule(
+  "resource://gre/modules/Integration.sys.mjs"
 );
 
 /* global DownloadIntegration */
-Integration.downloads.defineModuleGetter(
+Integration.downloads.defineESModuleGetter(
   this,
   "DownloadIntegration",
-  "resource://gre/modules/DownloadIntegration.jsm"
+  "resource://gre/modules/DownloadIntegration.sys.mjs"
 );
 
 // DownloadsPanel
@@ -87,28 +69,11 @@ var DownloadsPanel = {
    */
   _delayTimeout: null,
 
-  /**
-   * Internal state of the downloads panel, based on one of the kState
-   * constants.  This is not the same state as the XUL panel element.
-   */
-  _state: 0,
-
   /** The panel is not linked to downloads data yet. */
-  get kStateUninitialized() {
-    return 0;
-  },
-  /** This object is linked to data, but the panel is invisible. */
-  get kStateHidden() {
-    return 1;
-  },
-  /** The panel will be shown as soon as possible. */
-  get kStateWaitingData() {
-    return 2;
-  },
-  /** The panel is open. */
-  get kStateShown() {
-    return 3;
-  },
+  _initialized: false,
+
+  /** The panel will be shown as soon as data is available. */
+  _waitingDataForOpen: false,
 
   /**
    * Starts loading the download data in background, without opening the panel.
@@ -119,26 +84,27 @@ var DownloadsPanel = {
       "Attempting to initialize DownloadsPanel for a window."
     );
 
-    // Allow the download spam protection module to notify DownloadsView
-    // if it's been created.
-    if (
-      DownloadIntegration.downloadSpamProtection &&
-      !DownloadIntegration.downloadSpamProtection.spamList._views.has(
-        DownloadsView
-      )
-    ) {
-      DownloadIntegration.downloadSpamProtection.spamList.addView(
-        DownloadsView
+    if (DownloadIntegration.downloadSpamProtection) {
+      DownloadIntegration.downloadSpamProtection.register(
+        DownloadsView,
+        window
       );
     }
 
-    if (this._state != this.kStateUninitialized) {
+    if (this._initialized) {
       DownloadsCommon.log("DownloadsPanel is already initialized.");
       return;
     }
-    this._state = this.kStateHidden;
+    this._initialized = true;
 
     window.addEventListener("unload", this.onWindowUnload);
+    const downloadPanelCommands = document.getElementById(
+      "downloadPanelCommands"
+    );
+    downloadPanelCommands.addEventListener("command", this);
+    downloadPanelCommands.addEventListener("commandupdate", () => {
+      goUpdateCommand("cmd_delete");
+    });
 
     // Load and resume active downloads if required.  If there are downloads to
     // be shown in the panel, they will be loaded asynchronously.
@@ -170,7 +136,7 @@ var DownloadsPanel = {
    */
   terminate() {
     DownloadsCommon.log("Attempting to terminate DownloadsPanel for a window.");
-    if (this._state == this.kStateUninitialized) {
+    if (!this._initialized) {
       DownloadsCommon.log(
         "DownloadsPanel was never initialized. Nothing to do."
       );
@@ -178,6 +144,9 @@ var DownloadsPanel = {
     }
 
     window.removeEventListener("unload", this.onWindowUnload);
+    document
+      .getElementById("downloadPanelCommands")
+      .removeEventListener("command", this);
 
     // Ensure that the panel is closed before shutting down.
     this.hidePanel();
@@ -191,12 +160,10 @@ var DownloadsPanel = {
     this._unattachEventListeners();
 
     if (DownloadIntegration.downloadSpamProtection) {
-      DownloadIntegration.downloadSpamProtection.spamList.removeView(
-        DownloadsView
-      );
+      DownloadIntegration.downloadSpamProtection.unregister(window);
     }
 
-    this._state = this.kStateUninitialized;
+    this._initialized = false;
 
     DownloadsSummary.active = false;
     DownloadsCommon.log("DownloadsPanel terminated.");
@@ -219,7 +186,13 @@ var DownloadsPanel = {
    * only when data is ready.
    */
   showPanel(openedManually = false, isKeyPress = false) {
-    Services.telemetry.scalarAdd("downloads.panel_shown", 1);
+    Glean.downloads.panelShown.add(1);
+    // GLAM EXPERIMENT
+    // This metric is temporary, disabled by default, and will be enabled only
+    // for the purpose of experimenting with client-side sampling of data for
+    // GLAM use. See Bug 1947604 for more information.
+    Glean.glamExperiment.panelShown.add(1);
+
     DownloadsCommon.log("Opening the downloads panel.");
 
     this._openedManually = openedManually;
@@ -242,7 +215,7 @@ var DownloadsPanel = {
     setTimeout(() => this._openPopupIfDataReady(), 0);
 
     DownloadsCommon.log("Waiting for the downloads panel to appear.");
-    this._state = this.kStateWaitingData;
+    this._waitingDataForOpen = true;
   },
 
   /**
@@ -258,25 +231,39 @@ var DownloadsPanel = {
     }
 
     PanelMultiView.hidePopup(this.panel);
-
-    // Ensure that we allow the panel to be reopened.  Note that, if the popup
-    // was open, then the onPopupHidden event handler has already updated the
-    // current state, otherwise we must update the state ourselves.
-    this._state = this.kStateHidden;
     DownloadsCommon.log("Downloads panel is now closed.");
   },
 
   /**
-   * Indicates whether the panel is shown or will be shown.
+   * Indicates whether the panel is showing.
+   * @note this includes the hiding state.
    */
   get isPanelShowing() {
-    return (
-      this._state == this.kStateWaitingData || this._state == this.kStateShown
-    );
+    return this._waitingDataForOpen || this.panel.state != "closed";
   },
 
   handleEvent(aEvent) {
     switch (aEvent.type) {
+      case "click":
+        DownloadsPanel.showDownloadsHistory();
+        break;
+      case "command":
+        if (aEvent.currentTarget == DownloadsView.downloadsHistory) {
+          DownloadsPanel.showDownloadsHistory();
+          return;
+        }
+
+        if (
+          aEvent.currentTarget == DownloadsBlockedSubview.elements.deleteButton
+        ) {
+          DownloadsBlockedSubview.confirmBlock();
+          return;
+        }
+
+        // Handle the commands defined in downloadsPanel.inc.xhtml.
+        // Every command "id" is also its corresponding command.
+        goDoCommand(aEvent.target.id);
+        break;
       case "mousemove":
         if (
           !DownloadsView.contextMenuOpen &&
@@ -291,7 +278,30 @@ var DownloadsPanel = {
           this._focusPanel();
         }
         break;
+      case "mouseover":
+        DownloadsView._onDownloadMouseOver(aEvent);
+        break;
+      case "mouseout":
+        DownloadsView._onDownloadMouseOut(aEvent);
+        break;
+      case "contextmenu":
+        DownloadsView._onDownloadContextMenu(aEvent);
+        break;
+      case "dragstart":
+        DownloadsView._onDownloadDragStart(aEvent);
+        break;
+      case "mousedown":
+        if (DownloadsView.richListBox.hasAttribute("disabled")) {
+          this._handlePotentiallySpammyDownloadActivation(aEvent);
+        }
+        break;
+
       case "keydown":
+        if (aEvent.currentTarget == DownloadsSummary._summaryNode) {
+          DownloadsSummary._onKeyDown(aEvent);
+          return;
+        }
+
         this._onKeyDown(aEvent);
         break;
       case "keypress":
@@ -301,6 +311,12 @@ var DownloadsPanel = {
       case "select":
         this._onSelect(aEvent);
         break;
+      case "popupshown":
+        this._onPopupShown(aEvent);
+        break;
+      case "popuphidden":
+        this._onPopupHidden(aEvent);
+        break;
     }
   },
 
@@ -320,14 +336,13 @@ var DownloadsPanel = {
     DownloadsPanel.terminate();
   },
 
-  onPopupShown(aEvent) {
+  _onPopupShown(aEvent) {
     // Ignore events raised by nested popups.
-    if (aEvent.target != aEvent.currentTarget) {
+    if (aEvent.target != this.panel) {
       return;
     }
 
     DownloadsCommon.log("Downloads panel has shown.");
-    this._state = this.kStateShown;
 
     // Since at most one popup is open at any given time, we can set globally.
     DownloadsCommon.getIndicatorData(window).attentionSuppressed |=
@@ -341,9 +356,9 @@ var DownloadsPanel = {
     this._focusPanel();
   },
 
-  onPopupHidden(aEvent) {
+  _onPopupHidden(aEvent) {
     // Ignore events raised by nested popups.
-    if (aEvent.target != aEvent.currentTarget) {
+    if (aEvent.target != this.panel) {
       return;
     }
 
@@ -359,15 +374,11 @@ var DownloadsPanel = {
     DownloadsView.richListBox.removeAttribute("force-focus-visible");
 
     // Since at most one popup is open at any given time, we can set globally.
-    DownloadsCommon.getIndicatorData(
-      window
-    ).attentionSuppressed &= ~DownloadsCommon.SUPPRESS_PANEL_OPEN;
+    DownloadsCommon.getIndicatorData(window).attentionSuppressed &=
+      ~DownloadsCommon.SUPPRESS_PANEL_OPEN;
 
     // Allow the anchor to be hidden.
     DownloadsButton.releaseAnchor();
-
-    // Allow the panel to be reopened.
-    this._state = this.kStateHidden;
   },
 
   // Related operations
@@ -381,7 +392,7 @@ var DownloadsPanel = {
     // to the browser window when the panel closes automatically.
     this.hidePanel();
 
-    BrowserDownloadsUI();
+    BrowserCommands.downloadsUI();
   },
 
   // Internal functions
@@ -397,9 +408,25 @@ var DownloadsPanel = {
     // Handle keypress to be able to preventDefault() events before they reach
     // the richlistbox, for keyboard navigation.
     this.panel.addEventListener("keypress", this);
+    // Handle mousedown to be able to notice clicks on disabled items.
+    this.panel.addEventListener("mousedown", this);
     this.panel.addEventListener("mousemove", this);
+    this.panel.addEventListener("popupshown", this);
+    this.panel.addEventListener("popuphidden", this);
     DownloadsView.richListBox.addEventListener("focus", this);
     DownloadsView.richListBox.addEventListener("select", this);
+    DownloadsView.richListBox.addEventListener("mouseover", this);
+    DownloadsView.richListBox.addEventListener("mouseout", this);
+    DownloadsView.richListBox.addEventListener("contextmenu", this);
+    DownloadsView.richListBox.addEventListener("dragstart", this);
+
+    DownloadsView.downloadsHistory.addEventListener("command", this);
+    DownloadsBlockedSubview.elements.deleteButton.addEventListener(
+      "command",
+      this
+    );
+    DownloadsSummary._summaryNode.addEventListener("click", this);
+    DownloadsSummary._summaryNode.addEventListener("keydown", this);
   },
 
   /**
@@ -409,9 +436,23 @@ var DownloadsPanel = {
   _unattachEventListeners() {
     this.panel.removeEventListener("keydown", this);
     this.panel.removeEventListener("keypress", this);
+    this.panel.removeEventListener("mousedown", this);
     this.panel.removeEventListener("mousemove", this);
+    this.panel.removeEventListener("popupshown", this);
+    this.panel.removeEventListener("popuphidden", this);
     DownloadsView.richListBox.removeEventListener("focus", this);
     DownloadsView.richListBox.removeEventListener("select", this);
+    DownloadsView.richListBox.removeEventListener("mouseover", this);
+    DownloadsView.richListBox.removeEventListener("mouseout", this);
+    DownloadsView.richListBox.removeEventListener("contextmenu", this);
+    DownloadsView.richListBox.removeEventListener("dragstart", this);
+    DownloadsView.downloadsHistory.removeEventListener("command", this);
+    DownloadsBlockedSubview.elements.deleteButton.removeEventListener(
+      "command",
+      this
+    );
+    DownloadsSummary._summaryNode.removeEventListener("click", this);
+    DownloadsSummary._summaryNode.removeEventListener("keydown", this);
   },
 
   _onKeyPress(aEvent) {
@@ -470,10 +511,11 @@ var DownloadsPanel = {
       // If the last element in the list is selected, or the footer is already
       // focused, focus the footer.
       if (
-        richListBox.selectedItem === richListBox.lastElementChild ||
-        document
-          .getElementById("downloadsFooter")
-          .contains(document.activeElement)
+        DownloadsView.canChangeSelectedItem &&
+        (richListBox.selectedItem === richListBox.lastElementChild ||
+          document
+            .getElementById("downloadsFooter")
+            .contains(document.activeElement))
       ) {
         richListBox.selectedIndex = -1;
         DownloadsFooter.focus();
@@ -495,7 +537,7 @@ var DownloadsPanel = {
       Ci.nsITransferable
     );
     trans.init(null);
-    let flavors = ["text/x-moz-url", "text/unicode"];
+    let flavors = ["text/x-moz-url", "text/plain"];
     flavors.forEach(trans.addDataFlavor);
     Services.clipboard.getData(trans, Services.clipboard.kGlobalClipboard);
     // Getting the data or creating the nsIURI might fail
@@ -533,16 +575,25 @@ var DownloadsPanel = {
    */
   _focusPanel() {
     // We may be invoked while the panel is still waiting to be shown.
-    if (this._state != this.kStateShown) {
+    if (this.panel.state != "open") {
       return;
     }
 
-    if (document.activeElement && this.panel.contains(document.activeElement)) {
+    if (
+      document.activeElement &&
+      (this.panel.contains(document.activeElement) ||
+        this.panel.shadowRoot.contains(document.activeElement))
+    ) {
       return;
     }
-    let focusOptions = { preventFocusRing: !!this._preventFocusRing };
+    let focusOptions = {};
+    if (this._preventFocusRing) {
+      focusOptions.focusVisible = false;
+    }
     if (DownloadsView.richListBox.itemCount > 0) {
-      DownloadsView.richListBox.selectedIndex = 0;
+      if (DownloadsView.canChangeSelectedItem) {
+        DownloadsView.richListBox.selectedIndex = 0;
+      }
       DownloadsView.richListBox.focus(focusOptions);
     } else {
       DownloadsFooter.focus(focusOptions);
@@ -572,12 +623,19 @@ var DownloadsPanel = {
   },
 
   _startWatchingForSpammyDownloadActivation() {
-    Services.els.addSystemEventListener(window, "keydown", this, true);
+    window.addEventListener("keydown", this, {
+      capture: true,
+      mozSystemGroup: true,
+    });
   },
 
   _lastBeepTime: 0,
   _handlePotentiallySpammyDownloadActivation(aEvent) {
-    if (aEvent.key == "Enter" || aEvent.key == " ") {
+    let isSpammyKey =
+      aEvent.type.startsWith("key") &&
+      (aEvent.key == "Enter" || aEvent.key == " ");
+    let isSpammyMouse = aEvent.type.startsWith("mouse") && aEvent.button == 0;
+    if (isSpammyKey || isSpammyMouse) {
       // Throttle our beeping to a maximum of once per second, otherwise it
       // appears on Win10 that beeps never make it through at all.
       if (Date.now() - this._lastBeepTime > 1000) {
@@ -590,7 +648,10 @@ var DownloadsPanel = {
   },
 
   _stopWatchingForSpammyDownloadActivation() {
-    Services.els.removeSystemEventListener(window, "keydown", this, true);
+    window.removeEventListener("keydown", this, {
+      capture: true,
+      mozSystemGroup: true,
+    });
   },
 
   /**
@@ -599,16 +660,16 @@ var DownloadsPanel = {
   _openPopupIfDataReady() {
     // We don't want to open the popup if we already displayed it, or if we are
     // still loading data.
-    if (this._state != this.kStateWaitingData || DownloadsView.loading) {
+    if (!this._waitingDataForOpen || DownloadsView.loading) {
       return;
     }
+    this._waitingDataForOpen = false;
 
     // At this point, if the window is minimized, opening the panel could fail
     // without any notification, and there would be no way to either open or
     // close the panel any more.  To prevent this, check if the window is
     // minimized and in that case force the panel to the closed state.
     if (window.windowState == window.STATE_MINIMIZED) {
-      this._state = this.kStateHidden;
       return;
     }
 
@@ -618,7 +679,6 @@ var DownloadsPanel = {
 
     if (!anchor) {
       DownloadsCommon.error("Downloads button cannot be found.");
-      this._state = this.kStateHidden;
       return;
     }
 
@@ -630,7 +690,7 @@ var DownloadsPanel = {
     // do these checks on a background thread, and don't prevent the panel to
     // be displayed while these checks are being performed.
     for (let viewItem of DownloadsView._visibleViewItems.values()) {
-      viewItem.download.refresh().catch(Cu.reportError);
+      viewItem.download.refresh().catch(console.error);
     }
 
     DownloadsCommon.log("Opening downloads panel popup.");
@@ -643,19 +703,34 @@ var DownloadsPanel = {
       PanelMultiView.openPopup(
         this.panel,
         anchor,
-        "bottomcenter topright",
+        "bottomright topright",
         0,
         0,
         false,
         null
-      ).catch(e => {
-        Cu.reportError(e);
-        this._state = this.kStateHidden;
-      });
+      ).then(() => {
+        if (!this._openedManually) {
+          this._delayPopupItems();
+        }
 
-      if (!this._openedManually) {
-        this._delayPopupItems();
-      }
+        let isPrivate =
+          window && PrivateBrowsingUtils.isContentWindowPrivate(window);
+
+        if (
+          // If private, show message asking whether to delete files at end of session
+          isPrivate &&
+          Services.prefs.getBoolPref(
+            "browser.download.enableDeletePrivate",
+            false
+          ) &&
+          !Services.prefs.getBoolPref(
+            "browser.download.deletePrivate.chosen",
+            false
+          )
+        ) {
+          PrivateDownloadsSubview.openWhenReady();
+        }
+      }, console.error);
     }, 0);
   },
 };
@@ -743,9 +818,8 @@ var DownloadsView = {
    */
   get downloadsHistory() {
     delete this.downloadsHistory;
-    return (this.downloadsHistory = document.getElementById(
-      "downloadsHistory"
-    ));
+    return (this.downloadsHistory =
+      document.getElementById("downloadsHistory"));
   },
 
   // Callback functions from DownloadsData
@@ -897,9 +971,10 @@ var DownloadsView = {
   onDownloadClick(aEvent) {
     // Handle primary clicks in the main area only:
     if (aEvent.button == 0 && aEvent.target.closest(".downloadMainArea")) {
-      let target = aEvent.target;
-      while (target.nodeName != "richlistitem") {
-        target = target.parentNode;
+      let target = aEvent.target.closest("richlistitem");
+      // Ignore clicks if the box is disabled.
+      if (target.closest("richlistbox").hasAttribute("disabled")) {
+        return;
       }
       let download = DownloadsView.itemForElement(target).download;
       if (download.succeeded) {
@@ -911,19 +986,13 @@ var DownloadsView = {
       } else if (aEvent.shiftKey || aEvent.ctrlKey || aEvent.metaKey) {
         // We adjust the command for supported modifiers to suggest where the download
         // may be opened
-        let openWhere = target.ownerGlobal.whereToOpenLink(aEvent, false, true);
+        let openWhere = BrowserUtils.whereToOpenLink(aEvent, false, true);
         if (["tab", "window", "tabshifted"].includes(openWhere)) {
           command += ":" + openWhere;
         }
       }
       // Toggle opening the file after the download has completed
-      if (
-        !download.stopped &&
-        command.startsWith("downloadsCmd_open") &&
-        Services.prefs.getBoolPref(
-          "browser.download.improvements_to_download_panel"
-        )
-      ) {
+      if (!download.stopped && command.startsWith("downloadsCmd_open")) {
         download.launchWhenSucceeded = !download.launchWhenSucceeded;
         download._launchedFromPanel = download.launchWhenSucceeded;
       }
@@ -981,10 +1050,19 @@ var DownloadsView = {
     return this.contextMenu.state != "closed";
   },
 
+  /**
+   * Whether it's possible to change the currently selected item.
+   */
+  get canChangeSelectedItem() {
+    // When the context menu or a subview are open, the selected item should
+    // not change.
+    return !this.contextMenuOpen && !this.subViewOpen;
+  },
+
   /**
    * Mouse listeners to handle selection on hover.
    */
-  onDownloadMouseOver(aEvent) {
+  _onDownloadMouseOver(aEvent) {
     let item = aEvent.target.closest("richlistitem,richlistbox");
     if (item.localName != "richlistitem") {
       return;
@@ -999,12 +1077,12 @@ var DownloadsView = {
       aEvent.target.closest(".downloadMainArea")
     );
 
-    if (!this.contextMenuOpen && !this.subViewOpen) {
+    if (this.canChangeSelectedItem) {
       this.richListBox.selectedItem = item;
     }
   },
 
-  onDownloadMouseOut(aEvent) {
+  _onDownloadMouseOut(aEvent) {
     let item = aEvent.target.closest("richlistitem,richlistbox");
     if (item.localName != "richlistitem") {
       return;
@@ -1016,21 +1094,20 @@ var DownloadsView = {
 
     // If the destination element is outside of the richlistitem, clear the
     // selection.
-    if (
-      !this.contextMenuOpen &&
-      !this.subViewOpen &&
-      !item.contains(aEvent.relatedTarget)
-    ) {
+    if (this.canChangeSelectedItem && !item.contains(aEvent.relatedTarget)) {
       this.richListBox.selectedIndex = -1;
     }
   },
 
-  onDownloadContextMenu(aEvent) {
-    let element = this.richListBox.selectedItem;
+  _onDownloadContextMenu(aEvent) {
+    let element = aEvent.originalTarget.closest("richlistitem");
     if (!element) {
+      aEvent.preventDefault();
       return;
     }
-
+    // Ensure the selected item is the expected one, so commands and the
+    // context menu are updated appropriately.
+    this.richListBox.selectedItem = element;
     DownloadsViewController.updateCommands();
 
     DownloadsViewUI.updateContextMenuForElement(this.contextMenu, element);
@@ -1038,12 +1115,11 @@ var DownloadsView = {
     // this here instead of in DownloadsViewUI because DownloadsPlacesView
     // allows selecting multiple downloads, so in that view the menuitem will be
     // shown according to whether at least one of the selected items has a URL.
-    this.contextMenu.querySelector(
-      ".downloadCopyLocationMenuItem"
-    ).hidden = !element._shell.download.source?.url;
+    this.contextMenu.querySelector(".downloadCopyLocationMenuItem").hidden =
+      !element._shell.download.source?.url;
   },
 
-  onDownloadDragStart(aEvent) {
+  _onDownloadDragStart(aEvent) {
     let element = aEvent.target.closest("richlistitem");
     if (!element) {
       return;
@@ -1173,7 +1249,7 @@ class DownloadsViewItem extends DownloadsViewUI.DownloadElementShell {
 
   downloadsCmd_unblockAndOpen() {
     DownloadsPanel.hidePanel();
-    this.unblockAndOpenDownload().catch(Cu.reportError);
+    this.unblockAndOpenDownload().catch(console.error);
   }
   downloadsCmd_unblockAndSave() {
     DownloadsPanel.hidePanel();
@@ -1237,7 +1313,7 @@ class DownloadsViewItem extends DownloadsViewUI.DownloadElementShell {
     // So the remaining view item needs to be refreshed to hide the "Delete" option.
     // That example only concerns 2 duplicate view items but you can have an arbitrary number, so iterate over all items...
     for (let viewItem of DownloadsView._visibleViewItems.values()) {
-      viewItem.download.refresh().catch(Cu.reportError);
+      viewItem.download.refresh().catch(console.error);
     }
     // Don't use DownloadsPanel.hidePanel for this method because it will remove
     // the view item from the list, which is already sufficient feedback.
@@ -1287,7 +1363,11 @@ var DownloadsViewController = {
   // nsIController
 
   supportsCommand(aCommand) {
-    if (aCommand === "downloadsCmd_clearList") {
+    if (
+      aCommand === "downloadsCmd_clearList" ||
+      aCommand === "downloadsCmd_deletePrivate" ||
+      aCommand === "downloadsCmd_dismissDeletePrivate"
+    ) {
       return true;
     }
     // Firstly, determine if this is a command that we can handle.
@@ -1323,16 +1403,22 @@ var DownloadsViewController = {
 
   isCommandEnabled(aCommand) {
     // Handle commands that are not selection-specific.
-    if (aCommand == "downloadsCmd_clearList") {
-      return DownloadsCommon.getData(window).canRemoveFinished;
+    switch (aCommand) {
+      case "downloadsCmd_clearList": {
+        return DownloadsCommon.getData(window).canRemoveFinished;
+      }
+      case "downloadsCmd_deletePrivate":
+      case "downloadsCmd_dismissDeletePrivate":
+        return true;
+      default: {
+        // Other commands are selection-specific.
+        let element = DownloadsView.richListBox.selectedItem;
+        return (
+          element &&
+          DownloadsView.itemForElement(element).isCommandEnabled(aCommand)
+        );
+      }
     }
-
-    // Other commands are selection-specific.
-    let element = DownloadsView.richListBox.selectedItem;
-    return (
-      element &&
-      DownloadsView.itemForElement(element).isCommandEnabled(aCommand)
-    );
   },
 
   doCommand(aCommand) {
@@ -1371,6 +1457,14 @@ var DownloadsViewController = {
   downloadsCmd_clearList() {
     DownloadsCommon.getData(window).removeFinished();
   },
+
+  downloadsCmd_deletePrivate() {
+    PrivateDownloadsSubview.choose(true /* deletePrivate */);
+  },
+
+  downloadsCmd_dismissDeletePrivate() {
+    PrivateDownloadsSubview.choose(false /* deletePrivate */);
+  },
 };
 
 XPCOMUtils.defineConstant(
@@ -1491,7 +1585,7 @@ var DownloadsSummary = {
    * @param aEvent
    *        The keydown event being handled.
    */
-  onKeyDown(aEvent) {
+  _onKeyDown(aEvent) {
     if (
       aEvent.charCode == " ".charCodeAt(0) ||
       aEvent.keyCode == KeyEvent.DOM_VK_RETURN
@@ -1500,16 +1594,6 @@ var DownloadsSummary = {
     }
   },
 
-  /**
-   * Respond to click events on the Downloads Summary node.
-   *
-   * @param aEvent
-   *        The click event being handled.
-   */
-  onClick(aEvent) {
-    DownloadsPanel.showDownloadsHistory();
-  },
-
   /**
    * Element corresponding to the root of the downloads summary.
    */
@@ -1664,6 +1748,14 @@ var DownloadsBlockedSubview = {
     let e = this.elements;
     let s = DownloadsCommon.strings;
 
+    e.deleteButton.hidden =
+      download.error?.becauseBlockedByContentAnalysis &&
+      download.error?.reputationCheckVerdict === "Malware";
+
+    e.unblockButton.hidden =
+      download.error?.becauseBlockedByContentAnalysis &&
+      download.error?.reputationCheckVerdict === "Malware";
+
     title.l10n
       ? document.l10n.setAttributes(e.title, title.l10n.id, title.l10n.args)
       : (e.title.textContent = title);
@@ -1720,13 +1812,13 @@ var DownloadsBlockedSubview = {
   },
 };
 
-XPCOMUtils.defineLazyGetter(DownloadsBlockedSubview, "panelMultiView", () =>
+ChromeUtils.defineLazyGetter(DownloadsBlockedSubview, "panelMultiView", () =>
   document.getElementById("downloadsPanel-multiView")
 );
-XPCOMUtils.defineLazyGetter(DownloadsBlockedSubview, "mainView", () =>
+ChromeUtils.defineLazyGetter(DownloadsBlockedSubview, "mainView", () =>
   document.getElementById("downloadsPanel-mainView")
 );
-XPCOMUtils.defineLazyGetter(DownloadsBlockedSubview, "subview", () =>
+ChromeUtils.defineLazyGetter(DownloadsBlockedSubview, "subview", () =>
   document.getElementById("downloadsPanel-blockedSubview")
 );
 
@@ -1735,3 +1827,66 @@ XPCOMUtils.defineConstant(
   "DownloadsBlockedSubview",
   DownloadsBlockedSubview
 );
+
+/**
+ * Manages the private browsing downloads subview that appears when you download a file in private browsing mode
+ */
+var PrivateDownloadsSubview = {
+  /**
+   * Slides in the private downloads subview.
+   *
+   * @param element
+   *        The download richlistitem element that was clicked.
+   */
+  openWhenReady() {
+    DownloadsView.subViewOpen = true;
+    DownloadsViewController.updateCommands();
+
+    this.mainView.addEventListener("ViewShown", this, { once: true });
+    this.mainView.toggleAttribute("showing-private-browsing-choice", true);
+  },
+
+  handleEvent(event) {
+    // This is called when the main view is shown or the panel is hidden.
+
+    // Focus the proper element if we're going back to the main panel.
+    if (event.type == "ViewShown") {
+      this.panelMultiView.showSubView(this.subview);
+    }
+  },
+
+  /**
+   * Sets whether to delete files at the end of private download session
+   * Based on user response to download notification prompt
+   *
+   * @param deletePrivate
+   *        True if the user chose to delete files at the end of the session
+   */
+  choose(deletePrivate) {
+    if (deletePrivate) {
+      Services.prefs.setBoolPref("browser.download.deletePrivate", true);
+    }
+    Services.prefs.setBoolPref("browser.download.deletePrivate.chosen", true);
+    DownloadsView.subViewOpen = false;
+    this.mainView.toggleAttribute("showing-private-browsing-choice", false);
+    this.panelMultiView.goBack();
+  },
+};
+
+ChromeUtils.defineLazyGetter(PrivateDownloadsSubview, "panelMultiView", () =>
+  document.getElementById("downloadsPanel-multiView")
+);
+
+ChromeUtils.defineLazyGetter(PrivateDownloadsSubview, "mainView", () =>
+  document.getElementById("downloadsPanel-mainView")
+);
+
+ChromeUtils.defineLazyGetter(PrivateDownloadsSubview, "subview", () =>
+  document.getElementById("downloadsPanel-privateBrowsing")
+);
+
+XPCOMUtils.defineConstant(
+  this,
+  "PrivateDownloadsSubview",
+  PrivateDownloadsSubview
+);
