@@ -4,8 +4,8 @@
 "use strict";
 
 add_task(async function test_policy_disable_telemetry() {
-  const { TelemetryReportingPolicy } = ChromeUtils.import(
-    "resource://gre/modules/TelemetryReportingPolicy.jsm"
+  const { TelemetryReportingPolicy } = ChromeUtils.importESModule(
+    "resource://gre/modules/TelemetryReportingPolicy.sys.mjs"
   );
 
   ok(TelemetryReportingPolicy, "TelemetryReportingPolicy exists");
@@ -23,4 +23,6 @@ add_task(async function test_policy_disable_telemetry() {
     false,
     "Telemetry archive should be disabled."
   );
+
+  await testPageBlockedByPolicy("about:telemetry");
 });
