@@ -7,10 +7,8 @@ const BASE_URL =
   "http://mochi.test:8888/browser/browser/components/enterprisepolicies/tests/browser";
 
 async function isExtensionLocked(win, addonID) {
-  let addonCard = await BrowserTestUtils.waitForCondition(async () => {
-    let doc = win.getHtmlBrowser().contentDocument;
-    await win.htmlBrowserLoaded;
-    return doc.querySelector(`addon-card[addon-id="${addonID}"]`);
+  let addonCard = await TestUtils.waitForCondition(() => {
+    return win.document.querySelector(`addon-card[addon-id="${addonID}"]`);
   }, `Get addon-card for "${addonID}"`);
   let disableBtn = addonCard.querySelector('[action="toggle-disabled"]');
   let removeBtn = addonCard.querySelector('panel-item[action="remove"]');
@@ -19,7 +17,7 @@ async function isExtensionLocked(win, addonID) {
 }
 
 add_task(async function test_addon_install() {
-  let installPromise = wait_for_addon_install();
+  let installPromise = waitForAddonInstall(ADDON_ID);
   await setupPolicyEngineWithJson({
     policies: {
       Extensions: {
@@ -42,7 +40,7 @@ add_task(async function test_addon_install() {
 
 add_task(async function test_addon_locked() {
   let tab = await BrowserTestUtils.openNewForegroundTab(gBrowser);
-  const win = await BrowserOpenAddonsMgr("addons://list/extension");
+  const win = await BrowserAddonUI.openAddonsMgr("addons://list/extension");
 
   await isExtensionLocked(win, ADDON_ID);
 
@@ -53,8 +51,8 @@ add_task(async function test_addon_reinstall() {
   // Test that uninstalling and reinstalling the same addon ID works as expected.
   // This can be used to update an addon.
 
-  let uninstallPromise = wait_for_addon_uninstall();
-  let installPromise = wait_for_addon_install();
+  let uninstallPromise = waitForAddonUninstall(ADDON_ID);
+  let installPromise = waitForAddonInstall(ADDON_ID);
   await setupPolicyEngineWithJson({
     policies: {
       Extensions: {
@@ -82,7 +80,7 @@ add_task(async function test_addon_reinstall() {
 add_task(async function test_addon_uninstall() {
   EnterprisePolicyTesting.resetRunOnceState();
 
-  let uninstallPromise = wait_for_addon_uninstall();
+  let uninstallPromise = waitForAddonUninstall(ADDON_ID);
   await setupPolicyEngineWithJson({
     policies: {
       Extensions: {
@@ -99,7 +97,7 @@ add_task(async function test_addon_download_failure() {
   // Test that if the download fails, the runOnce pref
   // is cleared so that the download will happen again.
 
-  let installPromise = wait_for_addon_install();
+  let installPromise = waitForAddonInstall(ADDON_ID);
   await setupPolicyEngineWithJson({
     policies: {
       Extensions: {
@@ -117,38 +115,3 @@ add_task(async function test_addon_download_failure() {
     "runOnce pref should be unset"
   );
 });
-
-function wait_for_addon_install() {
-  return new Promise(resolve => {
-    let listener = {
-      onInstallEnded(install, addon) {
-        if (addon.id == ADDON_ID) {
-          AddonManager.removeInstallListener(listener);
-          resolve();
-        }
-      },
-      onDownloadFailed() {
-        AddonManager.removeInstallListener(listener);
-        resolve();
-      },
-      onInstallFailed() {
-        AddonManager.removeInstallListener(listener);
-        resolve();
-      },
-    };
-    AddonManager.addInstallListener(listener);
-  });
-}
-
-function wait_for_addon_uninstall() {
-  return new Promise(resolve => {
-    let listener = {};
-    listener.onUninstalled = addon => {
-      if (addon.id == ADDON_ID) {
-        AddonManager.removeAddonListener(listener);
-        resolve();
-      }
-    };
-    AddonManager.addAddonListener(listener);
-  });
-}
