@@ -6,25 +6,19 @@
 
 "use strict";
 
-ChromeUtils.defineModuleGetter(
-  this,
-  "PrivateBrowsingUtils",
-  "resource://gre/modules/PrivateBrowsingUtils.jsm"
-);
-
-ChromeUtils.defineModuleGetter(
-  this,
-  "PlacesUtils",
-  "resource://gre/modules/PlacesUtils.jsm"
-);
+ChromeUtils.defineESModuleGetters(this, {
+  ExtensionMenus: "resource://gre/modules/ExtensionMenus.sys.mjs",
+  PlacesUtils: "resource://gre/modules/PlacesUtils.sys.mjs",
+  PrivateBrowsingUtils: "resource://gre/modules/PrivateBrowsingUtils.sys.mjs",
+});
 
 var { DefaultMap, ExtensionError, parseMatchPatterns } = ExtensionUtils;
 
-var { ExtensionParent } = ChromeUtils.import(
-  "resource://gre/modules/ExtensionParent.jsm"
+var { ExtensionParent } = ChromeUtils.importESModule(
+  "resource://gre/modules/ExtensionParent.sys.mjs"
 );
 
-var { IconDetails, StartupCache } = ExtensionParent;
+var { IconDetails } = ExtensionParent;
 
 const ACTION_MENU_TOP_LEVEL_LIMIT = 6;
 
@@ -33,12 +27,6 @@ const ACTION_MENU_TOP_LEVEL_LIMIT = 6;
 // this cannot be a weak map.
 var gMenuMap = new Map();
 
-// Map[Extension -> Map[ID -> MenuCreateProperties]]
-// The map object for each extension is a reference to the same
-// object in StartupCache.menus.  This provides a non-async
-// getter for that object.
-var gStartupCache = new Map();
-
 // Map[Extension -> MenuItem]
 var gRootItems = new Map();
 
@@ -166,11 +154,8 @@ var gMenuBuilder = {
         );
       }
     } else if (contextData.webExtContextData) {
-      let {
-        extensionId,
-        showDefaults,
-        overrideContext,
-      } = contextData.webExtContextData;
+      let { extensionId, showDefaults, overrideContext } =
+        contextData.webExtContextData;
       if (extensionId === root.extension.id) {
         rootElements = this.buildTopLevelElements(
           root,
@@ -322,7 +307,7 @@ var gMenuBuilder = {
     return this.customizeElement(element, item, contextData);
   },
 
-  createMenuElement(doc, item) {
+  createMenuElement(doc) {
     let element = doc.createXULElement("menu");
     // Menu elements need to have a menupopup child for its menu items.
     let menupopup = doc.createXULElement("menupopup");
@@ -502,7 +487,7 @@ var gMenuBuilder = {
       element.setAttribute("class", "menuitem-iconic");
     }
 
-    element.setAttribute("image", resolvedURL);
+    element.setAttribute("image", ChromeUtils.encodeURIForSrcset(resolvedURL));
   },
 
   // Undo changes from setMenuItemIcon.
@@ -604,7 +589,7 @@ var gMenuBuilder = {
 };
 
 // Called from pageAction or browserAction popup.
-global.actionContextMenu = function(contextData) {
+global.actionContextMenu = function (contextData) {
   contextData.tab = tabTracker.activeTab;
   contextData.pageUrl = contextData.tab.linkedBrowser.currentURI.spec;
   gMenuBuilder.build(contextData);
@@ -737,22 +722,8 @@ class MenuItem {
     }
   }
 
-  static mergeProps(obj, properties) {
-    for (let propName in properties) {
-      if (properties[propName] === null) {
-        // Omitted optional argument.
-        continue;
-      }
-      obj[propName] = properties[propName];
-    }
-
-    if ("icons" in properties && properties.icons === null && obj.icons) {
-      obj.icons = null;
-    }
-  }
-
   setProps(createProperties) {
-    MenuItem.mergeProps(this, createProperties);
+    ExtensionMenus.mergeMenuProperties(this, createProperties);
 
     if (createProperties.documentUrlPatterns != null) {
       this.documentUrlMatchPattern = parseMatchPatterns(
@@ -821,9 +792,7 @@ class MenuItem {
     }
     let menuMap = gMenuMap.get(this.extension);
     if (!menuMap.has(parentId)) {
-      throw new ExtensionError(
-        `Could not find any MenuItem with id: ${parentId}`
-      );
+      throw new ExtensionError(`Cannot find menu item with id ${parentId}`);
     }
     for (let item = menuMap.get(parentId); item; item = item.parent) {
       if (item === this) {
@@ -834,24 +803,6 @@ class MenuItem {
     }
   }
 
-  /**
-   * When updating menu properties we need to ensure parents exist
-   * in the cache map before children.  That allows the menus to be
-   * created in the correct sequence on startup.  This reparents the
-   * tree starting from this instance of MenuItem.
-   */
-  reparentInCache() {
-    let { id, extension } = this;
-    let cachedMap = gStartupCache.get(extension);
-    let createProperties = cachedMap.get(id);
-    cachedMap.delete(id);
-    cachedMap.set(id, createProperties);
-
-    for (let child of this.children) {
-      child.reparentInCache();
-    }
-  }
-
   set parentId(parentId) {
     this.ensureValidParentId(parentId);
 
@@ -902,6 +853,12 @@ class MenuItem {
     return gRootItems.get(extension);
   }
 
+  get descendantIds() {
+    return this.children
+      ? this.children.flatMap(m => [m.id, ...m.descendantIds])
+      : [];
+  }
+
   remove() {
     if (this.parent) {
       this.parent.detachChild(this);
@@ -913,10 +870,6 @@ class MenuItem {
 
     let menuMap = gMenuMap.get(this.extension);
     menuMap.delete(this.id);
-    // Menu items are saved if !extension.persistentBackground.
-    if (gStartupCache.get(this.extension)?.delete(this.id)) {
-      StartupCache.save();
-    }
     if (this.root == this) {
       gRootItems.delete(this.extension);
     }
@@ -1094,7 +1047,7 @@ const menuTracker = {
     libraryTracker.uninit(this.cleanupLibrary);
   },
 
-  observe(subject, topic, data) {
+  observe(subject) {
     subject = subject.wrappedJSObject;
     gMenuBuilder.build(subject);
   },
@@ -1110,11 +1063,11 @@ const menuTracker = {
     );
     sidebarHeader.addEventListener("SidebarShown", menuTracker.onSidebarShown);
 
-    await window.SidebarUI.promiseInitialized;
+    await window.SidebarController.promiseInitialized;
 
     if (
       !window.closed &&
-      window.SidebarUI.currentID === "viewBookmarksSidebar"
+      window.SidebarController.currentID === "viewBookmarksSidebar"
     ) {
       menuTracker.onSidebarShown({ currentTarget: sidebarHeader });
     }
@@ -1131,12 +1084,11 @@ const menuTracker = {
     );
     sidebarHeader.removeEventListener("SidebarShown", this.onSidebarShown);
 
-    if (window.SidebarUI.currentID === "viewBookmarksSidebar") {
-      let sidebarBrowser = window.SidebarUI.browser;
+    if (window.SidebarController.currentID === "viewBookmarksSidebar") {
+      let sidebarBrowser = window.SidebarController.browser;
       sidebarBrowser.removeEventListener("load", this.onSidebarShown);
-      const menu = sidebarBrowser.contentDocument.getElementById(
-        "placesContext"
-      );
+      const menu =
+        sidebarBrowser.contentDocument.getElementById("placesContext");
       menu.removeEventListener("popupshowing", this.onBookmarksContextMenu);
     }
   },
@@ -1145,10 +1097,10 @@ const menuTracker = {
     // The event target is an element in a browser window, so |window| will be
     // the browser window that contains the sidebar.
     const window = event.currentTarget.ownerGlobal;
-    if (window.SidebarUI.currentID === "viewBookmarksSidebar") {
-      let sidebarBrowser = window.SidebarUI.browser;
+    if (window.SidebarController.currentID === "viewBookmarksSidebar") {
+      let sidebarBrowser = window.SidebarController.browser;
       if (sidebarBrowser.contentDocument.readyState !== "complete") {
-        // SidebarUI.currentID may be updated before the bookmark sidebar's
+        // SidebarController.currentID may be updated before the bookmark sidebar's
         // document has finished loading. This sometimes happens when the
         // sidebar is automatically shown when a new window is opened.
         sidebarBrowser.addEventListener("load", menuTracker.onSidebarShown, {
@@ -1156,9 +1108,8 @@ const menuTracker = {
         });
         return;
       }
-      const menu = sidebarBrowser.contentDocument.getElementById(
-        "placesContext"
-      );
+      const menu =
+        sidebarBrowser.contentDocument.getElementById("placesContext");
       menu.addEventListener("popupshowing", menuTracker.onBookmarksContextMenu);
     }
   },
@@ -1219,6 +1170,8 @@ const menuTracker = {
 };
 
 this.menusInternal = class extends ExtensionAPIPersistent {
+  #promiseInitialized = null;
+
   constructor(extension) {
     super(extension);
 
@@ -1228,36 +1181,57 @@ this.menusInternal = class extends ExtensionAPIPersistent {
     gMenuMap.set(extension, new Map());
   }
 
-  restoreFromCache() {
+  async initExtensionMenus() {
     let { extension } = this;
-    // ensure extension has not shutdown
-    if (!this.extension) {
+
+    await ExtensionMenus.asyncInitForExtension(extension);
+
+    if (
+      extension.hasShutdown ||
+      !ExtensionMenus.shouldPersistMenus(extension)
+    ) {
       return;
     }
-    for (let createProperties of gStartupCache.get(extension).values()) {
-      // The order of menu creation is significant, see reparentInCache.
-      let menuItem = new MenuItem(extension, createProperties);
-      gMenuMap.get(extension).set(menuItem.id, menuItem);
-    }
+
     // Used for testing
-    extension.emit("webext-menus-created", gMenuMap.get(extension));
+    const notifyMenusCreated = () =>
+      extension.emit("webext-menus-created", gMenuMap.get(extension));
+
+    const menus = ExtensionMenus.getMenus(extension);
+    if (!menus.size) {
+      notifyMenusCreated();
+      return;
+    }
+
+    let createErrorMenuIds = [];
+    for (let createProperties of menus.values()) {
+      // The order of menu creation is significant:
+      // When creating and reparenting the menu we ensure parents exist
+      // in the persisted menus map before children.  That allows the
+      // menus to be recreated in the correct sequence on startup.
+      //
+      // For details, see ExtensionMenusManager's updateMenus in
+      // ExtensionMenus.sys.mjs
+      try {
+        let menuItem = new MenuItem(extension, createProperties);
+        gMenuMap.get(extension).set(menuItem.id, menuItem);
+      } catch (err) {
+        Cu.reportError(
+          `Unexpected error on recreating persisted menu ${createProperties?.id} for ${extension.id}: ${err}`
+        );
+        createErrorMenuIds.push(createProperties.id);
+      }
+    }
+
+    if (createErrorMenuIds.length) {
+      ExtensionMenus.deleteMenus(extension, createErrorMenuIds);
+    }
+
+    notifyMenusCreated();
   }
 
-  async onStartup() {
-    let { extension } = this;
-    if (extension.persistentBackground) {
-      return;
-    }
-    // Using the map retains insertion order.
-    let cachedMenus = await StartupCache.menus.get(extension.id, () => {
-      return new Map();
-    });
-    gStartupCache.set(extension, cachedMenus);
-    if (!cachedMenus.size) {
-      return;
-    }
-
-    this.restoreFromCache();
+  onStartup() {
+    this.#promiseInitialized = this.initExtensionMenus();
   }
 
   onShutdown() {
@@ -1267,7 +1241,6 @@ this.menusInternal = class extends ExtensionAPIPersistent {
       gMenuMap.delete(extension);
       gRootItems.delete(extension);
       gShownMenuItems.delete(extension);
-      gStartupCache.delete(extension);
       gOnShownSubscribers.delete(extension);
       if (!gMenuMap.size) {
         menuTracker.unregister();
@@ -1395,9 +1368,14 @@ this.menusInternal = class extends ExtensionAPIPersistent {
       contextMenus: menus,
       menus,
       menusInternal: {
-        create(createProperties) {
+        create: async createProperties => {
+          await this.#promiseInitialized;
+          if (extension.hasShutdown) {
+            return;
+          }
+
           // event pages require id
-          if (!extension.persistentBackground) {
+          if (ExtensionMenus.shouldPersistMenus(extension)) {
             if (!createProperties.id) {
               throw new ExtensionError(
                 "menus.create requires an id for non-persistent background scripts."
@@ -1413,61 +1391,54 @@ this.menusInternal = class extends ExtensionAPIPersistent {
           // Note that the id is required by the schema. If the addon did not set
           // it, the implementation of menus.create in the child will add it for
           // extensions with persistent backgrounds, but not otherwise.
+
           let menuItem = new MenuItem(extension, createProperties);
+          ExtensionMenus.addMenu(extension, createProperties);
           gMenuMap.get(extension).set(menuItem.id, menuItem);
-          if (!extension.persistentBackground) {
-            // Only cache properties that are necessary.
-            let cached = {};
-            MenuItem.mergeProps(cached, createProperties);
-            gStartupCache.get(extension).set(menuItem.id, cached);
-            StartupCache.save();
-          }
         },
 
-        update(id, updateProperties) {
+        update: async (id, updateProperties) => {
+          await this.#promiseInitialized;
+          if (extension.hasShutdown) {
+            return;
+          }
+
           let menuItem = gMenuMap.get(extension).get(id);
           if (!menuItem) {
-            return;
+            throw new ExtensionError(`Cannot find menu item with id ${id}`);
           }
+
           menuItem.setProps(updateProperties);
+          ExtensionMenus.updateMenu(extension, id, updateProperties);
+        },
 
-          // Update the startup cache for non-persistent extensions.
-          if (extension.persistentBackground) {
+        remove: async id => {
+          await this.#promiseInitialized;
+          if (extension.hasShutdown) {
             return;
           }
 
-          let cached = gStartupCache.get(extension).get(id);
-          let reparent =
-            updateProperties.parentId != null &&
-            cached.parentId != updateProperties.parentId;
-          MenuItem.mergeProps(cached, updateProperties);
-          if (reparent) {
-            // The order of menu creation is significant, see reparentInCache.
-            menuItem.reparentInCache();
-          }
-          StartupCache.save();
-        },
-
-        remove(id) {
           let menuItem = gMenuMap.get(extension).get(id);
-          if (menuItem) {
-            menuItem.remove();
+          if (!menuItem) {
+            throw new ExtensionError(`Cannot find menu item with id ${id}`);
           }
+
+          const menuIds = [menuItem.id, ...menuItem.descendantIds];
+          menuItem.remove();
+          ExtensionMenus.deleteMenus(extension, menuIds);
         },
 
-        removeAll() {
+        removeAll: async () => {
+          await this.#promiseInitialized;
+          if (extension.hasShutdown) {
+            return;
+          }
+
           let root = gRootItems.get(extension);
           if (root) {
             root.remove();
           }
-          // Should be empty, just extra assurance.
-          if (!extension.persistentBackground) {
-            let cached = gStartupCache.get(extension);
-            if (cached.size) {
-              cached.clear();
-              StartupCache.save();
-            }
-          }
+          ExtensionMenus.deleteAllMenus(extension);
         },
 
         onClicked: new EventManager({
