@@ -7,6 +7,10 @@
 
 "use strict";
 
+ChromeUtils.defineESModuleGetters(this, {
+  SearchUIUtils: "moz-src:///browser/components/search/SearchUIUtils.sys.mjs",
+});
+
 var { ExtensionError } = ExtensionUtils;
 
 const dispositionMap = {
@@ -35,27 +39,26 @@ this.search = class extends ExtensionAPI {
     return {
       search: {
         async get() {
-          await searchInitialized;
+          await Services.search.promiseInitialized;
           let visibleEngines = await Services.search.getVisibleEngines();
           let defaultEngine = await Services.search.getDefault();
           return Promise.all(
             visibleEngines.map(async engine => {
-              let favIconUrl;
-              if (engine.iconURI) {
-                // Convert moz-extension:-URLs to data:-URLs to make sure that
-                // extensions can see icons from other extensions, even if they
-                // are not web-accessible.
-                // Also prevents leakage of extension UUIDs to other extensions..
-                if (
-                  engine.iconURI.schemeIs("moz-extension") &&
-                  engine.iconURI.host !== context.extension.uuid
-                ) {
-                  favIconUrl = await ExtensionUtils.makeDataURI(
-                    engine.iconURI.spec
-                  );
-                } else {
-                  favIconUrl = engine.iconURI.spec;
-                }
+              let favIconUrl = await engine.getIconURL();
+              // Convert blob:-URLs to data:-URLs since they can't be shared
+              // across processes. blob:-URLs originate from application provided
+              // search engines.
+              // Also convert moz-extension:-URLs to data:-URLs to make sure that
+              // extensions can see icons from other extensions, even if they
+              // are not web-accessible.
+              // Also prevents leakage of extension UUIDs to other extensions..
+              if (
+                favIconUrl &&
+                (favIconUrl.startsWith("blob:") ||
+                  (ExtensionUtils.isExtensionUrl(favIconUrl) &&
+                    !favIconUrl.startsWith(context.extension.baseURL)))
+              ) {
+                favIconUrl = await ExtensionUtils.makeDataURI(favIconUrl);
               }
 
               return {
@@ -69,7 +72,7 @@ this.search = class extends ExtensionAPI {
         },
 
         async search(searchProperties) {
-          await searchInitialized;
+          await Services.search.promiseInitialized;
           let engine;
 
           if (searchProperties.engine) {
@@ -87,7 +90,8 @@ this.search = class extends ExtensionAPI {
             defaultDisposition: "NEW_TAB",
           });
 
-          await windowTracker.topWindow.BrowserSearch.loadSearchFromExtension({
+          await SearchUIUtils.loadSearchFromExtension({
+            window: windowTracker.topWindow,
             query: searchProperties.query,
             where,
             engine,
@@ -97,7 +101,7 @@ this.search = class extends ExtensionAPI {
         },
 
         async query(queryProperties) {
-          await searchInitialized;
+          await Services.search.promiseInitialized;
 
           let { tab, where } = getTarget({
             tabId: queryProperties.tabId,
@@ -105,7 +109,8 @@ this.search = class extends ExtensionAPI {
             defaultDisposition: "CURRENT_TAB",
           });
 
-          await windowTracker.topWindow.BrowserSearch.loadSearchFromExtension({
+          await SearchUIUtils.loadSearchFromExtension({
+            window: windowTracker.topWindow,
             query: queryProperties.text,
             where,
             tab,
