@@ -65,7 +65,9 @@ add_task(async function test_permissions() {
 add_task(async function test_actionContextMenus() {
   const manifest = {
     page_action: {},
-    browser_action: {},
+    browser_action: {
+      default_area: "navbar",
+    },
     permissions: ["menus"],
   };
 
@@ -153,6 +155,17 @@ add_task(async function test_actionContextMenus() {
 });
 
 add_task(async function test_bookmarkContextMenu() {
+  info("Adding a bookmark to the bookmarks toolbar.");
+  let addedBookmark = await PlacesUtils.bookmarks.insert({
+    parentGuid: PlacesUtils.bookmarks.toolbarGuid,
+    title: "Test",
+    url: "https://example.com",
+  });
+
+  registerCleanupFunction(async () => {
+    await PlacesUtils.bookmarks.remove(addedBookmark);
+  });
+
   const ext = ExtensionTestUtils.loadExtension({
     manifest: {
       permissions: ["menus", "bookmarks"],
@@ -343,7 +356,7 @@ add_task(async function test_multiple_contexts_init() {
   const files = {
     "tab.html":
       "<!DOCTYPE html><meta charset=utf-8><script src=tab.js></script>",
-    "tab.js": function() {
+    "tab.js": function () {
       browser.menus.onClicked.addListener(info => {
         browser.test.sendMessage("click", info);
       });
