@@ -3,12 +3,8 @@
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 "use strict";
 
-const { GlobalManager } = ChromeUtils.import(
-  "resource://gre/modules/Extension.jsm",
-  null
-);
-const { ExtensionPermissions } = ChromeUtils.import(
-  "resource://gre/modules/ExtensionPermissions.jsm"
+const { ExtensionPermissions } = ChromeUtils.importESModule(
+  "resource://gre/modules/ExtensionPermissions.sys.mjs"
 );
 
 const PAGE =
@@ -19,97 +15,145 @@ const PAGE_HOST_PATTERN = "http://mochi.test/*";
 const EXPECT_TARGET_ELEMENT = 13337;
 
 async function grantOptionalPermission(extension, permissions) {
-  let ext = GlobalManager.extensionMap.get(extension.id);
+  let ext = WebExtensionPolicy.getByID(extension.id).extension;
   return ExtensionPermissions.add(extension.id, permissions, ext);
 }
 
+var someOtherTab, testTab;
+
+add_setup(async function () {
+  await SpecialPowers.pushPrefEnv({
+    set: [["extensions.manifestV3.enabled", true]],
+  });
+
+  // To help diagnose an intermittent later.
+  SimpleTest.requestCompleteLog();
+
+  // Setup the test tab now, rather than for each test
+  someOtherTab = gBrowser.selectedTab;
+  testTab = await BrowserTestUtils.openNewForegroundTab(gBrowser, PAGE);
+  registerCleanupFunction(() => BrowserTestUtils.removeTab(testTab));
+});
+
 // Registers a context menu using menus.create(menuCreateParams) and checks
 // whether the menus.onShown and menus.onHidden events are fired as expected.
 // doOpenMenu must open the menu and its returned promise must resolve after the
 // menu is shown. Similarly, doCloseMenu must hide the menu.
 async function testShowHideEvent({
   menuCreateParams,
+  id,
   doOpenMenu,
   doCloseMenu,
   expectedShownEvent,
   expectedShownEventWithPermissions = null,
+  forceTabToBackground = false,
+  manifest_version = 2,
 }) {
-  async function background() {
-    function awaitMessage(expectedId) {
-      return new Promise(resolve => {
-        browser.test.log(`Waiting for message: ${expectedId}`);
-        browser.test.onMessage.addListener(function listener(id, msg) {
-          // Temporary work-around for https://bugzil.la/1428213
-          // TODO Bug 1428213: remove workaround for onMessage.removeListener
-          if (listener._wasCalled) {
-            return;
-          }
-          listener._wasCalled = true;
-          browser.test.assertEq(expectedId, id, "Expected message");
-          browser.test.onMessage.removeListener(listener);
-          resolve(msg);
-        });
-      });
-    }
-
-    let menuCreateParams = await awaitMessage("create-params");
+  async function background(menu_create_params) {
     const [tab] = await browser.tabs.query({
       active: true,
       currentWindow: true,
     });
+    if (browser.pageAction) {
+      await browser.pageAction.show(tab.id);
+    }
 
     let shownEvents = [];
     let hiddenEvents = [];
 
     browser.menus.onShown.addListener((...args) => {
-      if (args[0].targetElementId) {
+      browser.test.log(`==> onShown args ${JSON.stringify(args)}`);
+      let [info, shownTab] = args;
+      if (info.targetElementId) {
         // In this test, we aren't interested in the exact value,
         // only in whether it is set or not.
-        args[0].targetElementId = 13337; // = EXPECT_TARGET_ELEMENT
+        info.targetElementId = 13337; // = EXPECT_TARGET_ELEMENT
       }
-      shownEvents.push(args[0]);
-      if (menuCreateParams.title.includes("TEST_EXPECT_NO_TAB")) {
-        browser.test.assertEq(undefined, args[1], "expect no tab");
+      shownEvents.push(info);
+
+      if (menu_create_params.title.includes("TEST_EXPECT_NO_TAB")) {
+        browser.test.assertEq(undefined, shownTab, "expect no tab");
       } else {
-        browser.test.assertEq(tab.id, args[1].id, "expected tab");
+        browser.test.assertEq(tab.id, shownTab?.id, "expected tab");
       }
       browser.test.assertEq(2, args.length, "expected number of onShown args");
     });
     browser.menus.onHidden.addListener(event => hiddenEvents.push(event));
 
-    await browser.pageAction.show(tab.id);
-
-    let menuId;
-    await new Promise(resolve => {
-      menuId = browser.menus.create(menuCreateParams, resolve);
+    browser.test.onMessage.addListener(async msg => {
+      switch (msg) {
+        case "register-menu":
+          let menuId;
+          await new Promise(resolve => {
+            menuId = browser.menus.create(menu_create_params, resolve);
+          });
+          browser.test.assertEq(
+            0,
+            shownEvents.length,
+            "no onShown before menu"
+          );
+          browser.test.assertEq(
+            0,
+            hiddenEvents.length,
+            "no onHidden before menu"
+          );
+          browser.test.sendMessage("menu-registered", menuId);
+          break;
+        case "assert-menu-shown":
+          browser.test.assertEq(1, shownEvents.length, "expected onShown");
+          browser.test.assertEq(
+            0,
+            hiddenEvents.length,
+            "no onHidden before closing"
+          );
+          browser.test.sendMessage("onShown-event-data", shownEvents[0]);
+          break;
+        case "assert-menu-hidden":
+          browser.test.assertEq(
+            1,
+            shownEvents.length,
+            "expected no more onShown"
+          );
+          browser.test.assertEq(1, hiddenEvents.length, "expected onHidden");
+          browser.test.sendMessage("onHidden-event-data", hiddenEvents[0]);
+          break;
+        case "optional-menu-shown-with-permissions":
+          browser.test.assertEq(
+            2,
+            shownEvents.length,
+            "expected second onShown"
+          );
+          browser.test.sendMessage("onShown-event-data2", shownEvents[1]);
+          break;
+      }
     });
-    browser.test.assertEq(0, shownEvents.length, "no onShown before menu");
-    browser.test.assertEq(0, hiddenEvents.length, "no onHidden before menu");
-    browser.test.sendMessage("menu-registered", menuId);
 
-    await awaitMessage("assert-menu-shown");
-    browser.test.assertEq(1, shownEvents.length, "expected onShown");
-    browser.test.assertEq(0, hiddenEvents.length, "no onHidden before closing");
-    browser.test.sendMessage("onShown-event-data", shownEvents[0]);
-
-    await awaitMessage("assert-menu-hidden");
-    browser.test.assertEq(1, shownEvents.length, "expected no more onShown");
-    browser.test.assertEq(1, hiddenEvents.length, "expected onHidden");
-    browser.test.sendMessage("onHidden-event-data", hiddenEvents[0]);
-
-    await awaitMessage("optional-menu-shown-with-permissions");
-    browser.test.assertEq(2, shownEvents.length, "expected second onShown");
-    browser.test.sendMessage("onShown-event-data2", shownEvents[1]);
+    browser.test.sendMessage("ready");
   }
 
-  const tab = await BrowserTestUtils.openNewForegroundTab(gBrowser, PAGE);
+  // Tab must initially open as a foreground tab, because the test extension
+  // looks for the active tab.
+  if (gBrowser.selectedTab != testTab) {
+    await BrowserTestUtils.switchTab(gBrowser, testTab);
+  }
 
+  let useAddonManager, browser_specific_settings;
+  const action = manifest_version < 3 ? "browser_action" : "action";
+  // hook up AOM so event pages in MV3 work.
+  if (manifest_version > 2) {
+    browser_specific_settings = { gecko: { id } };
+    useAddonManager = "temporary";
+  }
   let extension = ExtensionTestUtils.loadExtension({
-    background,
+    background: `(${background})(${JSON.stringify(menuCreateParams)})`,
+    useAddonManager,
     manifest: {
+      manifest_version,
+      browser_specific_settings,
       page_action: {},
-      browser_action: {
+      [action]: {
         default_popup: "popup.html",
+        default_area: "navbar",
       },
       permissions: ["menus"],
       optional_permissions: [PAGE_HOST_PATTERN],
@@ -119,10 +163,16 @@ async function testShowHideEvent({
     },
   });
   await extension.startup();
-  extension.sendMessage("create-params", menuCreateParams);
+  await extension.awaitMessage("ready");
+  extension.sendMessage("register-menu");
   let menuId = await extension.awaitMessage("menu-registered");
+  info(`menu registered ${menuId}`);
 
-  await doOpenMenu(extension);
+  if (forceTabToBackground && gBrowser.selectedTab != someOtherTab) {
+    await BrowserTestUtils.switchTab(gBrowser, someOtherTab);
+  }
+
+  await doOpenMenu(extension, testTab);
   extension.sendMessage("assert-menu-shown");
   let shownEvent = await extension.awaitMessage("onShown-event-data");
 
@@ -141,7 +191,7 @@ async function testShowHideEvent({
       permissions: [],
       origins: [PAGE_HOST_PATTERN],
     });
-    await doOpenMenu(extension);
+    await doOpenMenu(extension, testTab);
     extension.sendMessage("optional-menu-shown-with-permissions");
     let shownEvent2 = await extension.awaitMessage("onShown-event-data2");
     Assert.deepEqual(
@@ -153,7 +203,6 @@ async function testShowHideEvent({
   }
 
   await extension.unload();
-  BrowserTestUtils.removeTab(tab);
 }
 
 // Make sure that we won't trigger onShown when extensions cannot add menus.
@@ -280,6 +329,35 @@ add_task(async function test_show_hide_pageAction() {
   });
 });
 
+add_task(async function test_show_hide_pageAction_v3() {
+  await testShowHideEvent({
+    manifest_version: 3,
+    id: "page-action@mochitest",
+    menuCreateParams: {
+      id: "page_action_item",
+      title: "pageAction item",
+      contexts: ["page_action"],
+    },
+    expectedShownEvent: {
+      contexts: ["page_action", "all"],
+      viewType: undefined,
+      editable: false,
+    },
+    expectedShownEventWithPermissions: {
+      contexts: ["page_action", "all"],
+      viewType: undefined,
+      editable: false,
+      pageUrl: PAGE,
+    },
+    async doOpenMenu(extension) {
+      await openActionContextMenu(extension, "page");
+    },
+    async doCloseMenu() {
+      await closeActionContextMenu(null, "page");
+    },
+  });
+});
+
 add_task(async function test_show_hide_browserAction() {
   await testShowHideEvent({
     menuCreateParams: {
@@ -306,6 +384,35 @@ add_task(async function test_show_hide_browserAction() {
   });
 });
 
+add_task(async function test_show_hide_browserAction_v3() {
+  await testShowHideEvent({
+    manifest_version: 3,
+    id: "browser-action@mochitest",
+    menuCreateParams: {
+      id: "action_item",
+      title: "Action item",
+      contexts: ["action"],
+    },
+    expectedShownEvent: {
+      contexts: ["action", "all"],
+      viewType: undefined,
+      editable: false,
+    },
+    expectedShownEventWithPermissions: {
+      contexts: ["action", "all"],
+      viewType: undefined,
+      editable: false,
+      pageUrl: PAGE,
+    },
+    async doOpenMenu(extension) {
+      await openActionContextMenu(extension, "browser");
+    },
+    async doCloseMenu() {
+      await closeActionContextMenu();
+    },
+  });
+});
+
 add_task(async function test_show_hide_browserAction_popup() {
   let popupUrl;
   await testShowHideEvent({
@@ -345,8 +452,57 @@ add_task(async function test_show_hide_browserAction_popup() {
   });
 });
 
-add_task(async function test_show_hide_tab() {
+add_task(async function test_show_hide_browserAction_popup_v3() {
+  let popupUrl;
   await testShowHideEvent({
+    manifest_version: 3,
+    id: "browser-action-popup@mochitest",
+    menuCreateParams: {
+      id: "action_popup",
+      title: "Action popup - TEST_EXPECT_NO_TAB",
+      contexts: ["all", "action"],
+    },
+    expectedShownEvent: {
+      contexts: ["page", "all"],
+      viewType: "popup",
+      frameId: 0,
+      editable: false,
+      get pageUrl() {
+        return popupUrl;
+      },
+      targetElementId: EXPECT_TARGET_ELEMENT,
+    },
+    expectedShownEventWithPermissions: {
+      contexts: ["page", "all"],
+      viewType: "popup",
+      frameId: 0,
+      editable: false,
+      get pageUrl() {
+        return popupUrl;
+      },
+      targetElementId: EXPECT_TARGET_ELEMENT,
+    },
+    async doOpenMenu(extension) {
+      popupUrl = `moz-extension://${extension.uuid}/popup.html`;
+      await clickBrowserAction(extension);
+      await openContextMenuInPopup(extension);
+    },
+    async doCloseMenu(extension) {
+      await closeExtensionContextMenu();
+      await closeBrowserAction(extension);
+    },
+  });
+});
+
+// Common code used by test_show_hide_tab and test_show_hide_tab_via_tab_panel.
+async function testShowHideTabMenu({
+  doOpenTabContextMenu,
+  doCloseTabContextMenu,
+}) {
+  await testShowHideEvent({
+    // To verify that the event matches the contextmenu target, switch to
+    // an unrelated tab before opening a contextmenu on the desired tab.
+    forceTabToBackground: true,
     menuCreateParams: {
       title: "tab menu item",
       contexts: ["tab"],
@@ -362,15 +518,80 @@ add_task(async function test_show_hide_tab() {
       editable: false,
       pageUrl: PAGE,
     },
-    async doOpenMenu() {
-      await openTabContextMenu();
+    async doOpenMenu(extension, contextTab) {
+      await doOpenTabContextMenu(contextTab);
     },
     async doCloseMenu() {
+      await doCloseTabContextMenu();
+    },
+  });
+}
+
+add_task(async function test_show_hide_tab() {
+  await testShowHideTabMenu({
+    async doOpenTabContextMenu(contextTab) {
+      await openTabContextMenu(contextTab);
+    },
+    async doCloseTabContextMenu() {
       await closeTabContextMenu();
     },
   });
 });
 
+// Checks that right-clicking on a tab in the all-tabs panel
+// results in an event that is associated with the expected tab.
+add_task(async function test_show_hide_tab_via_tab_panel() {
+  /**
+   * @see TabsList.sys.mjs#getTabFromRow
+   * @param {XulToolbarItem} row
+   * @returns {MozTabbrowserTab}
+   */
+  function tabOf(row) {
+    return row._tab;
+  }
+
+  gTabsPanel.init();
+  const allTabsView = document.getElementById("allTabsMenu-allTabsView");
+
+  await testShowHideTabMenu({
+    async doOpenTabContextMenu(contextTab) {
+      // Show the tabs panel.
+      let allTabsPopupShownPromise = BrowserTestUtils.waitForEvent(
+        allTabsView,
+        "ViewShown"
+      );
+      gTabsPanel.showAllTabsPanel();
+      await allTabsPopupShownPromise;
+
+      // Find the menu item that is associated with the given tab
+      let index = Array.prototype.findIndex.call(
+        gTabsPanel.allTabsViewTabs.children,
+        toolbaritem => tabOf(toolbaritem) === contextTab
+      );
+      Assert.notStrictEqual(
+        index,
+        -1,
+        "sanity check: tabs panel has item for the tab"
+      );
+
+      // Finally, open the context menu on it.
+      await openChromeContextMenu(
+        "tabContextMenu",
+        `.all-tabs-item:nth-child(${index + 1})`
+      );
+    },
+    async doCloseTabContextMenu() {
+      await closeTabContextMenu();
+      let allTabsPopupHiddenPromise = BrowserTestUtils.waitForEvent(
+        allTabsView.panelMultiView,
+        "PanelMultiViewHidden"
+      );
+      gTabsPanel.hideAllTabsPanel();
+      await allTabsPopupHiddenPromise;
+    },
+  });
+});
+
 add_task(async function test_show_hide_tools_menu() {
   await testShowHideEvent({
     menuCreateParams: {
@@ -454,19 +675,19 @@ add_task(async function test_show_hide_frame() {
       targetElementId: EXPECT_TARGET_ELEMENT,
     },
     async doOpenMenu() {
-      frameId = await ContentTask.spawn(
+      frameId = await SpecialPowers.spawn(
         gBrowser.selectedBrowser,
-        {},
-        function() {
-          const { WebNavigationFrames } = ChromeUtils.import(
-            "resource://gre/modules/WebNavigationFrames.jsm"
+        [],
+        function () {
+          const { WebNavigationFrames } = ChromeUtils.importESModule(
+            "resource://gre/modules/WebNavigationFrames.sys.mjs"
           );
 
           let { contentWindow } = content.document.getElementById("frame");
           return WebNavigationFrames.getFrameId(contentWindow);
         }
       );
-      await openContextMenuInFrame("#frame");
+      await openContextMenuInFrame();
     },
     async doCloseMenu() {
       await closeExtensionContextMenu();
@@ -595,11 +816,12 @@ add_task(async function test_show_hide_editable_selection() {
     },
     async doOpenMenu() {
       // Select lots of text in the test page before opening the menu.
-      selectionText = await ContentTask.spawn(
+      selectionText = await SpecialPowers.spawn(
         gBrowser.selectedBrowser,
-        {},
-        function() {
+        [],
+        function () {
           let node = content.document.getElementById("editabletext");
+          node.scrollIntoView();
           node.select();
           node.focus();
           return node.value;
@@ -639,15 +861,18 @@ add_task(async function test_show_hide_video() {
       targetElementId: EXPECT_TARGET_ELEMENT,
     },
     async doOpenMenu() {
-      await ContentTask.spawn(gBrowser.selectedBrowser, VIDEO_URL, function(
-        VIDEO_URL
-      ) {
-        let video = content.document.createElement("video");
-        video.controls = true;
-        video.src = VIDEO_URL;
-        content.document.body.appendChild(video);
-        video.focus();
-      });
+      await SpecialPowers.spawn(
+        gBrowser.selectedBrowser,
+        [VIDEO_URL],
+        function (VIDEO_URL) {
+          let video = content.document.createElement("video");
+          video.controls = true;
+          video.src = VIDEO_URL;
+          content.document.body.appendChild(video);
+          video.scrollIntoView();
+          video.focus();
+        }
+      );
 
       await openContextMenu("video");
     },
@@ -682,15 +907,18 @@ add_task(async function test_show_hide_audio() {
       targetElementId: EXPECT_TARGET_ELEMENT,
     },
     async doOpenMenu() {
-      await ContentTask.spawn(gBrowser.selectedBrowser, AUDIO_URL, function(
-        AUDIO_URL
-      ) {
-        let audio = content.document.createElement("audio");
-        audio.controls = true;
-        audio.src = AUDIO_URL;
-        content.document.body.appendChild(audio);
-        audio.focus();
-      });
+      await SpecialPowers.spawn(
+        gBrowser.selectedBrowser,
+        [AUDIO_URL],
+        function (AUDIO_URL) {
+          let audio = content.document.createElement("audio");
+          audio.controls = true;
+          audio.src = AUDIO_URL;
+          content.document.body.appendChild(audio);
+          audio.scrollIntoView();
+          audio.focus();
+        }
+      );
 
       await openContextMenu("audio");
     },
