@@ -2,7 +2,7 @@
 /* vim: set sts=2 sw=2 et tw=80: */
 "use strict";
 
-add_task(async function() {
+add_task(async function () {
   let tab1 = await BrowserTestUtils.openNewForegroundTab(
     gBrowser,
     "about:blank?1"
@@ -209,11 +209,11 @@ add_task(async function() {
   });
 
   extension.onMessage("change-tab", (tabId, attr, on) => {
-    let {
+    const {
       Management: {
         global: { tabTracker },
       },
-    } = ChromeUtils.import("resource://gre/modules/Extension.jsm", null);
+    } = ChromeUtils.importESModule("resource://gre/modules/Extension.sys.mjs");
 
     let tab = tabTracker.getTab(tabId);
 
