@@ -9,21 +9,16 @@ add_task(async function test_onCreated_active() {
       permissions: ["tabs"],
     },
     async background() {
-      let created = false;
-      let tabIds = (await browser.tabs.query({})).map(t => t.id);
       browser.tabs.onCreated.addListener(tab => {
-        created = tab.id;
         browser.tabs.remove(tab.id);
         browser.test.sendMessage("onCreated", tab);
       });
-      // We always get at least one onUpdated event when creating tabs.
-      browser.tabs.onUpdated.addListener((tabId, changes, tab) => {
-        // ignore tabs created prior to extension startup
-        if (tabIds.includes(tabId)) {
-          return;
-        }
-        browser.test.assertTrue(created, tabId, "tab created before updated");
-        browser.test.notifyPass("onUpdated");
+      browser.tabs.onUpdated.addListener((tabId, changes) => {
+        browser.test.assertEq(
+          '["status"]',
+          JSON.stringify(Object.keys(changes)),
+          "Should get no update other than 'status' during tab creation."
+        );
       });
       browser.test.sendMessage("ready");
     },
@@ -31,11 +26,10 @@ add_task(async function test_onCreated_active() {
 
   await extension.startup();
   await extension.awaitMessage("ready");
-  BrowserOpenTab();
+  BrowserCommands.openTab();
 
   let tab = await extension.awaitMessage("onCreated");
   is(true, tab.active, "Tab should be active");
-  await extension.awaitFinish("onUpdated");
 
   await extension.unload();
 });
