@@ -23,7 +23,7 @@ add_task(async function test_filter_url() {
   let ext_perm = ExtensionTestUtils.loadExtension({
     background() {
       browser.tabs.onUpdated.addListener(
-        (tabId, changeInfo) => {
+        () => {
           browser.test.fail(
             `received unexpected onUpdated event without tabs permission`
           );
@@ -73,7 +73,7 @@ add_task(async function test_filter_url_activeTab() {
     },
     background() {
       browser.tabs.onUpdated.addListener(
-        (tabId, changeInfo) => {
+        () => {
           browser.test.fail(
             "should only have notification for activeTab, selectedTab is not activeTab"
           );
@@ -251,6 +251,54 @@ add_task(async function test_filter_windowId() {
   await BrowserTestUtils.removeTab(tab);
 });
 
+add_task(async function test_filter_cookieStoreId() {
+  let ext = ExtensionTestUtils.loadExtension({
+    manifest: {
+      permissions: ["tabs"],
+    },
+    background() {
+      browser.tabs.onUpdated.addListener(
+        async (tabId, changeInfo) => {
+          if (changeInfo.status === "complete") {
+            const tab = await browser.tabs.get(tabId);
+            browser.test.sendMessage("onUpdated", tab);
+          }
+        },
+        { cookieStoreId: "firefox-container-2" }
+      );
+      browser.test.sendMessage("ready");
+    },
+  });
+  await ext.startup();
+  await ext.awaitMessage("ready");
+
+  let tab1 = await BrowserTestUtils.addTab(gBrowser, "about:blank?1", {
+    userContextId: 1,
+  });
+  let tab2 = await BrowserTestUtils.addTab(gBrowser, "about:blank?2", {
+    userContextId: 2,
+  });
+
+  is(tab1.userContextId, 1, "userContextId is the expected value.");
+  is(tab2.userContextId, 2, "userContextId is the expected value.");
+
+  let triggeredTab = await ext.awaitMessage("onUpdated");
+  is(
+    triggeredTab.url,
+    "about:blank?2",
+    "The tab with the correct URL was triggered."
+  );
+  is(
+    triggeredTab.cookieStoreId,
+    "firefox-container-2",
+    "The tab with the correct cookieStoreId was triggered."
+  );
+
+  BrowserTestUtils.removeTab(tab1);
+  BrowserTestUtils.removeTab(tab2);
+  await ext.unload();
+});
+
 add_task(async function test_filter_isArticle() {
   let extension = ExtensionTestUtils.loadExtension({
     manifest: {
