@@ -4,7 +4,7 @@
 
 requestLongerTimeout(2);
 
-add_task(async function() {
+add_task(async function () {
   let tab1 = await BrowserTestUtils.openNewForegroundTab(
     gBrowser,
     "about:robots"
@@ -73,7 +73,7 @@ add_task(async function() {
   );
   let tab3 = await BrowserTestUtils.openNewForegroundTab(
     gBrowser,
-    "http://test1.example.org/MochiKit/"
+    "http://test1.example.org/Http2Server/"
   );
 
   // test simple queries
@@ -82,12 +82,12 @@ add_task(async function() {
       permissions: ["tabs"],
     },
 
-    background: function() {
+    background: function () {
       browser.tabs.query(
         {
           url: "<all_urls>",
         },
-        function(tabs) {
+        function (tabs) {
           browser.test.assertEq(tabs.length, 3, "should have three tabs");
 
           tabs.sort((tab1, tab2) => tab1.index - tab2.index);
@@ -104,7 +104,7 @@ add_task(async function() {
           );
           browser.test.assertEq(
             tabs[2].url,
-            "http://test1.example.org/MochiKit/",
+            "http://test1.example.org/Http2Server/",
             "tab 2 url correct"
           );
 
@@ -124,17 +124,17 @@ add_task(async function() {
       permissions: ["tabs"],
     },
 
-    background: function() {
+    background: function () {
       browser.tabs.query(
         {
-          url: "http://*/MochiKit*",
+          url: "http://*/Http2Server*",
         },
-        function(tabs) {
+        function (tabs) {
           browser.test.assertEq(tabs.length, 1, "should have one tab");
 
           browser.test.assertEq(
             tabs[0].url,
-            "http://test1.example.org/MochiKit/",
+            "http://test1.example.org/Http2Server/",
             "tab 0 url correct"
           );
 
@@ -154,12 +154,12 @@ add_task(async function() {
       permissions: ["tabs"],
     },
 
-    background: function() {
+    background: function () {
       browser.tabs.query(
         {
-          url: ["http://*/MochiKit*", "http://*.com/*"],
+          url: ["http://*/Http2Server*", "http://*.com/*"],
         },
-        function(tabs) {
+        function (tabs) {
           browser.test.assertEq(tabs.length, 2, "should have two tabs");
 
           tabs.sort((tab1, tab2) => tab1.index - tab2.index);
@@ -171,7 +171,7 @@ add_task(async function() {
           );
           browser.test.assertEq(
             tabs[1].url,
-            "http://test1.example.org/MochiKit/",
+            "http://test1.example.org/Http2Server/",
             "tab 1 url correct"
           );
 
@@ -231,7 +231,7 @@ add_task(async function() {
       );
       browser.test.assertEq(
         tabs[2].title,
-        "mochitest index /MochiKit/",
+        "mochitest index /Http2Server/",
         "tab 2 title correct"
       );
 
@@ -249,7 +249,7 @@ add_task(async function() {
       permissions: ["tabs"],
     },
 
-    background: async function() {
+    background: async function () {
       let tabs1 = await browser.tabs.query({ highlighted: false });
       browser.test.assertEq(
         3,
@@ -282,8 +282,8 @@ add_task(async function() {
       permissions: ["tabs"],
     },
 
-    background: function() {
-      browser.test.onMessage.addListener(async msg => {
+    background: function () {
+      browser.test.onMessage.addListener(async () => {
         let tabs = await browser.tabs.query({ active: true });
 
         browser.test.assertEq(tabs.length, 1, "should have one tab");
@@ -311,7 +311,12 @@ add_task(async function() {
       "window has the required resolution"
     );
 
-    let { clientHeight, clientWidth } = gBrowser.selectedBrowser;
+    let clientHeight;
+    let clientWidth;
+    await window.promiseDocumentFlushed(() => {
+      clientHeight = gBrowser.selectedBrowser.clientHeight;
+      clientWidth = gBrowser.selectedBrowser.clientWidth;
+    });
 
     extension.sendMessage("check-size");
     let dims = await extension.awaitMessage("dims");
@@ -354,33 +359,32 @@ add_task(async function testQueryPermissions() {
   await extension.unload();
 });
 
-add_task(async function testQueryWithoutURLOrTitlePermissions() {
+add_task(async function testInvalidUrl() {
   let extension = ExtensionTestUtils.loadExtension({
     manifest: {
-      permissions: [],
+      permissions: ["tabs"],
     },
-
     async background() {
       await browser.test.assertRejects(
-        browser.tabs.query({ url: "http://www.bbc.com/" }),
-        'The "tabs" permission is required to use the query API with the "url" or "title" parameters',
-        "Expected tabs.query with 'url' or 'title' to fail with permissions error message"
+        browser.tabs.query({ url: "http://test1.net" }),
+        "Invalid url pattern: http://test1.net",
+        "Expected url to match pattern"
       );
-
       await browser.test.assertRejects(
-        browser.tabs.query({ title: "Foo" }),
-        'The "tabs" permission is required to use the query API with the "url" or "title" parameters',
-        "Expected tabs.query with 'url' or 'title' to fail with permissions error message"
+        browser.tabs.query({ url: ["test2"] }),
+        "Invalid url pattern: test2",
+        "Expected an array with an invalid match pattern"
       );
-
-      browser.test.notifyPass("testQueryWithoutURLOrTitlePermissions");
+      await browser.test.assertRejects(
+        browser.tabs.query({ url: ["http://www.bbc.com/", "test3"] }),
+        "Invalid url pattern: test3",
+        "Expected an array with an invalid match pattern"
+      );
+      browser.test.notifyPass("testInvalidUrl");
     },
   });
-
   await extension.startup();
-
-  await extension.awaitFinish("testQueryWithoutURLOrTitlePermissions");
-
+  await extension.awaitFinish("testInvalidUrl");
   await extension.unload();
 });
 
@@ -390,8 +394,8 @@ add_task(async function test_query_index() {
       permissions: ["tabs"],
     },
 
-    background: function() {
-      browser.tabs.onCreated.addListener(async function({
+    background: function () {
+      browser.tabs.onCreated.addListener(async function ({
         index,
         windowId,
         id,
@@ -430,7 +434,7 @@ add_task(async function test_query_window() {
       permissions: ["tabs"],
     },
 
-    background: async function() {
+    background: async function () {
       let badWindowId = 0;
       for (let { id } of await browser.windows.getAll()) {
         badWindowId = Math.max(badWindowId, id + 1);
