@@ -2,19 +2,18 @@
 /* vim: set sts=2 sw=2 et tw=80: */
 "use strict";
 
-const { AddonTestUtils } = ChromeUtils.import(
-  "resource://testing-common/AddonTestUtils.jsm"
+const { AddonTestUtils } = ChromeUtils.importESModule(
+  "resource://testing-common/AddonTestUtils.sys.mjs"
 );
-const { HomePage } = ChromeUtils.import("resource:///modules/HomePage.jsm");
-const { ExtensionPermissions } = ChromeUtils.import(
-  "resource://gre/modules/ExtensionPermissions.jsm"
+const { HomePage } = ChromeUtils.importESModule(
+  "resource:///modules/HomePage.sys.mjs"
+);
+const { ExtensionPermissions } = ChromeUtils.importESModule(
+  "resource://gre/modules/ExtensionPermissions.sys.mjs"
 );
 
-const {
-  createAppInfo,
-  promiseShutdownManager,
-  promiseStartupManager,
-} = AddonTestUtils;
+const { createAppInfo, promiseShutdownManager, promiseStartupManager } =
+  AddonTestUtils;
 
 const EXTENSION_ID = "test_overrides@tests.mozilla.org";
 const HOMEPAGE_EXTENSION_CONTROLLED =
@@ -33,7 +32,7 @@ AddonTestUtils.overrideCertDB();
 createAppInfo("xpcshell@tests.mozilla.org", "XPCShell", "1", "42");
 
 function promisePrefChange(pref) {
-  return new Promise((resolve, reject) => {
+  return new Promise(resolve => {
     Services.prefs.addObserver(pref, function observer() {
       Services.prefs.removeObserver(pref, observer);
       resolve(arguments);
@@ -86,7 +85,7 @@ add_task(async function test_overrides_private() {
     useAddonManager: "permanent",
     manifest: {
       version: "1.0",
-      applications: {
+      browser_specific_settings: {
         gecko: {
           id: EXTENSION_ID,
         },
@@ -116,7 +115,7 @@ add_task(async function test_overrides_private() {
 
   extensionInfo.manifest = {
     version: "2.0",
-    applications: {
+    browser_specific_settings: {
       gecko: {
         id: EXTENSION_ID,
       },
