@@ -3,14 +3,15 @@
 
 "use strict";
 
-const { AddonTestUtils } = ChromeUtils.import(
-  "resource://testing-common/AddonTestUtils.jsm"
+const { AddonTestUtils } = ChromeUtils.importESModule(
+  "resource://testing-common/AddonTestUtils.sys.mjs"
+);
+const { setTimeout } = ChromeUtils.importESModule(
+  "resource://gre/modules/Timer.sys.mjs"
 );
-const { setTimeout } = ChromeUtils.import("resource://gre/modules/Timer.jsm");
 
 let delay = () => new Promise(resolve => setTimeout(resolve, 0));
 
-const kSearchFormURL = "https://example.com/searchform";
 const kSearchEngineURL = "https://example.com/?search={searchTerms}";
 const kSearchSuggestURL = "https://example.com/?suggest={searchTerms}";
 const kSearchTerm = "foo";
@@ -34,14 +35,13 @@ add_task(async function test_extension_adding_engine() {
   let ext1 = ExtensionTestUtils.loadExtension({
     manifest: {
       icons: {
-        "16": "foo.ico",
-        "32": "foo32.ico",
+        16: "foo.ico",
+        32: "foo32.ico",
       },
       chrome_settings_overrides: {
         search_provider: {
           name: "MozSearch",
           keyword: "MozSearch",
-          search_form: kSearchFormURL,
           search_url: kSearchEngineURL,
           suggest_url: kSearchSuggestURL,
         },
@@ -57,11 +57,22 @@ add_task(async function test_extension_adding_engine() {
   ok(engine, "Engine should exist.");
 
   let { baseURI } = ext1.extension;
-  equal(engine.iconURI.spec, baseURI.resolve("foo.ico"), "icon path matches");
-  let icons = engine.getIcons();
-  equal(icons.length, 2, "both icons avialable");
-  equal(icons[0].url, baseURI.resolve("foo.ico"), "icon path matches");
-  equal(icons[1].url, baseURI.resolve("foo32.ico"), "icon path matches");
+  equal(
+    await engine.getIconURL(),
+    baseURI.resolve("foo.ico"),
+    "16x16 icon path matches"
+  );
+  equal(
+    await engine.getIconURL(16),
+    baseURI.resolve("foo.ico"),
+    "16x16 icon path matches"
+  );
+
+  equal(
+    await engine.getIconURL(32),
+    baseURI.resolve("foo32.ico"),
+    "32x32 icon path matches"
+  );
 
   let expectedSuggestURL = kSearchSuggestURL.replace(
     "{searchTerms}",
@@ -88,7 +99,6 @@ add_task(async function test_extension_adding_engine() {
     "Suggest URLs should match"
   );
 
-  equal(engine.searchForm, kSearchFormURL, "Search form URLs should match");
   await ext1.unload();
   await delay();
 
@@ -133,7 +143,7 @@ add_task(async function test_upgrade_default_position_engine() {
           search_url: "https://example.com/?q={searchTerms}",
         },
       },
-      applications: {
+      browser_specific_settings: {
         gecko: {
           id: "testengine@mozilla.com",
         },
@@ -147,7 +157,10 @@ add_task(async function test_upgrade_default_position_engine() {
   await AddonTestUtils.waitForSearchProviderStartup(ext1);
 
   let engine = Services.search.getEngineByName("MozSearch");
-  await Services.search.setDefault(engine);
+  await Services.search.setDefault(
+    engine,
+    Ci.nsISearchService.CHANGE_REASON_UNKNOWN
+  );
   await Services.search.moveEngine(engine, 1);
 
   await ext1.upgrade({
@@ -159,7 +172,7 @@ add_task(async function test_upgrade_default_position_engine() {
           search_url: "https://example.com/?q={searchTerms}",
         },
       },
-      applications: {
+      browser_specific_settings: {
         gecko: {
           id: "testengine@mozilla.com",
         },
@@ -212,7 +225,7 @@ add_task(async function test_extension_get_params() {
   let engine = Services.search.getEngineByName("MozSearch");
   ok(engine, "Engine should exist.");
 
-  let url = engine.wrappedJSObject._getURLOfType("text/html");
+  let url = engine.wrappedJSObject.getURLOfType("text/html");
   equal(url.method, "GET", "Search URLs method is GET");
 
   let expectedURL = kSearchEngineURL.replace("{searchTerms}", kSearchTerm);
@@ -263,7 +276,7 @@ add_task(async function test_extension_post_params() {
   let engine = Services.search.getEngineByName("MozSearch");
   ok(engine, "Engine should exist.");
 
-  let url = engine.wrappedJSObject._getURLOfType("text/html");
+  let url = engine.wrappedJSObject.getURLOfType("text/html");
   equal(url.method, "POST", "Search URLs method is POST");
 
   let expectedURL = kSearchEngineURL.replace("{searchTerms}", kSearchTerm);
@@ -380,7 +393,7 @@ add_task(async function test_extension_empty_suggestUrl() {
   let engine = Services.search.getEngineByName("MozSearch");
   ok(engine, "Engine should exist.");
 
-  let url = engine.wrappedJSObject._getURLOfType("text/html");
+  let url = engine.wrappedJSObject.getURLOfType("text/html");
   equal(url.method, "POST", "Search URLs method is POST");
 
   let expectedURL = kSearchEngineURL.replace("{searchTerms}", kSearchTerm);
@@ -436,7 +449,7 @@ add_task(async function test_extension_empty_suggestUrl_with_params() {
   let engine = Services.search.getEngineByName("MozSearch");
   ok(engine, "Engine should exist.");
 
-  let url = engine.wrappedJSObject._getURLOfType("text/html");
+  let url = engine.wrappedJSObject.getURLOfType("text/html");
   equal(url.method, "POST", "Search URLs method is POST");
 
   let expectedURL = kSearchEngineURL.replace("{searchTerms}", kSearchTerm);
@@ -484,7 +497,6 @@ async function checkValidUrl(urlValue) {
       search_provider: {
         name: "MozSearch",
         keyword: "MozSearch",
-        search_form: urlValue,
         search_url: urlValue,
         suggest_url: urlValue,
       },
@@ -494,7 +506,6 @@ async function checkValidUrl(urlValue) {
 }
 
 add_task(async function test_extension_not_allow_http() {
-  await checkBadUrl("search_form", "http://example.com/{searchTerms}");
   await checkBadUrl("search_url", "http://example.com/{searchTerms}");
   await checkBadUrl("suggest_url", "http://example.com/{searchTerms}");
 });
