@@ -1,7 +1,7 @@
-add_task(async function setup() {
+add_setup(async function () {
   Services.prefs.setBoolPref("privacy.firstparty.isolate", true);
 
-  registerCleanupFunction(function() {
+  registerCleanupFunction(function () {
     Services.prefs.clearUserPref("privacy.firstparty.isolate");
   });
 });
@@ -12,11 +12,12 @@ add_task(async function test_remote_window_open_js_uri() {
 
   Assert.ok(browser.isRemoteBrowser, "should be a remote browser");
 
-  BrowserTestUtils.loadURI(browser, `javascript:1;`);
+  BrowserTestUtils.startLoadingURIString(browser, `javascript:"1";`);
 
-  await BrowserTestUtils.browserLoaded(browser);
+  // js URIs have about:blank as location
+  await BrowserTestUtils.browserLoaded(browser, { wantLoad: "about:blank" });
 
-  await SpecialPowers.spawn(browser, [], async function() {
+  await SpecialPowers.spawn(browser, [], async function () {
     Assert.ok(true, "origin " + content.document.nodePrincipal.origin);
 
     Assert.ok(
@@ -43,7 +44,7 @@ add_task(async function test_remote_window_open_js_uri2() {
 
   Assert.ok(browser.isRemoteBrowser, "should be a remote browser");
 
-  BrowserTestUtils.loadURI(
+  BrowserTestUtils.startLoadingURIString(
     browser,
     `javascript:
     let iframe = document.createElement("iframe");
@@ -54,12 +55,12 @@ add_task(async function test_remote_window_open_js_uri2() {
  `
   );
 
-  await BrowserTestUtils.browserLoaded(browser, true, function(url) {
+  await BrowserTestUtils.browserLoaded(browser, true, function (url) {
     info("URL:" + url);
     return url == "http://example.com/";
   });
 
-  await SpecialPowers.spawn(browser, [], async function() {
+  await SpecialPowers.spawn(browser, [], async function () {
     Assert.ok(true, "origin " + content.document.nodePrincipal.origin);
 
     Assert.ok(
@@ -77,7 +78,7 @@ add_task(async function test_remote_window_open_js_uri2() {
     );
 
     let iframe = content.document.getElementById("iframe1");
-    await SpecialPowers.spawn(iframe, [expectDomain], function(domain) {
+    await SpecialPowers.spawn(iframe, [expectDomain], function (domain) {
       Assert.equal(
         content.document.nodePrincipal.originAttributes.firstPartyDomain,
         domain,
