@@ -9,9 +9,17 @@ const TEST_PAGE =
 // Use a random key so we don't access it in later tests.
 const key = Math.random().toString();
 
+// IsolationTestTools flushes all preferences
+// hence we explicitly pref off https-first mode
+async function prefOffHttpsFirstMode() {
+  await SpecialPowers.pushPrefEnv({
+    set: [["dom.security.https_first", false]],
+  });
+}
+
 // Define the testing function
 function doTest(aBrowser) {
-  return SpecialPowers.spawn(aBrowser, [key], function(contentKey) {
+  return SpecialPowers.spawn(aBrowser, [key], function (contentKey) {
     let value = content.localStorage.getItem(contentKey);
     if (value === null) {
       // No value is found, so we create one.
@@ -22,4 +30,4 @@ function doTest(aBrowser) {
   });
 }
 
-IsolationTestTools.runTests(TEST_PAGE, doTest);
+IsolationTestTools.runTests(TEST_PAGE, doTest, null, prefOffHttpsFirstMode);
