@@ -51,18 +51,13 @@
  */
 
 /* import-globals-from editBookmark.js */
-/* import-globals-from controller.js */
 
 /* Shared Places Import - change other consumers if you change this: */
-var { Services } = ChromeUtils.import("resource://gre/modules/Services.jsm");
-var { XPCOMUtils } = ChromeUtils.import(
-  "resource://gre/modules/XPCOMUtils.jsm"
+var { XPCOMUtils } = ChromeUtils.importESModule(
+  "resource://gre/modules/XPCOMUtils.sys.mjs"
 );
-XPCOMUtils.defineLazyModuleGetters(this, {
-  PlacesUtils: "resource://gre/modules/PlacesUtils.jsm",
-  PlacesUIUtils: "resource:///modules/PlacesUIUtils.jsm",
-  PlacesTransactions: "resource://gre/modules/PlacesTransactions.jsm",
-  PrivateBrowsingUtils: "resource://gre/modules/PrivateBrowsingUtils.jsm",
+ChromeUtils.defineESModuleGetters(this, {
+  PrivateBrowsingUtils: "resource://gre/modules/PrivateBrowsingUtils.sys.mjs",
 });
 XPCOMUtils.defineLazyScriptGetter(
   this,
@@ -82,8 +77,6 @@ const BOOKMARK_FOLDER = 1;
 const ACTION_EDIT = 0;
 const ACTION_ADD = 1;
 
-var elementsHeight = new Map();
-
 var BookmarkPropertiesPanel = {
   /** UI Text Strings */
   __strings: null,
@@ -165,10 +158,9 @@ var BookmarkPropertiesPanel = {
       if ("defaultInsertionPoint" in dialogInfo) {
         this._defaultInsertionPoint = dialogInfo.defaultInsertionPoint;
       } else {
-        let guid = await PlacesUIUtils.defaultParentGuid;
+        let parentGuid = await PlacesUIUtils.defaultParentGuid;
         this._defaultInsertionPoint = new PlacesInsertionPoint({
-          parentId: await PlacesUtils.promiseItemId(guid),
-          parentGuid: guid,
+          parentGuid,
         });
       }
 
@@ -219,7 +211,7 @@ var BookmarkPropertiesPanel = {
       // edit
       this._node = dialogInfo.node;
       this._title = this._node.title;
-      if (PlacesUtils.nodeIsFolder(this._node)) {
+      if (PlacesUtils.nodeIsFolderOrShortcut(this._node)) {
         this._itemType = BOOKMARK_FOLDER;
       } else if (PlacesUtils.nodeIsURI(this._node)) {
         this._itemType = BOOKMARK_ITEM;
@@ -232,12 +224,9 @@ var BookmarkPropertiesPanel = {
    * dialog to initialize the state of the panel.
    */
   async onDialogLoad() {
-    document.addEventListener("dialogaccept", function() {
-      BookmarkPropertiesPanel.onDialogAccept();
-    });
-    document.addEventListener("dialogcancel", function() {
-      BookmarkPropertiesPanel.onDialogCancel();
-    });
+    document.addEventListener("dialogaccept", () => this.onDialogAccept());
+    document.addEventListener("dialogcancel", () => this.onDialogCancel());
+    window.addEventListener("unload", () => this.onDialogUnload());
 
     // Disable the buttons until we have all the information required.
     let acceptButton = document
@@ -259,11 +248,7 @@ var BookmarkPropertiesPanel = {
       );
     }
 
-    // Allow initialization to complete in a truely async manner so that we're
-    // not blocking the main thread.
-    document.mozSubdialogReady = this._initDialog().catch(ex => {
-      Cu.reportError(`Failed to initialize dialog: ${ex}`);
-    });
+    await this._initDialog();
   },
 
   _getIconUrl() {
@@ -287,63 +272,55 @@ var BookmarkPropertiesPanel = {
     acceptButton.label = this._getAcceptLabel();
     let acceptButtonDisabled = false;
 
-    // Do not use sizeToContent, otherwise, due to bug 90276, the dialog will
-    // grow at every opening.
-    // Since elements can be uncollapsed asynchronously, we must observe their
-    // mutations and resize the dialog using a cached element size.
+    // Since elements can be unhidden asynchronously, we must observe their
+    // mutations and resize the dialog accordingly.
     this._mutationObserver = new MutationObserver(mutations => {
-      for (let mutation of mutations) {
-        let target = mutation.target;
-        let id = target.id;
-        if (!/^editBMPanel_.*(Row|Checkbox)$/.test(id)) {
-          continue;
+      for (let { target, oldValue } of mutations) {
+        let hidden = target.hasAttribute("hidden");
+        let wasHidden = oldValue !== null;
+        if (target.classList.contains("hideable") && hidden != wasHidden) {
+          // To support both kind of dialogs (window and dialog-box) we need
+          // both resizeBy and sizeToContent, otherwise either the dialog
+          // doesn't resize, or it gets empty unused space.
+          if (hidden) {
+            let diff = this._mutationObserver._heightsById.get(target.id);
+            window.resizeBy(0, -diff);
+          } else {
+            let diff = target.getBoundingClientRect().height;
+            this._mutationObserver._heightsById.set(target.id, diff);
+            window.resizeBy(0, diff);
+          }
+          window.sizeToContent();
         }
-
-        let collapsed = target.getAttribute("collapsed") === "true";
-        let wasCollapsed = mutation.oldValue === "true";
-        if (collapsed == wasCollapsed) {
-          continue;
-        }
-
-        let heightDiff;
-        if (collapsed) {
-          heightDiff = -elementsHeight.get(id);
-          elementsHeight.delete(id);
-        } else {
-          heightDiff = target.getBoundingClientRect().height;
-          elementsHeight.set(id, heightDiff);
-        }
-        window.resizeBy(0, heightDiff);
       }
     });
-
+    this._mutationObserver._heightsById = new Map();
     this._mutationObserver.observe(document, {
       subtree: true,
       attributeOldValue: true,
-      attributeFilter: ["collapsed"],
+      attributeFilter: ["hidden"],
     });
 
-    // Some controls are flexible and we want to update their cached size when
-    // the dialog is resized.
-    window.addEventListener("resize", this);
-
     switch (this._action) {
-      case ACTION_EDIT:
-        gEditItemOverlay.initPanel({
+      case ACTION_EDIT: {
+        await gEditItemOverlay.initPanel({
           node: this._node,
           hiddenRows: this._hiddenRows,
           focusedElement: "first",
         });
         acceptButtonDisabled = gEditItemOverlay.readOnly;
         break;
-      case ACTION_ADD:
+      }
+      case ACTION_ADD: {
         this._node = await this._promiseNewItem();
+
         // Edit the new item
-        gEditItemOverlay.initPanel({
+        await gEditItemOverlay.initPanel({
           node: this._node,
           hiddenRows: this._hiddenRows,
           postData: this._postData,
           focusedElement: "first",
+          addedMultipleBookmarks: this._node.children?.length > 1,
         });
 
         // Empty location field if the uri is about:blank, this way inserting a new
@@ -360,6 +337,7 @@ var BookmarkPropertiesPanel = {
           acceptButtonDisabled = !this._inputIsValid();
         }
         break;
+      }
     }
 
     if (!gEditItemOverlay.readOnly) {
@@ -390,12 +368,6 @@ var BookmarkPropertiesPanel = {
             .getButton("accept").disabled = !this._inputIsValid();
         }
         break;
-      case "resize":
-        for (let id of elementsHeight.keys()) {
-          let { height } = document.getElementById(id).getBoundingClientRect();
-          elementsHeight.set(id, height);
-        }
-        break;
     }
   },
 
@@ -411,8 +383,6 @@ var BookmarkPropertiesPanel = {
     this._mutationObserver.disconnect();
     delete this._mutationObserver;
 
-    window.removeEventListener("resize", this);
-
     // Calling removeEventListener with arguments which do not identify any
     // currently registered EventListener on the EventTarget has no effect.
     this._element("locationField").removeEventListener("input", this);
@@ -421,13 +391,16 @@ var BookmarkPropertiesPanel = {
 
   onDialogAccept() {
     // We must blur current focused element to save its changes correctly
-    document.commandDispatcher.focusedElement.blur();
+    document.commandDispatcher.focusedElement?.blur();
+
+    // Get the states to compare bookmark and editedBookmark
+    window.arguments[0].bookmarkState = gEditItemOverlay._bookmarkState;
+
     // We have to uninit the panel first, otherwise late changes could force it
     // to commit more transactions.
     gEditItemOverlay.uninitPanel(true);
-    if (this._node.bookmarkGuid) {
-      window.arguments[0].bookmarkGuid = this._node.bookmarkGuid;
-    }
+
+    window.arguments[0].bookmarkGuid = this._node.bookmarkGuid;
   },
 
   onDialogCancel() {
@@ -482,25 +455,20 @@ var BookmarkPropertiesPanel = {
    * [New Item Mode] Get the insertion point details for the new item, given
    * dialog state and opening arguments.
    *
-   * The container-identifier and insertion-index are returned separately in
-   * the form of [containerIdentifier, insertionIndex]
+   * @returns {Array}
+   *   The container-identifier and insertion-index are returned separately in
+   *   the form of [containerIdentifier, insertionIndex]
    */
   async _getInsertionPointDetails() {
     return [
-      this._defaultInsertionPoint.itemId,
       await this._defaultInsertionPoint.getIndex(),
       this._defaultInsertionPoint.guid,
     ];
   },
 
   async _promiseNewItem() {
-    let [
-      containerId,
-      index,
-      parentGuid,
-    ] = await this._getInsertionPointDetails();
+    let [index, parentGuid] = await this._getInsertionPointDetails();
 
-    let itemGuid;
     let info = { parentGuid, index, title: this._title };
     if (this._itemType == BOOKMARK_ITEM) {
       info.url = this._uri;
@@ -513,24 +481,20 @@ var BookmarkPropertiesPanel = {
 
       if (this._charSet) {
         PlacesUIUtils.setCharsetForPage(this._uri, this._charSet, window).catch(
-          Cu.reportError
+          console.error
         );
       }
-
-      itemGuid = await PlacesTransactions.NewBookmark(info).transact();
     } else if (this._itemType == BOOKMARK_FOLDER) {
       // NewFolder requires a url rather than uri.
       info.children = this._URIs.map(item => {
         return { url: item.uri, title: item.title };
       });
-      itemGuid = await PlacesTransactions.NewFolder(info).transact();
     } else {
       throw new Error(`unexpected value for _itemType:  ${this._itemType}`);
     }
-
     return Object.freeze({
-      itemId: await PlacesUtils.promiseItemId(itemGuid),
-      bookmarkGuid: itemGuid,
+      index,
+      bookmarkGuid: PlacesUtils.bookmarks.unsavedGuid,
       title: this._title,
       uri: this._uri ? this._uri.spec : "",
       type:
@@ -538,14 +502,18 @@ var BookmarkPropertiesPanel = {
           ? Ci.nsINavHistoryResultNode.RESULT_TYPE_URI
           : Ci.nsINavHistoryResultNode.RESULT_TYPE_FOLDER,
       parent: {
-        itemId: containerId,
         bookmarkGuid: parentGuid,
         type: Ci.nsINavHistoryResultNode.RESULT_TYPE_FOLDER,
       },
+      children: info.children,
     });
   },
 };
 
-document.addEventListener("DOMContentLoaded", function() {
-  BookmarkPropertiesPanel.onDialogLoad();
+document.addEventListener("DOMContentLoaded", function () {
+  // Content initialization is asynchronous, thus set mozSubdialogReady
+  // immediately to properly wait for it.
+  document.mozSubdialogReady = BookmarkPropertiesPanel.onDialogLoad()
+    .catch(ex => console.error(`Failed to initialize dialog: ${ex}`))
+    .then(() => window.sizeToContent());
 });
