@@ -4,7 +4,9 @@
 
 "use strict";
 
-const { sinon } = ChromeUtils.import("resource://testing-common/Sinon.jsm");
+const { sinon } = ChromeUtils.importESModule(
+  "resource://testing-common/Sinon.sys.mjs"
+);
 
 const sandbox = sinon.createSandbox();
 const TAG_NAME = "testTag";
@@ -12,8 +14,8 @@ const TAG_NAME = "testTag";
 var bookmarks;
 var bookmarkId;
 
-add_task(async function setup() {
-  registerCleanupFunction(async function() {
+add_setup(async function () {
+  registerCleanupFunction(async function () {
     sandbox.restore();
     await PlacesUtils.bookmarks.eraseEverything();
     await PlacesUtils.history.clear();
@@ -27,16 +29,16 @@ add_task(async function setup() {
     children: [
       {
         title: "bm1",
-        url: "http://example1.com",
+        url: "https://example1.com",
       },
       {
         title: "bm2",
-        url: "http://example2.com",
+        url: "https://example2.com",
         tags: [TAG_NAME],
       },
     ],
   });
-  bookmarkId = await PlacesUtils.promiseItemId(bookmarks[0].guid);
+  bookmarkId = await PlacesTestUtils.promiseItemId(bookmarks[0].guid);
 });
 
 async function run_drag_test(startBookmarkIndex, newParentGuid) {
@@ -79,10 +81,10 @@ async function run_drag_test(startBookmarkIndex, newParentGuid) {
       mozCursor: "auto",
       mozItemCount: 1,
       types: [PlacesUtils.TYPE_X_MOZ_PLACE],
-      mozTypesAt(i) {
+      mozTypesAt() {
         return this.types;
       },
-      mozGetDataAt(i) {
+      mozGetDataAt() {
         return bookmarkWithId;
       },
     };
