@@ -11,7 +11,7 @@ var gChevron = document.getElementById("PlacesChevron");
 
 const BOOKMARKS_COUNT = 250;
 
-add_task(async function setup() {
+add_setup(async function () {
   let wasCollapsed = gToolbar.collapsed;
   await PlacesUtils.bookmarks.eraseEverything();
 
@@ -20,7 +20,7 @@ add_task(async function setup() {
     guid: PlacesUtils.bookmarks.toolbarGuid,
     children: Array(BOOKMARKS_COUNT)
       .fill("")
-      .map((_, i) => ({ url: `http://test.places.${i}/` })),
+      .map((_, i) => ({ url: `https://test.places.y${i}/` })),
   });
 
   // Toggle the bookmarks toolbar so that we start from a stable situation and
@@ -41,18 +41,20 @@ add_task(async function test_overflow() {
   // Check that the overflow chevron is visible.
   Assert.ok(!gChevron.collapsed, "The overflow chevron should be visible");
   let children = getPlacesChildren();
-  Assert.ok(
-    children.length < BOOKMARKS_COUNT,
+  Assert.less(
+    children.length,
+    BOOKMARKS_COUNT,
     "Not all the nodes should be built by default"
   );
   let visibleNodes = [];
   for (let node of children) {
-    if (node.style.visibility == "visible") {
+    if (getComputedStyle(node).visibility == "visible") {
       visibleNodes.push(node);
     }
   }
-  Assert.ok(
-    visibleNodes.length < children.length,
+  Assert.less(
+    visibleNodes.length,
+    children.length,
     `The number of visible nodes (${visibleNodes.length}) should be smaller than the number of built nodes (${children.length})`
   );
 
@@ -107,11 +109,11 @@ add_task(async function test_separator_first() {
   Assert.greater(children.length, 2, "Multiple elements are visible");
   Assert.equal(
     children[1]._placesNode.uri,
-    "http://test.places.0/",
+    "https://test.places.y0/",
     "Found the first bookmark"
   );
   Assert.equal(
-    children[1].style.visibility,
+    getComputedStyle(children[1]).visibility,
     "visible",
     "The first bookmark is visible"
   );
@@ -128,7 +130,7 @@ add_task(async function test_newWindow_noOverflow() {
   // Add a single bookmark.
   await PlacesUtils.bookmarks.insert({
     parentGuid: PlacesUtils.bookmarks.toolbarGuid,
-    url: "http://toolbar.overflow/",
+    url: "https://toolbar.overflow/",
     title: "Example",
   });
   // Add a favicon for the bookmark.
@@ -136,7 +138,7 @@ add_task(async function test_newWindow_noOverflow() {
     "data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAA" +
     "AAAA6fptVAAAACklEQVQI12NgAAAAAgAB4iG8MwAAAABJRU5ErkJggg==";
   await PlacesTestUtils.addFavicons(
-    new Map([["http://toolbar.overflow/", favicon]])
+    new Map([["https://toolbar.overflow/", favicon]])
   );
 
   let win = await BrowserTestUtils.openNewBrowserWindow();
@@ -163,14 +165,15 @@ async function test_index(desc, index, expected) {
   let originalLen = children.length;
   let nodeExisted = children.length > index;
   let previousNodeIsVisible =
-    nodeExisted && children[index - 1].style.visibility == "visible";
+    nodeExisted &&
+    getComputedStyle(children[index - 1]).visibility == "visible";
   let promise = promiseUpdateVisibility(
     expected == "visible" || previousNodeIsVisible
   );
 
   let bm = await PlacesUtils.bookmarks.insert({
     parentGuid: PlacesUtils.bookmarks.toolbarGuid,
-    url: "http://test.places.added/",
+    url: "https://test.places.added/",
     index,
   });
   Assert.equal(bm.index, index, "Sanity check the bookmark index");
@@ -178,8 +181,9 @@ async function test_index(desc, index, expected) {
   children = getPlacesChildren();
 
   if (!expected) {
-    Assert.ok(
-      children.length <= index,
+    Assert.lessOrEqual(
+      children.length,
+      index,
       "The new node should not have been added"
     );
   } else {
@@ -189,7 +193,7 @@ async function test_index(desc, index, expected) {
       "Found the added bookmark at the expected position"
     );
     Assert.equal(
-      children[index].style.visibility,
+      getComputedStyle(children[index]).visibility,
       expected,
       `The bookmark node should be ${expected}`
     );
@@ -210,11 +214,11 @@ async function test_index(desc, index, expected) {
   if (expected && nodeExisted) {
     Assert.equal(
       children[index]._placesNode.uri,
-      `http://test.places.${index}/`,
+      `https://test.places.y${index}/`,
       "Found the previous bookmark at the expected position"
     );
     Assert.equal(
-      children[index].style.visibility,
+      getComputedStyle(children[index]).visibility,
       expected,
       `The bookmark node should be ${expected}`
     );
@@ -237,7 +241,7 @@ async function test_move_index(desc, fromIndex, toIndex, original, expected) {
   let existingIndex = fromIndex < toIndex ? toIndex - 1 : toIndex + 1;
 
   Assert.equal(
-    children[fromIndex].style.visibility,
+    getComputedStyle(children[fromIndex]).visibility,
     original,
     `The bookmark node should be ${original}`
   );
@@ -253,8 +257,9 @@ async function test_move_index(desc, fromIndex, toIndex, original, expected) {
   children = getPlacesChildren();
 
   if (!expected) {
-    Assert.ok(
-      children.length <= toIndex,
+    Assert.lessOrEqual(
+      children.length,
+      toIndex,
       "Node in the new position is not expected"
     );
     Assert.ok(
@@ -268,13 +273,13 @@ async function test_move_index(desc, fromIndex, toIndex, original, expected) {
       "Found the moved bookmark at the expected position"
     );
     Assert.equal(
-      children[toIndex].style.visibility,
+      getComputedStyle(children[toIndex]).visibility,
       expected,
       `The destination bookmark node should be ${expected}`
     );
   }
   Assert.equal(
-    children[fromIndex].style.visibility,
+    getComputedStyle(children[fromIndex]).visibility,
     original,
     `The origin bookmark node should be ${original}`
   );
@@ -310,13 +315,13 @@ async function test_move_index(desc, fromIndex, toIndex, original, expected) {
   );
   if (expected) {
     Assert.equal(
-      children[toIndex].style.visibility,
+      getComputedStyle(children[toIndex]).visibility,
       expected,
       `The bookmark node should be ${expected}`
     );
   }
   Assert.equal(
-    children[fromIndex].style.visibility,
+    getComputedStyle(children[fromIndex]).visibility,
     original,
     `The bookmark node should be ${original}`
   );
@@ -353,12 +358,12 @@ add_task(async function test_separator_first() {
   let children = getPlacesChildren();
   Assert.equal(children.length, 2, "The expected elements are visible");
   Assert.equal(
-    children[0].style.visibility,
+    getComputedStyle(children[0]).visibility,
     "visible",
     "The first bookmark is visible"
   );
   Assert.equal(
-    children[1].style.visibility,
+    getComputedStyle(children[1]).visibility,
     "visible",
     "The second bookmark is visible"
   );
@@ -370,6 +375,7 @@ add_task(async function test_separator_first() {
 /**
  * If the passed-in condition is fulfilled, awaits for the toolbar nodes
  * visibility to have been updated.
+ *
  * @param {boolean} [condition] Awaits for visibility only if this condition is true.
  * @returns {Promise} resolved when the condition is not fulfilled or the
  *          visilibily update happened.
@@ -387,6 +393,7 @@ function promiseUpdateVisibility(condition = true) {
 /**
  * Returns an array of toolbar children that are Places nodes, ignoring things
  * like the chevron or other additional buttons.
+ *
  * @returns {Array} An array of Places element nodes.
  */
 function getPlacesChildren() {
@@ -398,6 +405,7 @@ function getPlacesChildren() {
 
 /**
  * Toggles the toolbar on or off.
+ *
  * @param {boolean} show Whether to show or hide the toolbar.
  * @param {number} [expectedMinChildCount] Optional number of Places nodes that
  *        should be visible on the toolbar.
@@ -415,7 +423,7 @@ async function toggleToolbar(show, expectedMinChildCount = 0) {
     if (getPlacesChildren().length < expectedMinChildCount) {
       await new Promise(resolve => {
         info("Waiting for bookmark elements to appear");
-        let mut = new MutationObserver(mutations => {
+        let mut = new MutationObserver(() => {
           let children = getPlacesChildren();
           info(`${children.length} bookmark elements appeared`);
           if (children.length >= expectedMinChildCount) {
