@@ -1,4 +1,6 @@
-const { sinon } = ChromeUtils.import("resource://testing-common/Sinon.jsm");
+const { sinon } = ChromeUtils.importESModule(
+  "resource://testing-common/Sinon.sys.mjs"
+);
 
 /* eslint-disable mozilla/use-chromeutils-generateqi */
 
