@@ -5,12 +5,6 @@
 
 /* import-globals-from /toolkit/content/preferencesBindings.js */
 
-var { Services } = ChromeUtils.import("resource://gre/modules/Services.jsm");
-
-document
-  .getElementById("LanguagesDialog")
-  .addEventListener("dialoghelp", window.top.openPrefsHelp);
-
 Preferences.addAll([
   { id: "intl.accept_languages", type: "wstring" },
   { id: "pref.browser.language.disable_button.up", type: "bool" },
@@ -35,9 +29,16 @@ var gLanguagesDialog = {
     );
 
     Preferences.get("intl.accept_languages").on("change", () =>
-      this._readAcceptLanguages().catch(Cu.reportError)
+      this._readAcceptLanguages().catch(console.error)
     );
 
+    let addListener = (id, cmd) => {
+      document.getElementById(id).addEventListener(cmd, this);
+    };
+    addListener("LanguagesDialog", "command");
+    addListener("availableLanguages", "command");
+    addListener("activeLanguages", "select");
+
     if (!this._availableLanguagesList.length) {
       document.mozSubdialogReady = this._loadAvailableLanguages();
     }
@@ -157,6 +158,8 @@ var gLanguagesDialog = {
     var selectedIndex = 0;
     var preference = Preferences.get("intl.accept_languages");
     if (preference.value == "") {
+      this._activeLanguages.selectedIndex = -1;
+      this.onLanguageSelect();
       return;
     }
     var languages = preference.value.toLowerCase().split(/\s*,\s*/);
@@ -195,6 +198,45 @@ var gLanguagesDialog = {
     this.readSpoofEnglish();
   },
 
+  handleEvent(event) {
+    switch (event.type) {
+      case "command":
+        if (event.currentTarget.id == "availableLanguages") {
+          this.onAvailableLanguageSelect();
+          break;
+        }
+
+        switch (event.target.id) {
+          case "key_close":
+            Preferences.close(event);
+            break;
+
+          case "up":
+            this.moveUp();
+            break;
+          case "down":
+            this.moveDown();
+            break;
+          case "remove":
+            this.removeLanguage();
+            break;
+          case "addButton":
+            this.addLanguage();
+            break;
+        }
+        break;
+      case "dialoghelp":
+        window.top.openPrefsHelp();
+        break;
+      case "load":
+        this.onLoad();
+        break;
+      case "select":
+        this.onLanguageSelect();
+        break;
+    }
+  },
+
   onAvailableLanguageSelect() {
     var availableLanguages = this._availableLanguages;
     var addButton = document.getElementById("addButton");
@@ -225,9 +267,10 @@ var gLanguagesDialog = {
 
     this._acceptLanguages[selectedID] = true;
     this._availableLanguages.selectedItem = null;
+    this.onAvailableLanguageSelect();
 
     // Rebuild the available list with the added item removed...
-    this._buildAvailableLanguageList().catch(Cu.reportError);
+    this._buildAvailableLanguageList().catch(console.error);
   },
 
   removeLanguage() {
@@ -255,19 +298,26 @@ var gLanguagesDialog = {
     var preference = Preferences.get("intl.accept_languages");
     preference.value = string;
 
-    this._buildAvailableLanguageList().catch(Cu.reportError);
+    this._buildAvailableLanguageList().catch(console.error);
   },
 
   _getLocaleName(localeCode) {
     if (!this._availableLanguagesList.length) {
       this._loadAvailableLanguages();
     }
+    let languageName = "";
     for (var i = 0; i < this._availableLanguagesList.length; ++i) {
       if (localeCode == this._availableLanguagesList[i].code) {
         return this._availableLanguagesList[i].name;
       }
+      // Try resolving the locale code without region code. Can't return
+      // directly because there might be a perfect match later.
+      if (localeCode.split("-")[0] == this._availableLanguagesList[i].code) {
+        languageName = this._availableLanguagesList[i].name;
+      }
     }
-    return "";
+
+    return languageName;
   },
 
   moveUp() {
@@ -377,3 +427,5 @@ var gLanguagesDialog = {
     return document.getElementById("spoofEnglish").checked ? 2 : 1;
   },
 };
+
+window.addEventListener("load", gLanguagesDialog);
