@@ -8,16 +8,16 @@
 const lazy = {};
 
 ChromeUtils.defineESModuleGetters(lazy, {
-  CustomizableUI: "resource:///modules/CustomizableUI.sys.mjs",
+  AddonSearchEngine:
+    "moz-src:///toolkit/components/search/AddonSearchEngine.sys.mjs",
+  CustomizableUI:
+    "moz-src:///browser/components/customizableui/CustomizableUI.sys.mjs",
   SearchUIUtils: "moz-src:///browser/components/search/SearchUIUtils.sys.mjs",
-  SearchUtils: "resource://gre/modules/SearchUtils.sys.mjs",
-  UserSearchEngine: "resource://gre/modules/UserSearchEngine.sys.mjs",
+  SearchUtils: "moz-src:///toolkit/components/search/SearchUtils.sys.mjs",
+  UserSearchEngine:
+    "moz-src:///toolkit/components/search/UserSearchEngine.sys.mjs",
 });
 
-const PREF_URLBAR_QUICKSUGGEST_BLOCKLIST =
-  "browser.urlbar.quicksuggest.blockedDigests";
-const PREF_URLBAR_WEATHER_USER_ENABLED = "browser.urlbar.suggest.weather";
-
 Preferences.addAll([
   { id: "browser.search.suggest.enabled", type: "bool" },
   { id: "browser.urlbar.suggest.searches", type: "bool" },
@@ -74,9 +74,11 @@ var gSearchPane = {
 
     Services.obs.addObserver(this, "browser-search-engine-modified");
     Services.obs.addObserver(this, "intl:app-locales-changed");
+    Services.obs.addObserver(this, "quicksuggest-dismissals-changed");
     window.addEventListener("unload", () => {
       Services.obs.removeObserver(this, "browser-search-engine-modified");
       Services.obs.removeObserver(this, "intl:app-locales-changed");
+      Services.obs.removeObserver(this, "quicksuggest-dismissals-changed");
     });
 
     let suggestsPref = Preferences.get("browser.search.suggest.enabled");
@@ -365,14 +367,8 @@ var gSearchPane = {
         QuickSuggest.SETTINGS_UI.FULL;
 
       this._updateDismissedSuggestionsStatus();
-      Preferences.get(PREF_URLBAR_QUICKSUGGEST_BLOCKLIST).on("change", () =>
-        this._updateDismissedSuggestionsStatus()
-      );
-      Preferences.get(PREF_URLBAR_WEATHER_USER_ENABLED).on("change", () =>
-        this._updateDismissedSuggestionsStatus()
-      );
       setEventListener("restoreDismissedSuggestions", "command", () =>
-        this.restoreDismissedSuggestions()
+        QuickSuggest.clearDismissedSuggestions()
       );
 
       container.hidden = false;
@@ -414,21 +410,9 @@ var gSearchPane = {
    * Enables/disables the "Restore" button for dismissed Firefox Suggest
    * suggestions.
    */
-  _updateDismissedSuggestionsStatus() {
+  async _updateDismissedSuggestionsStatus() {
     document.getElementById("restoreDismissedSuggestions").disabled =
-      !Services.prefs.prefHasUserValue(PREF_URLBAR_QUICKSUGGEST_BLOCKLIST) &&
-      !(
-        Services.prefs.prefHasUserValue(PREF_URLBAR_WEATHER_USER_ENABLED) &&
-        !Services.prefs.getBoolPref(PREF_URLBAR_WEATHER_USER_ENABLED)
-      );
-  },
-
-  /**
-   * Restores Firefox Suggest suggestions dismissed by the user.
-   */
-  restoreDismissedSuggestions() {
-    Services.prefs.clearUserPref(PREF_URLBAR_QUICKSUGGEST_BLOCKLIST);
-    Services.prefs.clearUserPref(PREF_URLBAR_WEATHER_USER_ENABLED);
+      !(await QuickSuggest.canClearDismissedSuggestions());
   },
 
   handleEvent(aEvent) {
@@ -481,7 +465,11 @@ var gSearchPane = {
           default:
             this._engineStore.browserSearchEngineModified(engine, data);
         }
+        break;
       }
+      case "quicksuggest-dismissals-changed":
+        this._updateDismissedSuggestionsStatus();
+        break;
     }
   },
 
@@ -522,14 +510,6 @@ class EngineStore {
    */
   engines = [];
 
-  /**
-   * A list of application provided engines used when restoring the list of
-   * engines to the default set and order.
-   *
-   * @type {nsISearchEngine[]}
-   */
-  #appProvidedEngines = [];
-
   /**
    * A list of listeners to be notified when the engine list changes.
    *
@@ -538,19 +518,17 @@ class EngineStore {
   #listeners = [];
 
   async init() {
-    let visibleEngines = await Services.search.getVisibleEngines();
+    let engines = await Services.search.getEngines();
+
+    let visibleEngines = engines.filter(e => !e.hidden);
     for (let engine of visibleEngines) {
       this.addEngine(engine);
     }
-
-    let appProvidedEngines = await Services.search.getAppProvidedEngines();
-    this.#appProvidedEngines = appProvidedEngines.map(this._cloneEngine, this);
-
     this.notifyRowCountChanged(0, visibleEngines.length);
 
-    // check if we need to disable the restore defaults button
-    var someHidden = this.#appProvidedEngines.some(e => e.hidden);
-    gSearchPane.showRestoreDefaults(someHidden);
+    gSearchPane.showRestoreDefaults(
+      engines.some(e => e.isAppProvided && e.hidden)
+    );
   }
 
   /**
@@ -620,13 +598,24 @@ class EngineStore {
     return this.engines.find(engine => engine.name == aName);
   }
 
+  /**
+   * Converts an nsISearchEngine object into an Engine Store
+   * search engine object.
+   *
+   * @param {nsISearchEngine} aEngine
+   *   The search engine to convert.
+   * @returns {object}
+   *   The EngineStore search engine object.
+   */
   _cloneEngine(aEngine) {
     var clonedObj = {
       iconURL: null,
     };
-    for (let i of ["id", "name", "alias", "hidden"]) {
+    for (let i of ["id", "name", "alias", "hidden", "isAppProvided"]) {
       clonedObj[i] = aEngine[i];
     }
+    clonedObj.isAddonEngine =
+      aEngine.wrappedJSObject instanceof lazy.AddonSearchEngine;
     clonedObj.isUserEngine =
       aEngine.wrappedJSObject instanceof lazy.UserSearchEngine;
     clonedObj.originalEngine = aEngine;
@@ -687,13 +676,19 @@ class EngineStore {
     return Services.search.moveEngine(aEngine.originalEngine, aNewIndex);
   }
 
+  /**
+   * Called when a search engine is removed.
+   *
+   * @param {nsISearchEngine} aEngine
+   *   The Engine being removed. Note that this is an nsISearchEngine object.
+   */
   removeEngine(aEngine) {
     if (this.engines.length == 1) {
       throw new Error("Cannot remove last engine!");
     }
 
-    let engineName = aEngine.name;
-    let index = this.engines.findIndex(element => element.name == engineName);
+    let engineId = aEngine.id;
+    let index = this.engines.findIndex(element => element.id == engineId);
 
     if (index == -1) {
       throw new Error("invalid engine?");
@@ -743,9 +738,14 @@ class EngineStore {
 
   async restoreDefaultEngines() {
     var added = 0;
+    // _cloneEngine is necessary here because all functions in
+    // this file work on EngineStore search engine objects.
+    let appProvidedEngines = (
+      await Services.search.getAppProvidedEngines()
+    ).map(this._cloneEngine, this);
 
-    for (var i = 0; i < this.#appProvidedEngines.length; ++i) {
-      var e = this.#appProvidedEngines[i];
+    for (var i = 0; i < appProvidedEngines.length; ++i) {
+      var e = appProvidedEngines[i];
 
       // If the engine is already in the list, just move it.
       if (this.engines.some(this._isSameEngine, e)) {
@@ -773,7 +773,10 @@ class EngineStore {
       let engine = Services.search.getEngineByName(engineName);
       if (engine) {
         try {
-          await Services.search.removeEngine(engine);
+          await Services.search.removeEngine(
+            engine,
+            Ci.nsISearchService.CHANGE_REASON_ENTERPRISE
+          );
         } catch (ex) {
           // Engine might not exist
         }
@@ -801,10 +804,13 @@ class EngineStore {
  * Manages the view of the Search Shortcuts tree on the search pane of preferences.
  */
 class EngineView {
-  _engineStore = null;
+  _engineStore;
   _engineList = null;
   tree = null;
 
+  /**
+   * @param {EngineStore} aEngineStore
+   */
   constructor(aEngineStore) {
     this._engineStore = aEngineStore;
     this._engineList = document.getElementById("engineList");
@@ -955,6 +961,61 @@ class EngineView {
     );
   }
 
+  /**
+   * Removes a search engine from the search service.
+   *
+   * Application provided engines are removed without confirmation since they
+   * can easily be restored. Addon engines are not removed (see comment).
+   * For other engine types, the user is prompted for confirmation.
+   *
+   * @param {object} engine
+   *   The search engine object from EngineStore to remove.
+   */
+  async promptAndRemoveEngine(engine) {
+    if (engine.isAppProvided) {
+      Services.search.removeEngine(
+        this.selectedEngine.originalEngine,
+        Ci.nsISearchService.CHANGE_REASON_USER
+      );
+      return;
+    }
+
+    if (engine.isAddonEngine) {
+      // Addon engines will re-appear after restarting, see Bug 1546652.
+      // This should ideally prompt the user if they want to remove the addon.
+      let msg = await document.l10n.formatValue("remove-addon-engine-alert");
+      alert(msg);
+      return;
+    }
+
+    let [body, removeLabel] = await document.l10n.formatValues([
+      "remove-engine-confirmation",
+      "remove-engine-remove",
+    ]);
+
+    let button = Services.prompt.confirmExBC(
+      window.browsingContext,
+      Services.prompt.MODAL_TYPE_CONTENT,
+      null,
+      body,
+      (Services.prompt.BUTTON_TITLE_IS_STRING * Services.prompt.BUTTON_POS_0) |
+        (Services.prompt.BUTTON_TITLE_CANCEL * Services.prompt.BUTTON_POS_1),
+      removeLabel,
+      null,
+      null,
+      null,
+      {}
+    );
+
+    // Button 0 is the remove button.
+    if (button == 0) {
+      Services.search.removeEngine(
+        this.selectedEngine.originalEngine,
+        Ci.nsISearchService.CHANGE_REASON_USER
+      );
+    }
+  }
+
   /**
    * Returns the local shortcut corresponding to a tree row, or null if the row
    * is not a local shortcut.
@@ -1026,14 +1087,19 @@ class EngineView {
             this.#onRestoreDefaults();
             break;
           case "removeEngineButton":
-            Services.search.removeEngine(this.selectedEngine.originalEngine);
+            if (this.isEngineSelectedAndRemovable()) {
+              this.promptAndRemoveEngine(this.selectedEngine);
+            }
             break;
           case "editEngineButton":
-            gSubDialog.open(
-              "chrome://browser/content/search/addEngine.xhtml",
-              { features: "resizable=no, modal=yes" },
-              { engine: this.selectedEngine.originalEngine, mode: "EDIT" }
-            );
+            if (this.selectedEngine.isUserEngine) {
+              let engine = this.selectedEngine.originalEngine.wrappedJSObject;
+              gSubDialog.open(
+                "chrome://browser/content/search/addEngine.xhtml",
+                { features: "resizable=no, modal=yes" },
+                { engine, mode: "EDIT" }
+              );
+            }
             break;
           case "addEngineButton":
             gSubDialog.open(
@@ -1126,11 +1192,12 @@ class EngineView {
         aEvent.keyCode == KeyEvent.DOM_VK_DELETE ||
         (isMac &&
           aEvent.shiftKey &&
-          aEvent.keyCode == KeyEvent.DOM_VK_BACK_SPACE &&
-          this.isEngineSelectedAndRemovable())
+          aEvent.keyCode == KeyEvent.DOM_VK_BACK_SPACE)
       ) {
         // Delete and Shift+Backspace (Mac) removes selected engine.
-        Services.search.removeEngine(this.selectedEngine.originalEngine);
+        if (this.isEngineSelectedAndRemovable()) {
+          this.promptAndRemoveEngine(this.selectedEngine);
+        }
       }
     }
   }
