@@ -18,7 +18,7 @@ function checkMenulistPermissionItem(origin, state) {
   let doc = sitePermissionsDialog.document;
 
   let label = doc.getElementsByTagName("label")[3];
-  Assert.equal(label.value, origin);
+  Assert.equal(label.textContent, origin);
 
   let menulist = doc.getElementsByTagName("menulist")[0];
   Assert.equal(menulist.value, state);
@@ -589,7 +589,7 @@ add_task(async function addSpeakerPermission() {
   let speakerRow =
     gBrowser.contentDocument.getElementById("speakerSettingsRow");
   Assert.equal(
-    BrowserTestUtils.is_visible(speakerRow),
+    BrowserTestUtils.isVisible(speakerRow),
     enabled,
     "speakerRow visible"
   );
@@ -628,8 +628,7 @@ add_task(async function addSpeakerPermission() {
   );
   // The website status element is not a menulist because all-device allow is
   // not an option.
-  Assert.equal(siteStatus.tagName, "hbox");
-  Assert.equal(siteStatus.firstElementChild.tagName, "label");
+  Assert.equal(siteStatus.tagName, "label");
 
   PermissionTestUtils.remove(URI, devicePermissionId);
   PermissionTestUtils.remove(URI, "speaker");
@@ -637,6 +636,44 @@ add_task(async function addSpeakerPermission() {
   doc.querySelector("dialog").getButton("cancel").click();
 });
 
+add_task(async function testLocalNetworkAccessPermissionVisibility() {
+  let enabled = Services.prefs.getBoolPref("network.lna.blocking", false);
+  let localHostSettingsRow = gBrowser.contentDocument.getElementById(
+    "localHostSettingsRow"
+  );
+  let localNetworkSettingsRow = gBrowser.contentDocument.getElementById(
+    "localNetworkSettingsRow"
+  );
+
+  Assert.equal(
+    BrowserTestUtils.isVisible(localNetworkSettingsRow),
+    enabled,
+    "localhost permissions visible"
+  );
+  Assert.equal(
+    BrowserTestUtils.isVisible(localHostSettingsRow),
+    enabled,
+    "localhost permissions visible"
+  );
+
+  enabled = !enabled;
+  Services.prefs.setBoolPref("network.lna.blocking", enabled);
+
+  Assert.equal(
+    BrowserTestUtils.isVisible(localHostSettingsRow),
+    enabled,
+    "localhost permissions toggle"
+  );
+
+  Assert.equal(
+    BrowserTestUtils.isVisible(localNetworkSettingsRow),
+    enabled,
+    "localhost permissions toggle"
+  );
+
+  Services.prefs.setBoolPref("network.lna.blocking", !enabled);
+});
+
 add_task(async function removeTab() {
   gBrowser.removeCurrentTab();
 });
