@@ -5,9 +5,7 @@
 // This test makes sure that the window title changes correctly while switching
 // from and to private browsing mode.
 
-const { AppConstants } = ChromeUtils.import(
-  "resource://gre/modules/AppConstants.jsm"
-);
+"use strict";
 
 add_task(async function test() {
   const testPageURL =
@@ -23,7 +21,7 @@ add_task(async function test() {
   //                    to compare with the actual values.
   const isMacOS = AppConstants.platform == "macosx";
 
-  let pb_postfix = isMacOS ? ` — (Private Browsing)` : ` (Private Browsing)`;
+  let pb_postfix = isMacOS ? ` — Private Browsing` : ` Private Browsing`;
   let page_with_title = isMacOS ? test_title : `${test_title} — ${app_name}`;
   let page_without_title = app_name;
   let about_pb_title = app_name;
@@ -35,8 +33,8 @@ add_task(async function test() {
 
   async function testTabTitle(aWindow, url, insidePB, expected_title) {
     let tab = await BrowserTestUtils.openNewForegroundTab(aWindow.gBrowser);
-    BrowserTestUtils.loadURI(tab.linkedBrowser, url);
-    await BrowserTestUtils.browserLoaded(tab.linkedBrowser);
+    BrowserTestUtils.startLoadingURIString(tab.linkedBrowser, url);
+    await BrowserTestUtils.browserLoaded(tab.linkedBrowser, { wantLoad: url });
 
     await BrowserTestUtils.waitForCondition(() => {
       return aWindow.document.title === expected_title;
@@ -75,8 +73,8 @@ add_task(async function test() {
     ]);
   }
 
-  function openWin(private) {
-    return BrowserTestUtils.openNewBrowserWindow({ private });
+  function openWin(isPrivate) {
+    return BrowserTestUtils.openNewBrowserWindow({ private: isPrivate });
   }
   await testTabTitle(
     await openWin(false),
@@ -109,4 +107,34 @@ add_task(async function test() {
     true,
     pb_about_pb_title
   );
+
+  await SpecialPowers.pushPrefEnv({
+    set: [["privacy.exposeContentTitleInWindow.pbm", false]],
+  });
+  await testTabTitle(await openWin(false), testPageURL, false, page_with_title);
+  await testTabTitle(
+    await openWin(true),
+    testPageURL,
+    true,
+    pb_page_without_title
+  );
+  await SpecialPowers.pushPrefEnv({
+    set: [
+      ["privacy.exposeContentTitleInWindow", false],
+      ["privacy.exposeContentTitleInWindow.pbm", true],
+    ],
+  });
+  await testTabTitle(
+    await openWin(false),
+    testPageURL,
+    false,
+    page_without_title
+  );
+  // The generic preference set to false is intended to override the PBM one
+  await testTabTitle(
+    await openWin(true),
+    testPageURL,
+    true,
+    pb_page_without_title
+  );
 });
