@@ -17,7 +17,7 @@
     BrowserUtils: "resource://gre/modules/BrowserUtils.sys.mjs",
     FormHistory: "resource://gre/modules/FormHistory.sys.mjs",
     SearchSuggestionController:
-      "resource://gre/modules/SearchSuggestionController.sys.mjs",
+      "moz-src:///toolkit/components/search/SearchSuggestionController.sys.mjs",
   });
 
   /**
@@ -332,7 +332,6 @@
 
       lazy.BrowserSearchTelemetry.recordSearchSuggestionSelectionMethod(
         aEvent,
-        "searchbar",
         selectedIndex
       );
 
@@ -379,7 +378,7 @@
         );
       }
 
-      let submission = engine.getSubmission(aData, null, "searchbar");
+      let submission = engine.getSubmission(aData, null);
 
       // If we hit here, we come either from a one-off, a plain search or a suggestion.
       const details = {
@@ -389,13 +388,6 @@
 
       this.telemetrySelectedIndex = -1;
 
-      lazy.BrowserSearchTelemetry.recordSearch(
-        gBrowser.selectedBrowser,
-        engine,
-        "searchbar",
-        details
-      );
-
       // Record when the user uses the search bar
       Services.prefs.setStringPref(
         "browser.search.widget.lastUsed",
@@ -414,6 +406,28 @@
           params[key] = aParams[key];
         }
       }
+
+      if (aWhere == "tab") {
+        gBrowser.tabContainer.addEventListener(
+          "TabOpen",
+          event =>
+            lazy.BrowserSearchTelemetry.recordSearch(
+              event.target.linkedBrowser,
+              engine,
+              "searchbar",
+              details
+            ),
+          { once: true }
+        );
+      } else {
+        lazy.BrowserSearchTelemetry.recordSearch(
+          gBrowser.selectedBrowser,
+          engine,
+          "searchbar",
+          details
+        );
+      }
+
       openTrustedLinkIn(submission.uri.spec, aWhere, params);
     }
 
@@ -505,6 +519,7 @@
         this._needBrowserFocusAtEnterKeyUp = true;
       }
 
+      lazy.BrowserSearchTelemetry.recordSearchForm(engine, "searchbar");
       openTrustedLinkIn(searchForm, where, params);
     }
 
@@ -562,6 +577,8 @@
           // If the input field is still focused then a different window has
           // received focus, ignore the next focus event.
           this._ignoreFocus = document.activeElement == this._textbox;
+
+          this.textbox.mController.resetSession();
         },
         true
       );
@@ -770,8 +787,7 @@
         let searchIcon = document.querySelector(".searchbar-search-button");
         searchIcon.setAttribute("aria-expanded", popup.popupOpen);
         if (popup.popupOpen) {
-          let suggestionsHidden =
-            popup.richlistbox.getAttribute("collapsed") == "true";
+          let suggestionsHidden = popup.richlistbox.hasAttribute("collapsed");
           let numItems = suggestionsHidden ? 0 : popup.matchCount;
           return popup.oneOffButtons.handleKeyDown(aEvent, numItems, true);
         } else if (aEvent.keyCode == KeyEvent.DOM_VK_ESCAPE) {
@@ -780,6 +796,7 @@
           } else {
             this.textbox.select();
           }
+          aEvent.preventDefault();
           return true;
         }
         return false;
