@@ -29,57 +29,37 @@ async function checkHeader(engine) {
   // The header can be updated after getting the engine, so we may have to
   // wait for it.
   let header = searchPopup.searchbarEngineName;
-  if (!header.getAttribute("value").includes(engine.name)) {
-    await new Promise(resolve => {
-      let observer = new MutationObserver(() => {
-        observer.disconnect();
-        resolve();
-      });
-      observer.observe(searchPopup.searchbarEngineName, {
-        attributes: true,
-        attributeFilter: ["value"],
-      });
-    });
-  }
+  await TestUtils.waitForCondition(
+    () => header.getAttribute("value").includes(engine.name),
+    "Should have the correct engine name displayed in the header"
+  );
   Assert.ok(
     header.getAttribute("value").includes(engine.name),
     "Should have the correct engine name displayed in the header"
   );
 }
 
-add_task(async function setup() {
+add_setup(async function () {
   searchbar = await gCUITestUtils.addSearchBar();
   textbox = searchbar.textbox;
 
-  let defaultEngine = await Services.search.getDefault();
-  let engine = await SearchTestUtils.promiseNewSearchEngine(
-    getRootDirectory(gTestPath) + "testEngine.xml"
-  );
-  await Services.search.setDefault(engine);
+  await SearchTestUtils.installOpenSearchEngine({
+    url: getRootDirectory(gTestPath) + "testEngine.xml",
+    setAsDefault: true,
+  });
   // First cleanup the form history in case other tests left things there.
-  await new Promise((resolve, reject) => {
-    info("cleanup the search history");
-    searchbar.FormHistory.update(
-      { op: "remove", fieldname: "searchbar-history" },
-      { handleCompletion: resolve, handleError: reject }
-    );
-  });
+  info("cleanup the search history");
+  await FormHistory.update({ op: "remove", fieldname: "searchbar-history" });
 
-  await new Promise((resolve, reject) => {
-    info("adding search history values: " + kValues);
-    let addOps = kValues.map(value => {
-      return { op: "add", fieldname: "searchbar-history", value };
-    });
-    searchbar.FormHistory.update(addOps, {
-      handleCompletion: resolve,
-      handleError: reject,
-    });
+  info("adding search history values: " + kValues);
+  let addOps = kValues.map(value => {
+    return { op: "add", fieldname: "searchbar-history", value };
   });
+  await FormHistory.update(addOps);
 
   textbox.value = kUserValue;
 
   registerCleanupFunction(async () => {
-    await Services.search.setDefault(defaultEngine);
     gCUITestUtils.removeSearchBar();
   });
 });
@@ -102,11 +82,16 @@ add_task(async function test_arrows() {
   // The tests will be less meaningful if the first, second, last, and
   // before-last one-off buttons aren't different. We should always have more
   // than 4 default engines, but it's safer to check this assumption.
-  let oneOffs = getOneOffs();
-  ok(oneOffs.length >= 4, "we have at least 4 one-off buttons displayed");
+  let oneOffs = await getOneOffs();
+  Assert.greaterOrEqual(
+    oneOffs.length,
+    4,
+    "we have at least 4 one-off buttons displayed"
+  );
 
   ok(!textbox.selectedButton, "no one-off button should be selected");
 
+  await checkHeader(Services.search.defaultEngine);
   // The down arrow should first go through the suggestions.
   for (let i = 0; i < kValues.length; ++i) {
     EventUtils.synthesizeKey("KEY_ArrowDown");
@@ -234,7 +219,7 @@ add_task(async function test_tab() {
     "the search bar should be focused"
   ); // from the previous test.
 
-  let oneOffs = getOneOffs();
+  let oneOffs = await getOneOffs();
   ok(!textbox.selectedButton, "no one-off button should be selected");
 
   // Pressing tab should select the first one-off without selecting suggestions.
@@ -263,10 +248,9 @@ add_task(async function test_tab() {
   await promise;
 
   // ... and move the focus out of the searchbox.
-  isnot(
-    Services.focus.focusedElement,
-    textbox.inputField,
-    "the search bar no longer be focused"
+  ok(
+    !Services.focus.focusedElement.classList.contains("searchbar-textbox"),
+    "the search input in the search bar should no longer be focused"
   );
 });
 
@@ -277,7 +261,7 @@ add_task(async function test_shift_tab() {
   searchbar.focus();
   await promise;
 
-  let oneOffs = getOneOffs();
+  let oneOffs = await getOneOffs();
   ok(!textbox.selectedButton, "no one-off button should be selected");
 
   // Press up once to select the last button.
@@ -310,11 +294,27 @@ add_task(async function test_shift_tab() {
   await promise;
 
   // ... and move the focus out of the searchbox.
-  isnot(
-    Services.focus.focusedElement,
-    textbox.inputField,
-    "the search bar no longer be focused"
+  ok(
+    !Services.focus.focusedElement.classList.contains("searchbar-textbox"),
+    "the search input in the search bar should no longer be focused"
   );
+
+  // Return the focus to the search bar
+  EventUtils.synthesizeKey("KEY_Tab");
+  ok(
+    Services.focus.focusedElement.classList.contains("searchbar-textbox"),
+    "the search bar should be focused"
+  );
+
+  // ... and confirm the input value was autoselected and is replaced.
+  EventUtils.synthesizeKey("fo");
+  is(
+    Services.focus.focusedElement.value,
+    "fo",
+    "when the search bar was focused, the value should be autoselected"
+  );
+  // Return to the expected value
+  EventUtils.synthesizeKey("o");
 });
 
 add_task(async function test_alt_down() {
@@ -341,7 +341,7 @@ add_task(async function test_alt_down() {
 
   // Pressing alt+down should select the first one-off without selecting suggestions
   // and cycle through the one-off items.
-  let oneOffs = getOneOffs();
+  let oneOffs = await getOneOffs();
   for (let i = 0; i < oneOffs.length; ++i) {
     EventUtils.synthesizeKey("KEY_ArrowDown", { altKey: true });
     is(
@@ -387,7 +387,7 @@ add_task(async function test_alt_up() {
 
   // Pressing alt+up should select the last one-off without selecting suggestions
   // and cycle up through the one-off items.
-  let oneOffs = getOneOffs();
+  let oneOffs = await getOneOffs();
   for (let i = oneOffs.length - 1; i >= 0; --i) {
     EventUtils.synthesizeKey("KEY_ArrowUp", { altKey: true });
     is(
@@ -446,7 +446,10 @@ add_task(async function test_accel_down() {
     );
     is(searchPopup.selectedIndex, -1, "no suggestion should be selected");
   }
-  Services.search.defaultEngine = current;
+  await Services.search.setDefault(
+    current,
+    Ci.nsISearchService.CHANGE_REASON_UNKNOWN
+  );
 });
 
 add_task(async function test_accel_up() {
@@ -476,7 +479,10 @@ add_task(async function test_accel_up() {
     );
     is(searchPopup.selectedIndex, -1, "no suggestion should be selected");
   }
-  Services.search.defaultEngine = current;
+  await Services.search.setDefault(
+    current,
+    Ci.nsISearchService.CHANGE_REASON_UNKNOWN
+  );
 });
 
 add_task(async function test_tab_and_arrows() {
@@ -493,7 +499,7 @@ add_task(async function test_tab_and_arrows() {
 
   // After pressing tab, the first one-off should be selected,
   // and no suggestion should be selected.
-  let oneOffs = getOneOffs();
+  let oneOffs = await getOneOffs();
   EventUtils.synthesizeKey("KEY_Tab");
   is(
     textbox.selectedButton,
@@ -614,7 +620,7 @@ add_task(async function test_open_search() {
 
   // Pressing up again should select the last one-off button.
   EventUtils.synthesizeKey("KEY_ArrowUp");
-  const allOneOffs = getOneOffs();
+  const allOneOffs = await getOneOffs();
   is(
     textbox.selectedButton,
     allOneOffs[allOneOffs.length - engines.length - 1],
@@ -650,7 +656,7 @@ add_task(async function cleanup() {
   let removeOps = kValues.map(value => {
     return { op: "remove", fieldname: "searchbar-history", value };
   });
-  searchbar.FormHistory.update(removeOps);
+  await FormHistory.update(removeOps);
 
   textbox.value = "";
 });
