@@ -27,6 +27,9 @@ const TEST_PROVIDER_INFO = [
     shoppingTab: {
       regexp: "&site=shop",
     },
+    searchMode: {
+      mode: "image_search",
+    },
     components: [
       {
         type: SearchSERPTelemetryUtils.COMPONENTS.AD_LINK,
@@ -103,6 +106,33 @@ const TEST_PROVIDER_INFO = [
       },
     ],
   },
+  {
+    telemetryId: "example5",
+    searchPageRegexp: /^https:\/\/www\.example5\.com\/search/,
+    queryParamNames: ["a", "q"],
+    codeParamName: "abc",
+    taggedCodes: ["ff", "tb"],
+    expectedOrganicCodes: ["baz"],
+    organicCodes: ["foo"],
+    followOnParamNames: ["a"],
+    followOnCookies: [
+      {
+        host: "www.example5.com",
+        name: "_dummyCookieName",
+        codeParamName: "abc",
+        // No required extra code param/prefixes.
+        extraCodePrefixes: [],
+        extraCodeParamName: "",
+      },
+    ],
+    extraAdServersRegexps: [/^https:\/\/www\.example\.com\/ad2/],
+    components: [
+      {
+        type: SearchSERPTelemetryUtils.COMPONENTS.AD_LINK,
+        default: true,
+      },
+    ],
+  },
 ];
 
 const TESTS = [
@@ -142,6 +172,25 @@ const TESTS = [
       is_signed_in: "false",
     },
   },
+  {
+    title: "Tagged image search",
+    trackingUrl: "https://www.example.com/search?q=test&abc=ff&mode=image",
+    expectedSearchCountEntry: "example:tagged:ff",
+    expectedAdKey: "example:tagged",
+    adUrls: ["https://www.example.com/ad2"],
+    nonAdUrls: ["https://www.example.com/ad3"],
+    impression: {
+      provider: "example",
+      tagged: "true",
+      partner_code: "ff",
+      search_mode: "image_search",
+      source: "unknown",
+      is_shopping_page: "false",
+      is_private: "false",
+      shopping_tab_displayed: "false",
+      is_signed_in: "false",
+    },
+  },
   {
     title: "Tagged follow-on",
     trackingUrl: "https://www.example.com/search?q=test&abc=tb&a=next",
@@ -163,7 +212,7 @@ const TESTS = [
   {
     setUp() {
       Services.cookies.removeAll();
-      Services.cookies.add(
+      const cv = Services.cookies.add(
         "www.example3.com",
         "/",
         "_dummyCookieName",
@@ -171,11 +220,12 @@ const TESTS = [
         false,
         false,
         false,
-        Date.now() + 1000 * 60 * 60,
+        Date.now() + 10 * 60 * 60 * 1000,
         {},
-        Ci.nsICookie.SAMESITE_NONE,
+        Ci.nsICookie.SAMESITE_UNSET,
         Ci.nsICookie.SCHEME_HTTPS
       );
+      Assert.equal(cv.result, Ci.nsICookieValidation.eOK, "Valid cookie");
     },
     tearDown() {
       Services.cookies.removeAll();
@@ -201,7 +251,7 @@ const TESTS = [
   {
     setUp() {
       Services.cookies.removeAll();
-      Services.cookies.add(
+      const cv = Services.cookies.add(
         "www.example4.com",
         "/",
         "_dummyCookieName",
@@ -209,11 +259,12 @@ const TESTS = [
         false,
         false,
         false,
-        Date.now() + 1000 * 60 * 60,
+        Date.now() + 10 * 60 * 60 * 1000,
         {},
-        Ci.nsICookie.SAMESITE_NONE,
+        Ci.nsICookie.SAMESITE_UNSET,
         Ci.nsICookie.SCHEME_HTTPS
       );
+      Assert.equal(cv.result, Ci.nsICookieValidation.eOK, "Valid cookie");
     },
     tearDown() {
       Services.cookies.removeAll();
@@ -237,6 +288,43 @@ const TESTS = [
       is_signed_in: "false",
     },
   },
+  {
+    setUp() {
+      Services.cookies.removeAll();
+      Services.cookies.add(
+        "www.example5.com",
+        "/",
+        "_dummyCookieName",
+        "abc=tb&def=ghi",
+        false,
+        false,
+        false,
+        Date.now() + 10 * 60 * 60 * 1000,
+        {},
+        Ci.nsICookie.SAMESITE_UNSET,
+        Ci.nsICookie.SCHEME_HTTPS
+      );
+    },
+    tearDown() {
+      Services.cookies.removeAll();
+    },
+    title: "Tagged follow-on with cookie and no required url param",
+    trackingUrl: "https://www.example5.com/search?q=test&a=next",
+    expectedSearchCountEntry: "example5:tagged-follow-on:tb",
+    expectedAdKey: "example5:tagged-follow-on",
+    adUrls: ["https://www.example.com/ad2"],
+    nonAdUrls: ["https://www.example.com/ad3"],
+    impression: {
+      provider: "example5",
+      tagged: "true",
+      partner_code: "tb",
+      source: "unknown",
+      is_shopping_page: "false",
+      is_private: "false",
+      shopping_tab_displayed: "false",
+      is_signed_in: "false",
+    },
+  },
   {
     title: "Organic search matched code",
     trackingUrl: "https://www.example.com/search?q=test&abc=foo",
