@@ -5,13 +5,13 @@
 function test() {
   waitForExplicitFinish();
 
-  let tab1 = BrowserTestUtils.addTab(gBrowser, "about:rights");
+  let tab1 = BrowserTestUtils.addTab(gBrowser, "about:robots");
   let tab2 = BrowserTestUtils.addTab(gBrowser, "about:mozilla");
 
   promiseBrowserLoaded(tab1.linkedBrowser).then(() => {
     // Tell the session storer that the tab is pinned
     let newTabState =
-      '{"entries":[{"url":"about:rights"}],"pinned":true,"userTypedValue":"Hello World!"}';
+      '{"entries":[{"url":"about:robots"}],"pinned":true,"userTypedValue":"Hello World!"}';
     ss.setTabState(tab1, newTabState);
 
     // Undo pinning
@@ -19,7 +19,7 @@ function test() {
 
     // Close and restore tab
     gBrowser.removeTab(tab1);
-    let savedState = JSON.parse(ss.getClosedTabData(window))[0].state;
+    let savedState = ss.getClosedTabDataForWindow(window)[0].state;
     isnot(savedState.pinned, true, "Pinned should not be true");
     tab1 = ss.undoCloseTab(window, 0);
 
