@@ -3,7 +3,7 @@
 async function createTabWithRandomValue(url) {
   let tab = BrowserTestUtils.addTab(gBrowser, url);
   let browser = tab.linkedBrowser;
-  await promiseBrowserLoaded(browser);
+  await BrowserTestUtils.browserLoaded(browser, { wantLoad: url });
 
   // Set a random value.
   let r = `rand-${Math.random()}`;
@@ -16,12 +16,12 @@ async function createTabWithRandomValue(url) {
 }
 
 function isValueInClosedData(rval) {
-  return JSON.stringify(ss.getClosedTabData(window)).includes(rval);
+  return JSON.stringify(ss.getClosedTabDataForWindow(window)).includes(rval);
 }
 
 function restoreClosedTabWithValue(rval) {
-  let closedTabData = ss.getClosedTabData(window);
-  let index = closedTabData.findIndex(function(data) {
+  let closedTabData = ss.getClosedTabDataForWindow(window);
+  let index = closedTabData.findIndex(function (data) {
     return (data.state.extData && data.state.extData.foobar) == rval;
   });
 
@@ -83,7 +83,7 @@ add_task(async function save_worthy_tabs_remote_final() {
 
   // Replace about:blank with a new remote page.
   let entryReplaced = promiseOnHistoryReplaceEntry(browser);
-  browser.loadURI("https://example.com/", {
+  browser.loadURI(Services.io.newURI("https://example.com/"), {
     triggeringPrincipal: Services.scriptSecurityManager.getSystemPrincipal(),
   });
   await entryReplaced;
@@ -92,15 +92,7 @@ add_task(async function save_worthy_tabs_remote_final() {
   ok(browser.isRemoteBrowser, "browser is still remote");
 
   // Remove the tab before the update arrives.
-  let promise = promiseRemoveTabAndSessionState(tab);
-
-  // With SHIP, we'll do the final tab state update sooner than we did before.
-  if (!Services.appinfo.sessionHistoryInParent) {
-    // No tab state worth saving (that we know about yet).
-    ok(!isValueInClosedData(r), "closed tab not saved");
-  }
-
-  await promise;
+  await promiseRemoveTabAndSessionState(tab);
 
   // Turns out there is a tab state worth saving.
   ok(isValueInClosedData(r), "closed tab saved");
@@ -112,20 +104,12 @@ add_task(async function save_worthy_tabs_nonremote_final() {
   ok(browser.isRemoteBrowser, "browser is remote");
 
   // Replace about:blank with a non-remote entry.
-  BrowserTestUtils.loadURI(browser, "about:robots");
+  BrowserTestUtils.startLoadingURIString(browser, "about:robots");
   await BrowserTestUtils.browserLoaded(browser);
   ok(!browser.isRemoteBrowser, "browser is not remote anymore");
 
   // Remove the tab before the update arrives.
-  let promise = promiseRemoveTabAndSessionState(tab);
-
-  // With SHIP, we'll do the final tab state update sooner than we did before.
-  if (!Services.appinfo.sessionHistoryInParent) {
-    // No tab state worth saving (that we know about yet).
-    ok(!isValueInClosedData(r), "closed tab not saved");
-  }
-
-  await promise;
+  await promiseRemoveTabAndSessionState(tab);
 
   // Turns out there is a tab state worth saving.
   ok(isValueInClosedData(r), "closed tab saved");
@@ -141,7 +125,7 @@ add_task(async function dont_save_empty_tabs_final() {
 
   // We're doing a cross origin navigation, so we can't reliably use a
   // SpecialPowers task here. Instead we just emulate a location.replace() call.
-  browser.loadURI("about:blank", {
+  browser.loadURI(Services.io.newURI("about:blank"), {
     loadFlags:
       Ci.nsIWebNavigation.LOAD_FLAGS_STOP_CONTENT |
       Ci.nsIWebNavigation.LOAD_FLAGS_REPLACE_HISTORY,
@@ -151,15 +135,7 @@ add_task(async function dont_save_empty_tabs_final() {
   await entryReplaced;
 
   // Remove the tab before the update arrives.
-  let promise = promiseRemoveTabAndSessionState(tab);
-
-  // With SHIP, we'll do the final tab state update sooner than we did before.
-  if (!Services.appinfo.sessionHistoryInParent) {
-    // Tab state deemed worth saving (yet).
-    ok(isValueInClosedData(r), "closed tab saved");
-  }
-
-  await promise;
+  await promiseRemoveTabAndSessionState(tab);
 
   // Turns out we don't want to save the tab state.
   ok(!isValueInClosedData(r), "closed tab not saved");
