@@ -12,14 +12,14 @@ const STATE = {
  * as pending and correctly finish the instructed load while keeping the
  * restored history around.
  */
-add_task(async function() {
+add_task(async function () {
   await testSwitchToTab("about:mozilla#fooobar", {
     ignoreFragment: "whenComparingAndReplace",
   });
   await testSwitchToTab("about:mozilla?foo=bar", { replaceQueryString: true });
 });
 
-var testSwitchToTab = async function(url, options) {
+var testSwitchToTab = async function (url, options) {
   // Create a background tab.
   let tab = BrowserTestUtils.addTab(gBrowser, "about:blank");
   let browser = tab.linkedBrowser;
@@ -34,7 +34,8 @@ var testSwitchToTab = async function(url, options) {
   ok(tab.hasAttribute("pending"), "tab is pending");
   await promise;
 
-  options.triggeringPrincipal = Services.scriptSecurityManager.getSystemPrincipal();
+  options.triggeringPrincipal =
+    Services.scriptSecurityManager.getSystemPrincipal();
 
   // Switch-to-tab with a similar URI.
   switchToTabHavingURI(url, false, options);
@@ -44,7 +45,7 @@ var testSwitchToTab = async function(url, options) {
   is(browser.currentURI.spec, url, "correct URL loaded");
 
   // Check that we didn't lose any history entries.
-  await SpecialPowers.spawn(browser, [], async function() {
+  await SpecialPowers.spawn(browser, [], async function () {
     let webNavigation = docShell.QueryInterface(Ci.nsIWebNavigation);
     let history = webNavigation.sessionHistory;
     Assert.equal(history && history.count, 3, "three history entries");
