@@ -10,12 +10,13 @@
 #include "nsString.h"
 #include "nsToolkitShellService.h"
 #include "nsIShellService.h"
+#include "nsIWindowsShellService.h"
 
 #include <windows.h>
 #include <ole2.h>
 
-class nsWindowsShellService : public nsIShellService,
-                              public nsToolkitShellService {
+class nsWindowsShellService : public nsToolkitShellService,
+                              public nsIWindowsShellService {
   virtual ~nsWindowsShellService();
 
  public:
@@ -23,13 +24,11 @@ class nsWindowsShellService : public nsIShellService,
 
   NS_DECL_ISUPPORTS
   NS_DECL_NSISHELLSERVICE
+  NS_DECL_NSIWINDOWSSHELLSERVICE
 
  protected:
   nsresult LaunchControlPanelDefaultsSelectionUI();
-  nsresult LaunchControlPanelDefaultPrograms();
   nsresult LaunchModernSettingsDialogDefaultApps();
-  nsresult InvokeHTTPOpenAsVerb();
-  nsresult LaunchHTTPHandlerPane();
 };
 
 #endif  // nswindowsshellservice_h____
