@@ -7,8 +7,7 @@ requestLongerTimeout(10);
 
 const lazy = {};
 
-const TAB_DIRECTION_PREF = "sidebar.verticalTabs";
-const initialTabDirection = Services.prefs.getBoolPref(TAB_DIRECTION_PREF)
+const initialTabDirection = Services.prefs.getBoolPref(VERTICAL_TABS_PREF)
   ? "vertical"
   : "horizontal";
 
@@ -25,9 +24,7 @@ add_setup(async () => {
 });
 
 registerCleanupFunction(() => {
-  while (gBrowser.tabs.length > 1) {
-    BrowserTestUtils.removeTab(gBrowser.tabs[0]);
-  }
+  cleanUpExtraTabs();
 });
 
 function getExpectedVersionString() {
@@ -49,7 +46,7 @@ add_task(async function test_metrics_initialized() {
 add_task(async function test_sidebar_expand() {
   await SidebarController.initializeUIState({ launcherExpanded: false });
   await SpecialPowers.pushPrefEnv({
-    set: [[TAB_DIRECTION_PREF, true]],
+    set: [[VERTICAL_TABS_PREF, true]],
   });
   await waitForTabstripOrientation("vertical");
   // Vertical tabs are expanded by default
@@ -235,30 +232,21 @@ add_task(async function test_extension_sidebar_toggle() {
   Assert.equal(events?.length, 2, "Two events were reported.");
 });
 
-add_task(async function test_review_checker_sidebar_toggle() {
-  const gleanEvent = Glean.shopping.sidebarToggle;
-  await testSidebarToggle("viewReviewCheckerSidebar", gleanEvent);
-  for (const { extra } of gleanEvent.testGetValue()) {
-    Assert.equal(
-      extra.version,
-      getExpectedVersionString(),
-      "Event has the correct sidebar version."
-    );
-  }
-});
-
 add_task(async function test_contextual_manager_toggle() {
   await SpecialPowers.pushPrefEnv({
-    set: [
-      ["browser.contextual-password-manager.enabled", true],
-      ["sidebar.revamp", false],
-    ],
+    set: [["browser.contextual-password-manager.enabled", true]],
   });
   await SidebarController.waitUntilStable();
   const gleanEvent = Glean.contextualManager.sidebarToggle;
   await testSidebarToggle("viewCPMSidebar", gleanEvent);
+  await testCustomizeToggle(
+    "viewCPMSidebar",
+    Glean.contextualManager.passwordsEnabled,
+    false // Remove this in bug 1957425
+  );
   await SpecialPowers.popPrefEnv();
   await SidebarController.waitUntilStable();
+  Services.fog.testResetFOG();
 });
 
 add_task(async function test_customize_panel_toggle() {
@@ -365,18 +353,6 @@ add_task(async function test_customize_bookmarks_enabled() {
   );
 });
 
-add_task(async function test_customize_review_checker_enabled() {
-  await SpecialPowers.pushPrefEnv({
-    set: [["browser.shopping.experience2023.integratedSidebar", true]],
-  });
-  await testCustomizeToggle(
-    "viewReviewCheckerSidebar",
-    Glean.sidebarCustomize.shoppingReviewCheckerEnabled
-  );
-  await SpecialPowers.popPrefEnv();
-  await SidebarController.waitUntilStable();
-});
-
 add_task(async function test_customize_extensions_clicked() {
   info("Load an extension.");
   const extension = ExtensionTestUtils.loadExtension({ ...extData });
@@ -391,17 +367,18 @@ add_task(async function test_customize_extensions_clicked() {
     );
 
   info("Click on the extension link.");
-  const deferredEMLoaded = Promise.withResolvers();
-  Services.obs.addObserver(function observer(_, topic) {
-    Services.obs.removeObserver(observer, topic);
-    deferredEMLoaded.resolve();
-  }, "EM-loaded");
+  let browserLocationChanged = BrowserTestUtils.waitForLocationChange(
+    window.gBrowser,
+    "about:addons"
+  );
+  customizeComponent.extensionLink.focus();
+
   EventUtils.synthesizeMouseAtCenter(
-    customizeComponent.extensionLinks[0],
+    customizeComponent.extensionLink,
     {},
     SidebarController.browser.contentWindow
   );
-  await deferredEMLoaded.promise;
+  await browserLocationChanged;
 
   const events = Glean.sidebarCustomize.extensionsClicked.testGetValue();
   Assert.equal(events.length, 1, "One event was reported.");
@@ -448,7 +425,7 @@ async function testCustomizeSetting(
 
 add_task(async function test_customize_sidebar_display() {
   await SpecialPowers.pushPrefEnv({
-    set: [[TAB_DIRECTION_PREF, true]],
+    set: [[VERTICAL_TABS_PREF, true]],
   });
   await waitForTabstripOrientation("vertical");
   await testCustomizeSetting(
@@ -495,7 +472,7 @@ add_task(async function test_customize_firefox_settings_clicked() {
 
 add_task(async function test_sidebar_resize() {
   await SpecialPowers.pushPrefEnv({
-    set: [[TAB_DIRECTION_PREF, true]],
+    set: [[VERTICAL_TABS_PREF, true]],
   });
   await waitForTabstripOrientation("vertical");
   await SidebarController.show("viewHistorySidebar");
@@ -526,7 +503,7 @@ add_task(async function test_sidebar_resize() {
 
 add_task(async function test_sidebar_display_settings() {
   await SpecialPowers.pushPrefEnv({
-    set: [[TAB_DIRECTION_PREF, true]],
+    set: [[VERTICAL_TABS_PREF, true]],
   });
   await waitForTabstripOrientation("vertical");
   await testCustomizeSetting(
@@ -558,9 +535,7 @@ add_task(async function test_sidebar_tabs_layout() {
 });
 
 add_task(async function test_sidebar_position_rtl_ui() {
-  const sandbox = sinon.createSandbox();
-  sandbox.stub(window, "RTL_UI").value(true);
-  await SpecialPowers.pushPrefEnv({ set: [["intl.l10n.pseudo", "bidi"]] });
+  await BrowserTestUtils.enableRtlLocale();
   Services.fog.testResetFOG();
 
   // When RTL is enabled, sidebar is shown on the right by default.
@@ -578,8 +553,7 @@ add_task(async function test_sidebar_position_rtl_ui() {
     "right"
   );
 
-  sandbox.restore();
-  await SpecialPowers.popPrefEnv();
+  await BrowserTestUtils.disableRtlLocale();
   await SidebarController.waitUntilStable();
 });
 
@@ -587,15 +561,13 @@ async function testIconClick(expanded) {
   await SpecialPowers.pushPrefEnv({
     set: [
       ["browser.ml.chat.enabled", true],
-      ["browser.shopping.experience2023.integratedSidebar", true],
-      [TAB_DIRECTION_PREF, true],
+      [VERTICAL_TABS_PREF, true],
     ],
   });
   await waitForTabstripOrientation("vertical");
 
   const { sidebarMain } = SidebarController;
   const gleanEvents = new Map([
-    ["viewReviewCheckerSidebar", Glean.sidebar.shoppingReviewCheckerIconClick],
     ["viewGenaiChatSidebar", Glean.sidebar.chatbotIconClick],
     ["viewTabsSidebar", Glean.sidebar.syncedTabsIconClick],
     ["viewHistorySidebar", Glean.sidebar.historyIconClick],
@@ -617,23 +589,27 @@ async function testIconClick(expanded) {
     Assert.ok(!SidebarController._state.panelOpen, "No panel is open");
 
     let view = button.getAttribute("view");
-    info(`Click the icon for: ${view}`);
+    if (view) {
+      info(`Click the icon for: ${view}`);
 
-    // The nodelist for sidebarMain may be out of date.
-    let buttonEl = sidebarMain.shadowRoot.querySelector(
-      `moz-button[view='${view}']`
-    );
-    EventUtils.synthesizeMouseAtCenter(buttonEl, {});
-
-    let gleanEvent = gleanEvents.get(view);
-    if (gleanEvent) {
-      const events = gleanEvent.testGetValue();
-      Assert.equal(events?.length, 1, "One event was reported.");
-      Assert.deepEqual(
-        events?.[0].extra,
-        { sidebar_open: `${expanded}` },
-        `Event indicates the sidebar was ${expanded ? "expanded" : "collapsed"}.`
+      // The nodelist for sidebarMain may be out of date.
+      let buttonEl = sidebarMain.shadowRoot.querySelector(
+        `moz-button[view='${view}']`
       );
+      EventUtils.synthesizeMouseAtCenter(buttonEl, {});
+
+      let gleanEvent = gleanEvents.get(view);
+      if (gleanEvent) {
+        const events = gleanEvent.testGetValue();
+        if (events?.length) {
+          Assert.equal(events?.length, 1, "One event was reported.");
+          Assert.deepEqual(
+            events?.[0].extra,
+            { sidebar_open: `${expanded}` },
+            `Event indicates the sidebar was ${expanded ? "expanded" : "collapsed"}.`
+          );
+        }
+      }
     }
   }
 
@@ -682,43 +658,6 @@ async function testIconClick(expanded) {
   Services.fog.testResetFOG();
 }
 
-async function testIconClickReviewChecker(expanded) {
-  const { sidebarMain } = SidebarController;
-
-  await SidebarController.initializeUIState({
-    launcherVisible: true,
-    launcherExpanded: expanded,
-    command: "",
-  });
-  Assert.equal(
-    SidebarController.sidebarMain.expanded,
-    expanded,
-    `The launcher is ${expanded ? "expanded" : "collapsed"}`
-  );
-  Assert.ok(!SidebarController._state.panelOpen, "No panel is open");
-
-  let reviewCheckerButton = sidebarMain.shadowRoot.querySelector(
-    "moz-button[view='viewReviewCheckerSidebar']"
-  );
-  EventUtils.synthesizeMouseAtCenter(reviewCheckerButton, {});
-
-  let event = Glean.sidebar.shoppingReviewCheckerIconClick.testGetValue();
-  Assert.equal(event?.length, 1, "One event was reported.");
-  Assert.deepEqual(
-    event?.[0].extra,
-    { sidebar_open: `${expanded}` },
-    `Event indicates the sidebar was ${expanded ? "expanded" : "collapsed"}.`
-  );
-
-  await SpecialPowers.popPrefEnv();
-  await SidebarController.initializeUIState({
-    launcherExpanded: false,
-    launcherVisible: true,
-    command: "",
-  });
-  Services.fog.testResetFOG();
-}
-
 add_task(async function test_icon_click_collapsed_sidebar() {
   await testIconClick(false);
 });
@@ -727,20 +666,136 @@ add_task(async function test_icon_click_expanded_sidebar() {
   await testIconClick(true);
 });
 
-add_task(async function test_review_checker_icon_click_collapsed_sidebar() {
+async function test_pinned_tabs_activations(verticalTabs) {
   await SpecialPowers.pushPrefEnv({
-    set: [["browser.shopping.experience2023.integratedSidebar", true]],
+    set: [[VERTICAL_TABS_PREF, verticalTabs]],
   });
-  await testIconClickReviewChecker(false);
+
+  info("Switch to a pinned tab.");
+  const pinnedTab = BrowserTestUtils.addTab(gBrowser, "https://example.com/", {
+    pinned: true,
+  });
+  await BrowserTestUtils.switchTab(gBrowser, pinnedTab);
+
+  const counter = verticalTabs
+    ? Glean.pinnedTabs.activations.sidebar
+    : Glean.pinnedTabs.activations.horizontalBar;
+  Assert.equal(counter.testGetValue(), 1, "Pinned tab activation was counted.");
+
+  gBrowser.removeTab(pinnedTab);
   await SpecialPowers.popPrefEnv();
-  await SidebarController.waitUntilStable();
+}
+
+add_task(async function test_pinned_tabs_activations_sidebar() {
+  await test_pinned_tabs_activations(true);
+
+  const pinEvent = Glean.pinnedTabs.pin.testGetValue()?.at(-1);
+  const closeEvent = Glean.pinnedTabs.close.testGetValue()?.at(-1);
+  Assert.deepEqual(
+    pinEvent?.extra,
+    { layout: "vertical", source: "unknown" },
+    "Pin event was recorded for vertical tabs."
+  );
+  Assert.deepEqual(
+    closeEvent?.extra,
+    { layout: "vertical" },
+    "Close event was recorded for vertical tabs."
+  );
 });
 
-add_task(async function test_review_checker_icon_click_expanded_sidebar() {
-  await SpecialPowers.pushPrefEnv({
-    set: [["browser.shopping.experience2023.integratedSidebar", true]],
-  });
-  await testIconClickReviewChecker(true);
-  await SpecialPowers.popPrefEnv();
-  await SidebarController.waitUntilStable();
+add_task(async function test_pinned_tabs_activations_horizontal_bar() {
+  await test_pinned_tabs_activations(false);
+
+  const pinEvent = Glean.pinnedTabs.pin.testGetValue()?.at(-1);
+  const closeEvent = Glean.pinnedTabs.close.testGetValue()?.at(-1);
+  Assert.deepEqual(
+    pinEvent?.extra,
+    { layout: "horizontal", source: "unknown" },
+    "Pin event was recorded for horizontal tabs."
+  );
+  Assert.deepEqual(
+    closeEvent?.extra,
+    { layout: "horizontal" },
+    "Close event was recorded for horizontal tabs."
+  );
 });
+
+async function test_pinned_tabs_count(verticalTabs) {
+  await SpecialPowers.pushPrefEnv({
+    set: [[VERTICAL_TABS_PREF, verticalTabs]],
+  });
+
+  info("Add two pinned tabs.");
+  const firstTab = BrowserTestUtils.addTab(gBrowser, "https://example.com/", {
+    pinned: true,
+  });
+  const secondTab = BrowserTestUtils.addTab(gBrowser, "https://example.com/", {
+    pinned: true,
+  });
+
+  const quantity = verticalTabs
+    ? Glean.pinnedTabs.count.sidebar
+    : Glean.pinnedTabs.count.horizontalBar;
+  Assert.equal(quantity.testGetValue(), 2, "Both tabs were counted.");
+
+  gBrowser.unpinTab(firstTab);
+  Assert.equal(
+    quantity.testGetValue(),
+    1,
+    "Count was updated after unpinning a tab."
+  );
+
+  gBrowser.removeTab(secondTab);
+  Assert.equal(
+    quantity.testGetValue(),
+    0,
+    "Count was updated after removing a pinned tab."
+  );
+
+  gBrowser.removeTab(firstTab);
+  await SpecialPowers.popPrefEnv();
+}
+
+add_task(async function test_pinned_tabs_count_sidebar() {
+  await test_pinned_tabs_count(true);
+});
+
+add_task(async function test_pinned_tabs_count_horizontal_bar() {
+  await test_pinned_tabs_count(false);
+});
+
+add_task(async function test_pinned_tabs_pin_from_context_menu() {
+  info("Open a new tab.");
+  const newTab = BrowserTestUtils.addTab(gBrowser, "https://example.com/", {
+    skipAnimation: true,
+  });
+
+  info("Pin the new tab using context menu.");
+  const tabContextMenu = document.getElementById("tabContextMenu");
+  const promiseMenuShown = BrowserTestUtils.waitForEvent(
+    tabContextMenu,
+    "popupshown"
+  );
+  EventUtils.synthesizeMouseAtCenter(newTab, {
+    type: "contextmenu",
+    button: 2,
+  });
+  await promiseMenuShown;
+  const promiseTabPinned = BrowserTestUtils.waitForEvent(
+    window,
+    "TabPinned",
+    true
+  );
+  const pinTabMenuItem = document.getElementById("context_pinTab");
+  tabContextMenu.activateItem(pinTabMenuItem);
+  await promiseTabPinned;
+
+  const pinEvent = Glean.pinnedTabs.pin.testGetValue()?.at(-1);
+  Assert.deepEqual(
+    pinEvent?.extra,
+    { layout: "horizontal", source: "tab_menu" },
+    "Pin event was recorded with the correct telemetry source."
+  );
+});
+
+// TODO: Bug 1971584 - Add test coverage for pinning and unpinning a tab from the vertical grid
