@@ -10,15 +10,14 @@ let gAreas = CustomizableUI.getTestOnlyInternalProp("gAreas");
 
 const SIDEBAR_BUTTON_INTRODUCED_PREF =
   "browser.toolbarbuttons.introduced.sidebar-button";
-const SIDEBAR_VISIBILITY_PREF = "sidebar.visibility";
-const SIDEBAR_TAB_DIRECTION_PREF = "sidebar.verticalTabs";
 
 add_setup(async () => {
   // Only vertical tabs mode has expanded state
   await SpecialPowers.pushPrefEnv({
     set: [
-      [SIDEBAR_TAB_DIRECTION_PREF, true],
+      [VERTICAL_TABS_PREF, true],
       [SIDEBAR_BUTTON_INTRODUCED_PREF, false],
+      ["sidebar.main.tools", "aichat,passwords,syncedtabs,history"],
     ],
   });
   await waitForTabstripOrientation("vertical");
@@ -53,11 +52,11 @@ add_setup(async () => {
     "sidebar-button"
   );
   ok(
-    window.SidebarController.sidebarMain?.expanded,
+    SidebarController.sidebarMain?.expanded,
     "With verticalTabs enabled, the launcher should be initially expanded"
   );
   ok(
-    BrowserTestUtils.isVisible(window.SidebarController.sidebarMain),
+    BrowserTestUtils.isVisible(SidebarController.sidebarMain),
     "Sidebar launcher is visible at setup"
   );
 });
@@ -87,7 +86,7 @@ add_task(async function test_toolbar_sidebar_button() {
 
 add_task(async function test_expanded_state_for_always_show() {
   await waitForTabstripOrientation("vertical");
-  const { sidebarMain, toolbarButton } = window.SidebarController;
+  const { sidebarMain, toolbarButton } = SidebarController;
 
   const checkExpandedState = async (
     expanded,
@@ -200,11 +199,10 @@ add_task(async function test_expanded_state_for_always_show() {
 add_task(async function test_states_for_hide_sidebar() {
   // With horizontal tabs and visibility set to "hide-sidebar", check launcher is initially visible
   await SpecialPowers.pushPrefEnv({
-    set: [[SIDEBAR_TAB_DIRECTION_PREF, false]],
+    set: [[VERTICAL_TABS_PREF, false]],
   });
   await waitForTabstripOrientation("horizontal");
 
-  const { SidebarController } = window;
   const { sidebarContainer, sidebarMain, toolbarButton } = SidebarController;
 
   Assert.equal(
@@ -303,13 +301,93 @@ add_task(async function test_states_for_hide_sidebar() {
   await waitForTabstripOrientation("vertical");
 });
 
+add_task(async function test_toolbar_sidebar_badges() {
+  const SIDEBAR_COMMAND_ID = "viewGenaiChatSidebar";
+
+  await SpecialPowers.pushPrefEnv({
+    set: [["sidebar.notification.badge.aichat", true]],
+  });
+  await SpecialPowers.pushPrefEnv({
+    set: [[VERTICAL_TABS_PREF, false]],
+  });
+  await waitForTabstripOrientation("horizontal");
+
+  let toolbarButton = document.getElementById("sidebar-button");
+  let badgeEl = toolbarButton?.querySelector(".toolbarbutton-badge");
+  let toolEntry = SidebarController.toolsAndExtensions.get(SIDEBAR_COMMAND_ID);
+
+  await SidebarController.initializeUIState({ launcherExpanded: true });
+  Assert.ok(
+    !badgeEl.classList.contains("feature-callout"),
+    "Toolbar badge should not be visible when sidebar is open"
+  );
+  Assert.ok(
+    toolEntry.attention,
+    "Sidebar tool badge should show when sidebar is open"
+  );
+
+  // Simulate user closing the sidebar
+  EventUtils.synthesizeMouseAtCenter(toolbarButton, {}, window);
+  Assert.ok(
+    badgeEl.classList.contains("feature-callout"),
+    "Toolbar badge should appear when sidebar is closed"
+  );
+
+  // Set badge pref false to check if all badges are cleared
+  await SpecialPowers.pushPrefEnv({
+    set: [[`sidebar.notification.badge.aichat`, false]],
+  });
+  Assert.ok(
+    !badgeEl.classList.contains("feature-callout") && !toolEntry.attention,
+    "Toolbar badge and sidebar badge should clear when pref is false"
+  );
+
+  // Test that disabled tools don't show badges
+  await SpecialPowers.pushPrefEnv({
+    set: [
+      ["sidebar.main.tools", "history"],
+      ["sidebar.notification.badge.aichat", true],
+    ],
+  });
+  Assert.ok(
+    !badgeEl.classList.contains("feature-callout"),
+    "Toolbar badge should not appear for disabled tools"
+  );
+  await SpecialPowers.popPrefEnv();
+
+  // Test that hidden tools don't show badges
+  await SpecialPowers.pushPrefEnv({
+    set: [
+      ["browser.ml.chat.enabled", false],
+      ["sidebar.notification.badge.aichat", true],
+    ],
+  });
+  Assert.ok(
+    !badgeEl.classList.contains("feature-callout"),
+    "Toolbar badge should not appear for hidden tools"
+  );
+  await SpecialPowers.popPrefEnv();
+
+  await SpecialPowers.popPrefEnv();
+  await SpecialPowers.popPrefEnv();
+  await waitForTabstripOrientation("vertical");
+
+  Assert.ok(
+    !badgeEl.classList.contains("feature-callout"),
+    "Toolbar button don't appear a badge in vertical sidebar"
+  );
+
+  await SpecialPowers.popPrefEnv();
+});
+
 add_task(async function test_states_for_hide_sidebar_vertical() {
   info(
-    `starting test with pref values: verticalTabs: ${Services.prefs.getBoolPref("sidebar.verticalTabs")}, visibility: ${Services.prefs.getStringPref("sidebar.visibility")}`
+    `starting test with pref values: verticalTabs: ${Services.prefs.getBoolPref(VERTICAL_TABS_PREF)},
+    visibility: ${Services.prefs.getStringPref(SIDEBAR_VISIBILITY_PREF)}`
   );
   await waitForTabstripOrientation("vertical", window);
   await SpecialPowers.pushPrefEnv({
-    set: [["sidebar.visibility", "hide-sidebar"]],
+    set: [[SIDEBAR_VISIBILITY_PREF, "hide-sidebar"]],
   });
   await window.SidebarController.sidebarMain.updateComplete;
   ok(
@@ -385,10 +463,11 @@ add_task(async function test_states_for_hide_sidebar_vertical() {
   await SidebarController.waitUntilStable();
 
   info("Don't collapse the sidebar by loading a tool.");
-  const toolButton = sidebarMain.toolButtons[0];
+  const toolButton = sidebarMain.toolButtons[2];
   EventUtils.synthesizeMouseAtCenter(toolButton, {}, win);
 
   await checkStates({ hidden: false, expanded: true });
+
   ok(SidebarController.isOpen, "Panel is open.");
 
   info("Close a panel using the toolbar button.");
@@ -399,7 +478,6 @@ add_task(async function test_states_for_hide_sidebar_vertical() {
 
   EventUtils.synthesizeMouseAtCenter(toolbarButton, {}, win);
   await checkStates({ hidden: false, expanded: true });
-
   info("Check states on a new window.");
   const newWin = await BrowserTestUtils.openNewBrowserWindow();
   await checkStates(
@@ -430,8 +508,9 @@ add_task(async function test_sidebar_button_runtime_pref_enabled() {
     "The sidebar button is not visible after being removed"
   );
 
-  // rever the pref change, this should cause the button to be placed in the nav-bar
+  // revert the pref change, this should cause the button to be placed in the nav-bar
   await SpecialPowers.popPrefEnv();
+  await SidebarController.waitUntilStable();
   button = document.getElementById("sidebar-button");
   Assert.ok(
     BrowserTestUtils.isVisible(button),
@@ -444,8 +523,23 @@ add_task(async function test_sidebar_button_runtime_pref_enabled() {
     CustomizableUI.AREA_NAVBAR,
     "The sidebar button is in the nav-bar"
   );
+  Assert.ok(
+    !BrowserTestUtils.isVisible(document.querySelector("sidebar-main")),
+    "The sidebar launcher is hidden"
+  );
+  Assert.ok(
+    !button.checked,
+    "Sidebar button should be un-checked when the launcher is hidden."
+  );
+
+  button.doCommand();
+  await SidebarController.waitUntilStable();
+  Assert.ok(button.checked, "Sidebar button should be checked");
+  Assert.ok(
+    BrowserTestUtils.isVisible(document.querySelector("sidebar-main")),
+    "The sidebar launcher is visible"
+  );
 
-  Assert.ok(button.checked, "Sidebar button should be checked when showing.");
   await SpecialPowers.pushPrefEnv({
     set: [["sidebar.revamp", false]],
   });
@@ -453,6 +547,7 @@ add_task(async function test_sidebar_button_runtime_pref_enabled() {
     !button.checked,
     "Sidebar button should not be checked when old sidebar is not showing."
   );
+
   await SpecialPowers.popPrefEnv();
   await SidebarController.waitUntilStable();
 });
@@ -472,7 +567,7 @@ add_task(async function test_keyboard_shortcut() {
   const key = document.getElementById("toggleSidebarKb");
 
   Assert.equal(
-    Services.prefs.getStringPref("sidebar.visibility"),
+    Services.prefs.getStringPref(SIDEBAR_VISIBILITY_PREF),
     "always-show",
     "Got expected visibility value"
   );
