@@ -17,7 +17,7 @@ add_setup(async () => {
   await SpecialPowers.pushPrefEnv({
     set: [
       ["sidebar.animation.enabled", false],
-      ["sidebar.verticalTabs", false],
+      [VERTICAL_TABS_PREF, false],
     ],
   });
   Services.telemetry.clearScalars();
@@ -25,9 +25,7 @@ add_setup(async () => {
 });
 registerCleanupFunction(async () => {
   await SpecialPowers.popPrefEnv();
-  while (gBrowser.tabs.length > 1) {
-    BrowserTestUtils.removeTab(gBrowser.tabs.at(-1));
-  }
+  cleanUpExtraTabs();
   NonPrivateTabs.stop();
 });
 
@@ -130,7 +128,7 @@ add_task(async function test_toggle_vertical_tabs() {
   );
 
   // flip the pref to move the tabstrip into the sidebar
-  await SpecialPowers.pushPrefEnv({ set: [["sidebar.verticalTabs", true]] });
+  await SpecialPowers.pushPrefEnv({ set: [[VERTICAL_TABS_PREF, true]] });
   await waitForTabstripOrientation("vertical");
 
   for (let selector of expectedElementsWhenVertical) {
@@ -164,9 +162,28 @@ add_task(async function test_toggle_vertical_tabs() {
   gBrowser.selectedTab.focus();
 
   info("Open a new tab using the context menu.");
-  await openAndWaitForContextMenu(contextMenu, gBrowser.selectedTab, () => {
-    document.getElementById("context_openANewTab").click();
-  });
+  const promiseTabOpen = BrowserTestUtils.waitForEvent(
+    window.gBrowser.tabContainer,
+    "TabOpen"
+  );
+  let hidden = BrowserTestUtils.waitForEvent(contextMenu, "popuphidden");
+  await openAndWaitForContextMenu(
+    contextMenu,
+    gBrowser.selectedTab,
+    async () => {
+      info("Tab context menu opened");
+      let newTabOption = document.getElementById("context_openANewTab");
+      if (!newTabOption) {
+        info("New tab context menu option not found");
+      }
+      newTabOption?.click();
+    }
+  );
+
+  await promiseTabOpen;
+  info("New tab opened");
+  contextMenu.hidePopup();
+  await hidden;
 
   let keyedScalars = TelemetryTestUtils.getProcessScalars("parent", true);
   TelemetryTestUtils.assertKeyedScalar(
@@ -191,9 +208,36 @@ add_task(async function test_toggle_vertical_tabs() {
 
   info("Pin a tab using the context menu.");
   await SidebarController.waitUntilStable();
-  await openAndWaitForContextMenu(contextMenu, gBrowser.selectedTab, () => {
-    document.getElementById("context_pinTab").click();
-  });
+  const promiseTabPinned = BrowserTestUtils.waitForEvent(
+    window,
+    "TabPinned",
+    true
+  );
+  let hidden2 = BrowserTestUtils.waitForEvent(contextMenu, "popuphidden");
+  await openAndWaitForContextMenu(
+    contextMenu,
+    gBrowser.selectedTab,
+    async () => {
+      info("Tab context menu opened");
+      let pinTabOption = document.getElementById("context_pinTab");
+      if (!pinTabOption) {
+        info("Pin tab context menu option not found");
+      }
+      pinTabOption?.click();
+    }
+  );
+
+  await promiseTabPinned;
+  // Wait for pinned tab to render
+  let pinnedTabsContainer = document.getElementById("pinned-tabs-container");
+  await BrowserTestUtils.waitForMutationCondition(
+    pinnedTabsContainer,
+    { childList: true },
+    () => pinnedTabsContainer.childElementCount === 1
+  );
+  info("Tab pinned via the context menu");
+  contextMenu.hidePopup();
+  await hidden2;
 
   scalars = await getTelemetryScalars([
     "browser.engagement.max_concurrent_vertical_tab_pinned_count",
@@ -228,6 +272,8 @@ add_task(async function test_toggle_vertical_tabs() {
   });
 
   // Synthesize a double click 100px below the last tab
+  let target = document.getElementById("tabbrowser-arrowscrollbox");
+  let dblClickPromise = BrowserTestUtils.waitForEvent(target, "dblclick");
   EventUtils.synthesizeMouseAtPoint(
     containerRect.left + containerRect.width / 2,
     tabRect.bottom + 100,
@@ -238,6 +284,7 @@ add_task(async function test_toggle_vertical_tabs() {
     tabRect.bottom + 100,
     { clickCount: 2 }
   );
+  await dblClickPromise;
 
   is(gBrowser.tabs.length, 3, "Tabstrip now has three tabs");
 
@@ -286,6 +333,7 @@ add_task(async function test_toggle_vertical_tabs() {
       );
     }
   );
+  toolbarContextMenu.hidePopup();
 
   await openAndWaitForContextMenu(
     toolbarContextMenu,
@@ -297,6 +345,7 @@ add_task(async function test_toggle_vertical_tabs() {
       );
     }
   );
+  toolbarContextMenu.hidePopup();
 
   await openAndWaitForContextMenu(
     toolbarContextMenu,
@@ -312,6 +361,7 @@ add_task(async function test_toggle_vertical_tabs() {
       );
     }
   );
+  toolbarContextMenu.hidePopup();
 
   await openAndWaitForContextMenu(
     toolbarContextMenu,
@@ -323,6 +373,7 @@ add_task(async function test_toggle_vertical_tabs() {
       );
     }
   );
+  toolbarContextMenu.hidePopup();
 
   let newTabButton = document.getElementById("tabs-newtab-button");
   info("Open a new tab using the new tab button.");
@@ -350,7 +401,7 @@ add_task(async function test_toggle_vertical_tabs() {
   );
 
   // flip the pref to move the tabstrip horizontally
-  await SpecialPowers.pushPrefEnv({ set: [["sidebar.verticalTabs", false]] });
+  await SpecialPowers.pushPrefEnv({ set: [[VERTICAL_TABS_PREF, false]] });
   await waitForTabstripOrientation("horizontal");
 
   ok(
@@ -392,14 +443,14 @@ add_task(async function test_enabling_vertical_tabs_enables_sidebar_revamp() {
     "sidebar.revamp pref is false initially."
   );
   ok(
-    !Services.prefs.getBoolPref("sidebar.verticalTabs", false),
+    !Services.prefs.getBoolPref(VERTICAL_TABS_PREF, false),
     "sidebar.verticalTabs pref is false initially."
   );
 
-  await SpecialPowers.pushPrefEnv({ set: [["sidebar.verticalTabs", true]] });
+  await SpecialPowers.pushPrefEnv({ set: [[VERTICAL_TABS_PREF, true]] });
   await waitForTabstripOrientation("vertical");
   ok(
-    Services.prefs.getBoolPref("sidebar.verticalTabs", false),
+    Services.prefs.getBoolPref(VERTICAL_TABS_PREF, false),
     "sidebar.verticalTabs pref is enabled after we've enabled it."
   );
   ok(
@@ -410,26 +461,17 @@ add_task(async function test_enabling_vertical_tabs_enables_sidebar_revamp() {
 
 add_task(async function test_vertical_tabs_overflow() {
   await waitForTabstripOrientation("vertical");
-  const numTabs = 50;
-  const winData = {
-    tabs: Array.from({ length: numTabs }, (_, i) => ({
-      entries: [
-        {
-          url: `data:,Tab${i}`,
-          triggeringPrincipal_base64: E10SUtils.SERIALIZED_SYSTEMPRINCIPAL,
-        },
-      ],
-    })),
-    selected: numTabs,
-  };
-  const browserState = { windows: [winData] };
-
-  // use Session restore to batch-open tabs
-  info(`Restoring to browserState: ${JSON.stringify(browserState, null, 2)}`);
-  await SessionStoreTestUtils.promiseBrowserState(browserState);
-  info("Windows and tabs opened, waiting for readyWindowsPromise");
-  await NonPrivateTabs.readyWindowsPromise;
-  info("readyWindowsPromise resolved");
+  let tabsContainer = document.getElementById("tabbrowser-tabs");
+  info("Open new tabs until they overflow");
+  let index = gBrowser.tabs.length;
+  while (!tabsContainer.hasAttribute("overflow")) {
+    await BrowserTestUtils.openNewForegroundTab(
+      gBrowser,
+      `data:text/html,<title>${index + 1}</title>`
+    );
+    index++;
+  }
+  await SidebarController.waitUntilStable();
 
   info("Open a new tab using the new tab button.");
   const newTabButton = document.getElementById("vertical-tabs-newtab-button");
@@ -439,11 +481,7 @@ add_task(async function test_vertical_tabs_overflow() {
   );
   EventUtils.synthesizeMouseAtCenter(newTabButton, {});
 
-  is(
-    gBrowser.tabs.length,
-    numTabs + 1,
-    `Tabstrip now has ${numTabs + 1} tabs.`
-  );
+  is(gBrowser.tabs.length, index + 1, `Tabstrip now has ${index + 1} tabs.`);
   const keyedScalars = TelemetryTestUtils.getProcessScalars("parent", true);
   TelemetryTestUtils.assertKeyedScalar(
     keyedScalars,
@@ -452,16 +490,14 @@ add_task(async function test_vertical_tabs_overflow() {
     1
   );
 
-  while (gBrowser.tabs.length > 1) {
-    await BrowserTestUtils.removeTab(gBrowser.tabs.at(-1));
-  }
+  cleanUpExtraTabs();
 });
 
 add_task(async function test_vertical_tabs_expanded() {
   await SpecialPowers.pushPrefEnv({
     set: [
       ["sidebar.revamp", true],
-      ["sidebar.verticalTabs", true],
+      [VERTICAL_TABS_PREF, true],
     ],
   });
   await waitForTabstripOrientation("vertical");
@@ -475,7 +511,7 @@ add_task(async function test_vertical_tabs_expanded() {
   );
 
   info("Enable vertical tabs.");
-  Services.prefs.setBoolPref("sidebar.verticalTabs", true);
+  Services.prefs.setBoolPref(VERTICAL_TABS_PREF, true);
   await waitForTabstripOrientation("vertical");
   ok(
     BrowserTestUtils.isVisible(document.getElementById("sidebar-main")),
@@ -496,7 +532,7 @@ add_task(async function test_vertical_tabs_expanded() {
 
 add_task(async function test_vertical_tabs_min_width() {
   await SpecialPowers.pushPrefEnv({
-    set: [["sidebar.verticalTabs", true]],
+    set: [[VERTICAL_TABS_PREF, true]],
   });
   await waitForTabstripOrientation("vertical");
 
@@ -538,20 +574,18 @@ add_task(async function test_vertical_tabs_min_width() {
     BrowserTestUtils.addTab(gBrowser, "about:blank"),
   ];
   gBrowser.pinTab(tabs[1]);
-  let verticalPinnedTabsContainer = document.querySelector(
-    "#vertical-pinned-tabs-container"
-  );
+  let pinnedTabsContainer = document.querySelector("#pinned-tabs-container");
   ok(
-    BrowserTestUtils.isVisible(verticalPinnedTabsContainer),
+    BrowserTestUtils.isVisible(pinnedTabsContainer),
     "Vertical pinned tabs container is visible"
   );
   is(
-    verticalPinnedTabsContainer.children.length,
-    1,
-    "One tab is pinned in vertical pinned tabs container"
+    pinnedTabsContainer.children.length,
+    2,
+    "Two tabs are pinned in vertical pinned tabs container"
   );
   is(
-    verticalPinnedTabsContainer.getBoundingClientRect().width,
+    pinnedTabsContainer.getBoundingClientRect().width,
     gBrowser.tabContainer.getBoundingClientRect().width,
     "Vertical pinned tabs container should be the same width as the tab strip"
   );
@@ -561,11 +595,12 @@ add_task(async function test_vertical_tabs_min_width() {
     Math.round(tabs[1].getBoundingClientRect().width),
     "Vertical pinned tabs should be the same width as the unpinned tabs"
   );
+  gBrowser.unpinTab(tabs[0]);
   gBrowser.unpinTab(tabs[1]);
 
   // Switch to horizontal tabs
   await SpecialPowers.pushPrefEnv({
-    set: [["sidebar.verticalTabs", false]],
+    set: [[VERTICAL_TABS_PREF, false]],
   });
   await waitForTabstripOrientation("horizontal");
 
@@ -580,8 +615,60 @@ add_task(async function test_vertical_tabs_min_width() {
   );
 
   // clean up extra tabs
-  while (gBrowser.tabs.length > 1) {
-    await BrowserTestUtils.removeTab(gBrowser.tabs.at(-1));
-  }
+  cleanUpExtraTabs();
   await SpecialPowers.popPrefEnv();
 });
+
+add_task(
+  async function test_launcher_collapsed_entering_horiz_tabs_with_hide_sidebar() {
+    const { sidebarMain } = SidebarController;
+    await SpecialPowers.pushPrefEnv({ set: [[VERTICAL_TABS_PREF, true]] });
+    await waitForTabstripOrientation("vertical");
+    ok(
+      BrowserTestUtils.isVisible(sidebarMain),
+      "Revamped sidebar main is shown initially."
+    );
+    ok(
+      sidebarMain.expanded,
+      "Launcher is expanded with vertical tabs and always-show"
+    );
+
+    await SpecialPowers.pushPrefEnv({
+      set: [["sidebar.visibility", "hide-sidebar"]],
+    });
+    await sidebarMain.updateComplete;
+    ok(
+      BrowserTestUtils.isHidden(sidebarMain),
+      "Revamped sidebar main hidden when we switch to hide-sidebar."
+    );
+
+    // toggle the launcher back open.
+    document.getElementById("sidebar-button").doCommand();
+    await sidebarMain.updateComplete;
+    ok(
+      BrowserTestUtils.isVisible(sidebarMain),
+      "Revamped sidebar main visible again."
+    );
+    ok(
+      sidebarMain.expanded,
+      "Launcher is still expanded as vertical tabs are still enabled"
+    );
+
+    // switch back to horizontal tabs and confirm the launcher get un-expanded
+    await SpecialPowers.pushPrefEnv({ set: [[VERTICAL_TABS_PREF, false]] });
+    await waitForTabstripOrientation("horizontal");
+
+    ok(
+      BrowserTestUtils.isVisible(sidebarMain),
+      "Revamped sidebar main is still visible when we switch to horizontal tabs."
+    );
+    ok(
+      !sidebarMain.expanded,
+      "Launcher is collapsed when we switch to horizontal tabs with hide-sidebar"
+    );
+
+    await SpecialPowers.popPrefEnv();
+    await SpecialPowers.popPrefEnv();
+    await SpecialPowers.popPrefEnv();
+  }
+);
