@@ -72,17 +72,13 @@
        */
       this.muteReason = undefined;
 
-      this.mOverCloseButton = false;
-
-      this.mCorrespondingMenuitem = null;
-
       this.closing = false;
     }
 
     static get inheritedAttributes() {
       return {
         ".tab-background":
-          "selected=visuallyselected,fadein,multiselected,dragover-createGroup",
+          "selected=visuallyselected,fadein,multiselected,dragover-groupTarget",
         ".tab-group-line": "selected=visuallyselected,multiselected",
         ".tab-loading-burst": "pinned,bursting,notselectedsinceload",
         ".tab-content":
@@ -94,7 +90,7 @@
         ".tab-icon-pending":
           "fadein,pinned,busy,progress,selected=visuallyselected,pendingicon",
         ".tab-icon-image":
-          "src=image,triggeringprincipal=iconloadingprincipal,requestcontextid,fadein,pinned,selected=visuallyselected,busy,crashed,sharing,pictureinpicture,pending,discarded",
+          "src=image,requestcontextid,fadein,pinned,selected=visuallyselected,busy,crashed,sharing,pictureinpicture,pending,discarded",
         ".tab-sharing-icon-overlay": "sharing,selected=visuallyselected,pinned",
         ".tab-icon-overlay":
           "sharing,pictureinpicture,crashed,busy,soundplaying,soundplaying-scheduledremoval,pinned,muted,blocked,selected=visuallyselected,activemedia-blocked",
@@ -110,10 +106,18 @@
       };
     }
 
+    #lastGroup;
     connectedCallback() {
+      this.#updateOnTabGrouped();
+      this.#lastGroup = this.group;
+
       this.initialize();
     }
 
+    disconnectedCallback() {
+      this.#updateOnTabUngrouped();
+    }
+
     initialize() {
       if (this._initialized) {
         return;
@@ -132,6 +136,11 @@
       let labelContainer = this.querySelector(".tab-label-container");
       labelContainer.addEventListener("overflow", this);
       labelContainer.addEventListener("underflow", this);
+
+      // Tabs in the tab strip default to being at the top level (level 1)
+      // Tabs in tab groups are one level down (level 2); this tab will
+      // update its value when it moves in and out of tab groups.
+      this.setAttribute("aria-level", 1);
     }
 
     #elementIndex;
@@ -211,7 +220,11 @@
     }
 
     get visible() {
-      return this.isOpen && !this.hidden && !this.group?.collapsed;
+      return (
+        this.isOpen &&
+        !this.hidden &&
+        (!this.group || this.group.isTabVisibleInGroup(this))
+      );
     }
 
     get hidden() {
@@ -365,6 +378,15 @@
       return null;
     }
 
+    get splitview() {
+      if (
+        this.parentElement?.parentElement?.tagName == "tab-split-view-wrapper"
+      ) {
+        return this.parentElement.parentElement;
+      }
+      return null;
+    }
+
     updateLastAccessed(aDate) {
       this._lastAccessed = this.selected ? Infinity : aDate || Date.now();
     }
@@ -384,23 +406,19 @@
       }
 
       const diff_in_msec = Date.now() - this._lastUnloaded;
-      Services.telemetry
-        .getHistogramById("TAB_UNLOAD_TO_RELOAD")
-        .add(diff_in_msec / 1000);
+      Glean.browserEngagement.tabUnloadToReload.accumulateSingleSample(
+        diff_in_msec / 1000
+      );
       Glean.browserEngagement.tabReloadCount.add(1);
       delete this._lastUnloaded;
     }
 
     on_mouseover(event) {
-      if (event.target.classList.contains("tab-close-button")) {
-        this.mOverCloseButton = true;
-      }
-
       if (!this.visible) {
         return;
       }
 
-      let tabToWarm = this.mOverCloseButton
+      let tabToWarm = event.target.classList.contains("tab-close-button")
         ? gBrowser._findTabToBlurTo(this)
         : this;
       gBrowser.warmupTab(tabToWarm);
@@ -412,10 +430,6 @@
     }
 
     on_mouseout(event) {
-      if (event.target.classList.contains("tab-close-button")) {
-        this.mOverCloseButton = false;
-      }
-
       // If the new target is not part of this tab then this is a mouseleave event.
       if (!this.contains(event.relatedTarget)) {
         this._mouseleave();
@@ -431,7 +445,7 @@
       if (event.eventPhase == Event.CAPTURING_PHASE) {
         this.style.MozUserFocus = "";
       } else if (
-        this.mOverCloseButton ||
+        event.target.classList?.contains("tab-close-button") ||
         gSharedTabWarning.willShowSharedTabWarning(this)
       ) {
         event.stopPropagation();
@@ -550,14 +564,18 @@
 
       if (event.target.classList.contains("tab-close-button")) {
         if (this.multiselected) {
-          gBrowser.removeMultiSelectedTabs({
-            telemetrySource: lazy.TabMetrics.METRIC_SOURCE.TAB_STRIP,
-          });
+          gBrowser.removeMultiSelectedTabs(
+            lazy.TabMetrics.userTriggeredContext(
+              lazy.TabMetrics.METRIC_SOURCE.TAB_STRIP
+            )
+          );
         } else {
           gBrowser.removeTab(this, {
             animate: true,
             triggeringEvent: event,
-            telemetrySource: lazy.TabMetrics.METRIC_SOURCE.TAB_STRIP,
+            ...lazy.TabMetrics.userTriggeredContext(
+              lazy.TabMetrics.METRIC_SOURCE.TAB_STRIP
+            ),
           });
         }
         // This enables double-click protection for the tab container
@@ -709,6 +727,45 @@
     on_underflow(event) {
       event.currentTarget.removeAttribute("textoverflow");
     }
+
+    #updateOnTabGrouped() {
+      if (this.group && this.#lastGroup != this.group) {
+        // Trigger TabGrouped on the tab group, not the tab itself. This is a
+        // bit unorthodox, but fixes bug1964152 where tab group events are not
+        // fired correctly when tabs change windows (because the tab is
+        // detached from the DOM at time of the event).
+        this.group.dispatchEvent(
+          new CustomEvent("TabGrouped", {
+            bubbles: true,
+            detail: this,
+          })
+        );
+        this.setAttribute("aria-level", 2);
+      }
+    }
+
+    #updateOnTabUngrouped() {
+      if (this.#lastGroup && this.#lastGroup != this.group) {
+        // Trigger TabUngrouped on the tab group, not the tab itself. This is a
+        // bit unorthodox, but fixes bug1964152 where tab group events are not
+        // fired correctly when tabs change windows (because the tab is
+        // detached from the DOM at time of the event).
+        this.#lastGroup.dispatchEvent(
+          new CustomEvent("TabUngrouped", {
+            bubbles: true,
+            detail: this,
+          })
+        );
+        // Tab could have moved to be ungrouped (level 1)
+        // or to a different group (level 2).
+        this.setAttribute("aria-level", this.group ? 2 : 1);
+        // `posinset` and `setsize` only need to be set explicitly
+        // on grouped tabs so that a11y tools can tell users that a
+        // given tab is "2 of 7" in the group, for example.
+        this.removeAttribute("aria-posinset");
+        this.removeAttribute("aria-setsize");
+      }
+    }
   }
 
   customElements.define("tabbrowser-tab", MozTabbrowserTab, {
