@@ -15,12 +15,20 @@ async function openCreatePanel(tabgroupPanel, tab) {
   await panelShown;
 }
 
-async function setup(enableSmartTab = true, optIn = true) {
+async function setup({
+  enableSmartTab = true,
+  optIn = true,
+  userEnabled = true,
+  mlSwitchEnabled = true,
+  labelReason = "DEFAULT",
+} = {}) {
   await SpecialPowers.pushPrefEnv({
     set: [
       ["browser.tabs.groups.enabled", true],
       ["browser.tabs.groups.smart.enabled", enableSmartTab],
       ["browser.tabs.groups.smart.optin", optIn],
+      ["browser.tabs.groups.smart.userEnabled", userEnabled],
+      ["browser.ml.enable", mlSwitchEnabled],
     ],
   });
   sinon
@@ -33,10 +41,19 @@ async function setup(enableSmartTab = true, optIn = true) {
     "text2text-generation": { modelRevision: "v0.3.4" },
     "feature-extraction": { modelRevision: "v0.1.0" },
   });
+
+  sinon
+    .stub(SmartTabGroupingManager.prototype, "initEmbeddingEngine")
+    .resolves({});
+
   sinon
     .stub(SmartTabGroupingManager.prototype, "preloadAllModels")
     .resolves([]);
 
+  sinon
+    .stub(SmartTabGroupingManager.prototype, "getLabelReason")
+    .returns(labelReason);
+
   let tab = BrowserTestUtils.addTab(gBrowser, "about:blank");
   const cleanup = () => {
     sinon.restore();
@@ -75,6 +92,13 @@ add_task(async function test_saving_ml_suggested_label_telemetry() {
     "v0.3.4",
     "Model revision should be present"
   );
+  Assert.equal(
+    events[0].extra.label_reason,
+    "DEFAULT",
+    "If suggested label had more than zero length, reason should be default"
+  );
+  const enabled = Glean.tabgroup.smartTabEnabled.testGetValue();
+  Assert.equal(enabled, true, "Should create a ping event");
   cleanup();
 });
 
@@ -215,7 +239,7 @@ add_task(async function test_canceling_ml_suggested_tabs_with_ml_label() {
 });
 
 add_task(async function test_pref_off_should_not_create_events() {
-  let { tab, cleanup } = await setup(false);
+  let { tab, cleanup } = await setup({ enableSmartTab: false });
   let tabgroupEditor = document.getElementById("tab-group-editor");
   let tabgroupPanel = tabgroupEditor.panel;
   let nameField = tabgroupPanel.querySelector("#tab-group-name");
@@ -280,7 +304,7 @@ async function waitForUpdateComplete(element) {
 }
 
 add_task(async function test_optin_telemetry() {
-  let { tab, cleanup } = await setup(true, false);
+  let { tab, cleanup } = await setup({ enableSmartTab: true, optIn: false });
   let tabgroupEditor = document.getElementById("tab-group-editor");
   let tabgroupPanel = tabgroupEditor.panel;
 
@@ -350,7 +374,7 @@ add_task(async function test_saving_ml_suggested_empty_label_telemetry() {
 });
 
 add_task(async function test_user_not_opted_in_should_not_send_ml_events() {
-  let { tab, cleanup } = await setup(true, false);
+  let { tab, cleanup } = await setup({ enableSmartTab: true, optIn: false });
   let tabgroupEditor = document.getElementById("tab-group-editor");
   let tabgroupPanel = tabgroupEditor.panel;
   let nameField = tabgroupPanel.querySelector("#tab-group-name");
@@ -379,3 +403,168 @@ add_task(async function test_user_not_opted_in_should_not_send_ml_events() {
   );
   cleanup();
 });
+
+add_task(
+  async function test_saving_ml_zero_length_low_confidence_label_telemetry() {
+    let { tab, cleanup } = await setup({ labelReason: "LOW_CONFIDENCE" });
+    let tabgroupEditor = document.getElementById("tab-group-editor");
+    let tabgroupPanel = tabgroupEditor.panel;
+    let nameField = tabgroupPanel.querySelector("#tab-group-name");
+
+    await openCreatePanel(tabgroupPanel, tab);
+    nameField.focus();
+    nameField.value = "Random Non-ML Label"; // user label matching suggested label
+    tabgroupEditor.mlLabel = ""; // empty label
+    tabgroupPanel.querySelector("#tab-group-editor-button-create").click();
+    let panelHidden = BrowserTestUtils.waitForPopupEvent(
+      tabgroupPanel,
+      "hidden"
+    );
+    await panelHidden;
+
+    const events = Glean.tabgroup.smartTabTopic.testGetValue();
+    Assert.equal(
+      events[0].extra.label_reason,
+      "LOW_CONFIDENCE",
+      "If suggested label zero length with low confidence, proper reason should be given"
+    );
+    cleanup();
+  }
+);
+
+add_task(
+  async function test_saving_ml_zero_length_dissimilar_label_telemetry() {
+    let { tab, cleanup } = await setup({ labelReason: "EXCLUDE" });
+    let tabgroupEditor = document.getElementById("tab-group-editor");
+    let tabgroupPanel = tabgroupEditor.panel;
+    let nameField = tabgroupPanel.querySelector("#tab-group-name");
+
+    await openCreatePanel(tabgroupPanel, tab);
+    nameField.focus();
+    nameField.value = "Random Non-ML Label"; // user label matching suggested label
+    tabgroupEditor.mlLabel = ""; // empty label
+    tabgroupPanel.querySelector("#tab-group-editor-button-create").click();
+    let panelHidden = BrowserTestUtils.waitForPopupEvent(
+      tabgroupPanel,
+      "hidden"
+    );
+    await panelHidden;
+
+    const events = Glean.tabgroup.smartTabTopic.testGetValue();
+    Assert.equal(
+      events[0].extra.label_reason,
+      "EXCLUDE",
+      "If suggested label zero length with dissimilar tabs, proper reason should be given"
+    );
+    cleanup();
+  }
+);
+
+add_task(async function test_disabling_smart_tab_bool_prefs() {
+  let { tab, cleanup } = await setup();
+  let tabgroupEditor = document.getElementById("tab-group-editor");
+  let tabgroupPanel = tabgroupEditor.panel;
+  let nameField = tabgroupPanel.querySelector("#tab-group-name");
+
+  await openCreatePanel(tabgroupPanel, tab);
+  nameField.focus();
+  nameField.value = "Random Non-ML Label"; // user label matching suggested label
+  tabgroupEditor.mlLabel = ""; // empty label
+  tabgroupPanel.querySelector("#tab-group-editor-button-create").click();
+  let panelHidden = BrowserTestUtils.waitForPopupEvent(tabgroupPanel, "hidden");
+  await panelHidden;
+
+  Services.prefs.setBoolPref("browser.tabs.groups.smart.userEnabled", false);
+
+  const events = Glean.tabgroup.smartTab.testGetValue();
+  Assert.equal(events.length, 1, "Should create a prefs change event");
+  Assert.equal(
+    events[0].extra.enabled,
+    "false",
+    "if the preference is changed for any reason, we should get the correct value"
+  );
+  cleanup();
+});
+
+add_task(async function test_enabling_smart_tab_bool_prefs() {
+  let { tab, cleanup } = await setup({ userEnabled: false });
+  let tabgroupEditor = document.getElementById("tab-group-editor");
+  let tabgroupPanel = tabgroupEditor.panel;
+  let nameField = tabgroupPanel.querySelector("#tab-group-name");
+
+  await openCreatePanel(tabgroupPanel, tab);
+  nameField.focus();
+  nameField.value = "Random Non-ML Label"; // user label matching suggested label
+  tabgroupEditor.mlLabel = ""; // empty label
+  tabgroupPanel.querySelector("#tab-group-editor-button-create").click();
+  let panelHidden = BrowserTestUtils.waitForPopupEvent(tabgroupPanel, "hidden");
+  await panelHidden;
+
+  Services.prefs.setBoolPref("browser.tabs.groups.smart.userEnabled", true);
+
+  const events = Glean.tabgroup.smartTab.testGetValue();
+  Assert.equal(events.length, 1, "Should create a prefs change event");
+  Assert.equal(
+    events[0].extra.enabled,
+    "true",
+    "if the preference is changed for any reason, we should get the correct value"
+  );
+  cleanup();
+});
+
+add_task(
+  async function test_master_ml_switch_off_should_not_show_ui_and_send_events() {
+    let { tab, cleanup } = await setup({ mlSwitchEnabled: false });
+    let tabgroupEditor = document.getElementById("tab-group-editor");
+    let tabgroupPanel = tabgroupEditor.panel;
+    let nameField = tabgroupPanel.querySelector("#tab-group-name");
+
+    await openCreatePanel(tabgroupPanel, tab);
+    // below should not be visible
+    const isVisible = tabgroupPanel
+      .querySelector("#tab-group-create-suggestions-button")
+      .checkVisibility();
+    Assert.ok(!isVisible, "ML button should be hidden if master switch if off");
+
+    nameField.focus();
+    nameField.value = "Random Non-ML Label"; // user label matching suggested label
+    tabgroupEditor.mlLabel = "Random Non-ML Label"; // suggested label
+    tabgroupPanel.querySelector("#tab-group-editor-button-create").click();
+    let panelHidden = BrowserTestUtils.waitForPopupEvent(
+      tabgroupPanel,
+      "hidden"
+    );
+    tabgroupPanel.querySelector("#tab-group-editor-button-create"); // save
+    await panelHidden;
+
+    Assert.equal(
+      Glean.tabgroup.smartTabTopic.testGetValue() ?? "none",
+      "none",
+      "No event if the feature is off"
+    );
+    cleanup();
+  }
+);
+
+add_task(async function test_backend_field_sent_as_part_of_telemetry() {
+  let { tab, cleanup } = await setup();
+  let tabgroupEditor = document.getElementById("tab-group-editor");
+  let tabgroupPanel = tabgroupEditor.panel;
+  let nameField = tabgroupPanel.querySelector("#tab-group-name");
+
+  await openCreatePanel(tabgroupPanel, tab);
+  nameField.focus();
+  nameField.value = "Random Non-ML Label"; // user label matching suggested label
+  tabgroupEditor.mlLabel = ""; // empty label
+  tabgroupPanel.querySelector("#tab-group-editor-button-create").click();
+  let panelHidden = BrowserTestUtils.waitForPopupEvent(tabgroupPanel, "hidden");
+  await panelHidden;
+
+  const events = Glean.tabgroup.smartTabTopic.testGetValue();
+  Assert.equal(
+    events[0].extra.backend,
+    "onnx-native",
+    "Check that the field is present in the telemetry"
+  );
+  cleanup();
+});
