@@ -21,6 +21,7 @@ let win;
 add_setup(async () => {
   await SpecialPowers.pushPrefEnv({
     set: [
+      ["test.wait300msAfterTabSwitch", true],
       ["browser.tabs.groups.enabled", true],
       ["browser.urlbar.scotchBonnet.enableOverride", true],
     ],
@@ -41,20 +42,21 @@ add_task(async function test_tabGroupTelemetry() {
   let group1tab = BrowserTestUtils.addTab(win.gBrowser, "https://example.com");
   await BrowserTestUtils.browserLoaded(group1tab.linkedBrowser);
 
+  let tabGroupCreateByUser = BrowserTestUtils.waitForEvent(
+    win.gBrowser.tabContainer,
+    "TabGroupCreateByUser"
+  );
   let group1 = win.gBrowser.addTabGroup([group1tab], {
     isUserTriggered: true,
     telemetryUserCreateSource: "test-source",
   });
   win.gBrowser.tabGroupMenu.close();
+  await tabGroupCreateByUser;
 
   await BrowserTestUtils.waitForCondition(() => {
     tabGroupCreateTelemetry = Glean.tabgroup.createGroup.testGetValue();
-    return (
-      tabGroupCreateTelemetry?.length == 1 &&
-      Glean.tabgroup.tabCountInGroups.inside.testGetValue() !== null &&
-      Glean.tabgroup.tabsPerActiveGroup.average.testGetValue() !== null
-    );
-  }, "Wait for createGroup and at least one metric from the tabCountInGroups and tabsPerActiveGroup to be set");
+    return tabGroupCreateTelemetry?.length == 1;
+  }, "Wait for createGroup event to be recorded");
 
   Assert.deepEqual(
     tabGroupCreateTelemetry[0].extra,
@@ -67,6 +69,13 @@ add_task(async function test_tabGroupTelemetry() {
     "tabGroupCreate event extra_keys has correct values after tab group create"
   );
 
+  await BrowserTestUtils.waitForCondition(() => {
+    return (
+      Glean.tabgroup.tabCountInGroups.inside.testGetValue() == 1 &&
+      Glean.tabgroup.tabCountInGroups.outside.testGetValue() == 2
+    );
+  }, "Wait for group tab counts to settle");
+
   Assert.equal(
     Glean.tabgroup.tabCountInGroups.inside.testGetValue(),
     1,
@@ -77,6 +86,16 @@ add_task(async function test_tabGroupTelemetry() {
     2,
     "tabCountInGroups.outside has correct value"
   );
+
+  await BrowserTestUtils.waitForCondition(() => {
+    return (
+      Glean.tabgroup.tabsPerActiveGroup.median.testGetValue() == 1 &&
+      Glean.tabgroup.tabsPerActiveGroup.average.testGetValue() == 1 &&
+      Glean.tabgroup.tabsPerActiveGroup.max.testGetValue() == 1 &&
+      Glean.tabgroup.tabsPerActiveGroup.min.testGetValue() == 1
+    );
+  }, "Wait for active group tab statistics to settle");
+
   Assert.equal(
     Glean.tabgroup.tabsPerActiveGroup.median.testGetValue(),
     1,
@@ -117,10 +136,10 @@ add_task(async function test_tabGroupTelemetry() {
 
   await BrowserTestUtils.waitForCondition(() => {
     return (
-      Glean.tabgroup.tabCountInGroups.inside.testGetValue() !== null &&
-      Glean.tabgroup.tabsPerActiveGroup.average.testGetValue() !== null
+      Glean.tabgroup.tabCountInGroups.inside.testGetValue() == 4 &&
+      Glean.tabgroup.tabCountInGroups.outside.testGetValue() == 2
     );
-  }, "Wait for at least one metric from the tabCountInGroups and tabsPerActiveGroup to be set after adding a new tab group");
+  }, "Wait for group tab counts to settle");
 
   Assert.equal(
     Glean.tabgroup.tabCountInGroups.inside.testGetValue(),
@@ -132,6 +151,16 @@ add_task(async function test_tabGroupTelemetry() {
     2,
     "tabCountInGroups.outside has correct value after adding a new tab group"
   );
+
+  await BrowserTestUtils.waitForCondition(() => {
+    return (
+      Glean.tabgroup.tabsPerActiveGroup.median.testGetValue() == 2 &&
+      Glean.tabgroup.tabsPerActiveGroup.average.testGetValue() == 2 &&
+      Glean.tabgroup.tabsPerActiveGroup.max.testGetValue() == 3 &&
+      Glean.tabgroup.tabsPerActiveGroup.min.testGetValue() == 1
+    );
+  }, "Wait for active group tab statistics to settle");
+
   Assert.equal(
     Glean.tabgroup.tabsPerActiveGroup.median.testGetValue(),
     2,
@@ -165,10 +194,10 @@ add_task(async function test_tabGroupTelemetry() {
 
   await BrowserTestUtils.waitForCondition(() => {
     return (
-      Glean.tabgroup.tabCountInGroups.inside.testGetValue() !== null &&
-      Glean.tabgroup.tabsPerActiveGroup.average.testGetValue() !== null
+      Glean.tabgroup.tabCountInGroups.inside.testGetValue() == 5 &&
+      Glean.tabgroup.tabCountInGroups.outside.testGetValue() == 2
     );
-  }, "Wait for at least one metric from the tabCountInGroups and tabsPerActiveGroup to be set after modifying a tab group");
+  }, "Wait for group tab counts to settle");
 
   Assert.equal(
     Glean.tabgroup.tabCountInGroups.inside.testGetValue(),
@@ -180,6 +209,16 @@ add_task(async function test_tabGroupTelemetry() {
     2,
     "tabCountInGroups.outside has correct value after modifying a tab group"
   );
+
+  await BrowserTestUtils.waitForCondition(() => {
+    return (
+      Glean.tabgroup.tabsPerActiveGroup.median.testGetValue() == 2 &&
+      Glean.tabgroup.tabsPerActiveGroup.average.testGetValue() == 2 &&
+      Glean.tabgroup.tabsPerActiveGroup.max.testGetValue() == 4 &&
+      Glean.tabgroup.tabsPerActiveGroup.min.testGetValue() == 1
+    );
+  }, "Wait for active group tab statistics to settle");
+
   Assert.equal(
     Glean.tabgroup.tabsPerActiveGroup.median.testGetValue(),
     2,
@@ -206,8 +245,11 @@ add_task(async function test_tabGroupTelemetry() {
   group2.collapsed = true;
 
   await BrowserTestUtils.waitForCondition(() => {
-    return Glean.tabgroup.activeGroups.collapsed.testGetValue() !== null;
-  }, "Wait for the activeGroups metric to be set after collapsing a tab group");
+    return (
+      Glean.tabgroup.activeGroups.collapsed.testGetValue() == 1 &&
+      Glean.tabgroup.activeGroups.expanded.testGetValue() == 1
+    );
+  }, "Wait for the activeGroups metrics to settle");
 
   Assert.equal(
     Glean.tabgroup.activeGroups.collapsed.testGetValue(),
@@ -217,7 +259,7 @@ add_task(async function test_tabGroupTelemetry() {
   Assert.equal(
     Glean.tabgroup.activeGroups.expanded.testGetValue(),
     1,
-    "activeGroups.collapsed has correct value after collapsing a tab group"
+    "activeGroups.expanded has correct value after collapsing a tab group"
   );
 
   await resetTelemetry();
@@ -584,7 +626,7 @@ async function doReopenTests(useVerticalTabs) {
 
   info("restoring saved group via undoClosetab");
   await waitForNoActiveGroups();
-  undoCloseTab(undefined, win.__SSi);
+  SessionWindowUI.undoCloseTab(win, undefined, win.__SSi);
   await waitForReopenRecord();
   assertReopenEvent({
     id: groupId,
@@ -592,7 +634,7 @@ async function doReopenTests(useVerticalTabs) {
     layout: expectedLayout,
     type: "saved",
   });
-  await addTab("about:blank"); // removed by undoCloseTab
+  await addTabTo(win.gBrowser, "about:blank"); // removed by undoCloseTab
   await saveAndCloseGroup(win.gBrowser.getTabGroupById(groupId));
   await resetTelemetry();
 
@@ -624,9 +666,19 @@ async function doReopenTests(useVerticalTabs) {
     layout: expectedLayout,
     type: "saved",
   });
-
-  await win.gBrowser.removeTabGroup(win.gBrowser.getTabGroupById(groupId));
   await resetTelemetry();
+
+  await TabGroupTestUtils.removeTabGroup(win.gBrowser.getTabGroupById(groupId));
+  SessionStore.undoCloseTabGroup(win, groupId, win);
+  await waitForReopenRecord();
+  assertReopenEvent({
+    id: groupId,
+    source: "recent",
+    layout: expectedLayout,
+    type: "deleted",
+  });
+  await resetTelemetry();
+  await TabGroupTestUtils.removeTabGroup(win.gBrowser.getTabGroupById(groupId));
   await SpecialPowers.popPrefEnv();
 }
 
@@ -654,6 +706,11 @@ add_task(async function test_tabContextMenu_addTabsToGroup() {
   let group = await makeTabGroup();
   let groupId = group.id;
 
+  info("create and save a group");
+  let savedGroup = await makeTabGroup();
+  let savedGroupId = savedGroup.id;
+  await saveAndCloseGroup(savedGroup);
+
   info("create 8 ungrouped tabs to test with");
   let moreTabs = Array.from({ length: 8 }).map(() =>
     BrowserTestUtils.addTab(win.gBrowser, "https://example.com")
@@ -678,16 +735,72 @@ add_task(async function test_tabContextMenu_addTabsToGroup() {
   await closeContextMenu(menu);
 
   await BrowserTestUtils.waitForCondition(() => {
-    return Glean.tabgroup.addTab.testGetValue() !== null;
+    return Glean.tabgroup.addTab.testGetValue()?.length === 1;
   }, "Wait for a Glean event to be recorded");
 
-  let [addTabEvent] = Glean.tabgroup.addTab.testGetValue();
+  info("Collapse the tab group and add another tab to it");
+  group.collapsed = true;
+
+  menu = await getContextMenu(win.gBrowser.tabs.at(-1), "tabContextMenu");
+  moveTabToGroupItem = win.document.getElementById("context_moveTabToGroup");
+  tabGroupButton = moveTabToGroupItem.querySelector(
+    `[tab-group-id="${groupId}"]`
+  );
+  tabGroupButton.click();
+  await closeContextMenu(menu);
+
+  await BrowserTestUtils.waitForCondition(() => {
+    return Glean.tabgroup.addTab.testGetValue()?.length === 2;
+  }, "Wait for a Glean event to be recorded");
+
+  info("Add a tab to the saved tab group");
+  // TODO bug1983054 saved group does not appear in context menu on first open
+  menu = await getContextMenu(win.gBrowser.tabs.at(-1), "tabContextMenu");
+  await closeContextMenu(menu);
+
+  menu = await getContextMenu(win.gBrowser.tabs.at(-1), "tabContextMenu");
+  moveTabToGroupItem = win.document.getElementById(
+    "context_moveTabToSavedGroup"
+  );
+  tabGroupButton = moveTabToGroupItem.querySelector(
+    `[tab-group-id="${savedGroupId}"]`
+  );
+  tabGroupButton.click();
+  await closeContextMenu(menu);
+
+  await BrowserTestUtils.waitForCondition(() => {
+    return Glean.tabgroup.addTab.testGetValue()?.length === 3;
+  }, "Wait for a Glean event to be recorded");
+
+  let [addTabEventExpanded, addTabEventCollapsed, addTabEventSaved] =
+    Glean.tabgroup.addTab.testGetValue();
   Assert.deepEqual(
-    addTabEvent.extra,
+    addTabEventExpanded.extra,
     {
       source: "tab_menu",
       tabs: "4",
       layout: "horizontal",
+      group_type: "expanded",
+    },
+    "should have recorded the correct event metadata"
+  );
+  Assert.deepEqual(
+    addTabEventCollapsed.extra,
+    {
+      source: "tab_menu",
+      tabs: "1",
+      layout: "horizontal",
+      group_type: "collapsed",
+    },
+    "should have recorded the correct event metadata"
+  );
+  Assert.deepEqual(
+    addTabEventSaved.extra,
+    {
+      source: "tab_menu",
+      tabs: "1",
+      layout: "horizontal",
+      group_type: "saved",
     },
     "should have recorded the correct event metadata"
   );
@@ -700,113 +813,259 @@ add_task(async function test_tabContextMenu_addTabsToGroup() {
   await resetTelemetry();
 });
 
-add_task(async function test_tabInteractions() {
+add_task(async function test_groupInteractions() {
   await resetTelemetry();
   let group = await makeTabGroup();
+  const groupId = group.id;
 
-  info(
-    "Test that selecting a tab in a group records tab_interactions.activate"
+  info("test that collapsing and expanding the group gets counted");
+  Assert.ok(!group.collapsed, "new tab group should start expanded");
+  const tabGroupCollapseEvent = BrowserTestUtils.waitForEvent(
+    win,
+    "TabGroupCollapse"
   );
-  const tabSelectEvent = BrowserTestUtils.waitForEvent(win, "TabSelect");
-  win.gBrowser.selectTabAtIndex(1);
-  await tabSelectEvent;
-
-  await BrowserTestUtils.waitForCondition(() => {
-    return Glean.tabgroup.tabInteractions.activate.testGetValue() !== null;
-  }, "Wait for tab_interactions.activate to be recorded");
+  group.labelElement.click();
+  await tabGroupCollapseEvent;
   Assert.equal(
-    Glean.tabgroup.tabInteractions.activate.testGetValue(),
+    Glean.tabgroup.groupInteractions.collapse.testGetValue(),
     1,
-    "tab_interactions.activate was recorded"
+    "tab group collapse should have been recorded"
   );
-
-  info(
-    "Test that moving an existing tab into a tab group records tab_interactions.add"
+  const tabGroupExpandEvent = BrowserTestUtils.waitForEvent(
+    win,
+    "TabGroupExpand"
   );
-  let tab1 = BrowserTestUtils.addTab(win.gBrowser, "https://example.com");
-  win.gBrowser.moveTabToGroup(tab1, group, { isUserTriggered: true });
-
-  await BrowserTestUtils.waitForCondition(() => {
-    return Glean.tabgroup.tabInteractions.add.testGetValue() !== null;
-  }, "Wait for tab_interactions.add to be recorded");
+  group.labelElement.click();
+  await tabGroupExpandEvent;
   Assert.equal(
-    Glean.tabgroup.tabInteractions.add.testGetValue(),
+    Glean.tabgroup.groupInteractions.expand.testGetValue(),
     1,
-    "tab_interactions.add was recorded"
+    "tab group expand should have been recorded"
   );
 
-  info(
-    "Test that adding a new tab to a tab group records tab_interactions.new"
+  info("opening and closing tab group context menu");
+  let tabGroupContextMenu = await openTabGroupContextMenu(group);
+  await closeContextMenu(tabGroupContextMenu);
+
+  Assert.equal(
+    Glean.tabgroup.groupInteractions.rename.testGetValue(),
+    null,
+    "tab group rename count should not have changed because the name did not change"
   );
-  BrowserTestUtils.addTab(win.gBrowser, "https://example.com", {
-    tabGroup: group,
+
+  info("opening tab group context menu and inputting tab group name change");
+  tabGroupContextMenu = await openTabGroupContextMenu(group);
+  let tabGroupNameInput = win.document.getElementById("tab-group-name");
+  let inputEvent = BrowserTestUtils.waitForEvent(tabGroupNameInput, "input");
+  tabGroupNameInput.value = "test group name";
+  tabGroupNameInput.dispatchEvent(
+    new InputEvent("input", { data: "test group name" })
+  );
+  await inputEvent;
+  await closeContextMenu(tabGroupContextMenu);
+
+  await TestUtils.waitForCondition(
+    () => Glean.tabgroup.groupInteractions.rename.testGetValue() != null,
+    "waiting for `rename` metric to be set"
+  );
+  Assert.equal(
+    Glean.tabgroup.groupInteractions.rename.testGetValue(),
+    1,
+    "tab group rename count should have increased because the name changed"
+  );
+
+  Assert.equal(
+    Glean.tabgroup.groupInteractions.change_color.testGetValue(),
+    null,
+    "tab group change_color count should start unset"
+  );
+  info("opening tab group context menu and changing tab group color");
+  tabGroupContextMenu = await openTabGroupContextMenu(group);
+  win.document.getElementById("tab-group-editor-swatch-green").click();
+  await closeContextMenu(tabGroupContextMenu);
+  Assert.equal(
+    Glean.tabgroup.groupInteractions.change_color.testGetValue(),
+    1,
+    "tab group change_color count should have increased because the color changed"
+  );
+
+  Assert.equal(
+    Glean.tabgroup.groupInteractions.delete.testGetValue(),
+    null,
+    "tab group delete count should start unset"
+  );
+  info("opening tab group context menu and deleting it");
+  tabGroupContextMenu = await openTabGroupContextMenu(group);
+  let tabGroupRemoved = BrowserTestUtils.waitForEvent(group, "TabGroupRemoved");
+  win.document.getElementById("tabGroupEditor_deleteGroup").click();
+  await tabGroupRemoved;
+  Assert.equal(
+    Glean.tabgroup.groupInteractions.delete.testGetValue(),
+    1,
+    "tab group delete count should have increased because a tab group was deleted"
+  );
+
+  Assert.equal(
+    Glean.tabgroup.groupInteractions.open_recent.testGetValue(),
+    null,
+    "tab group open_recent count should start unset"
+  );
+  info(
+    "undoing last closed tab group, which should restore the just-deleted tab group"
+  );
+  SessionStore.undoCloseTabGroup(win, groupId, win);
+  group = win.gBrowser.getTabGroupById(groupId);
+  Assert.ok(group, "group should have been restored");
+  Assert.equal(
+    Glean.tabgroup.groupInteractions.open_recent.testGetValue(),
+    1,
+    "tab group open_recent count should have increased because a recently closed tab group was reopened"
+  );
+
+  Assert.equal(
+    Glean.tabgroup.groupInteractions.save.testGetValue(),
+    null,
+    "tab group save count should start unset"
+  );
+  info("opening tab group context menu and saving it");
+  tabGroupContextMenu = await openTabGroupContextMenu(group);
+  win.document.getElementById("tabGroupEditor_saveAndCloseGroup").click();
+  await TestUtils.waitForCondition(
+    () => Glean.tabgroup.groupInteractions.save.testGetValue() != null,
+    "waiting for `save` metric to be set"
+  );
+  Assert.equal(
+    Glean.tabgroup.groupInteractions.save.testGetValue(),
+    1,
+    "tab group save count should have increased because a tab group was saved"
+  );
+
+  info("reopen saved tab group virtually from tab overflow menu");
+
+  group = SessionStore.openSavedTabGroup(groupId, win, {
+    source: "tab_overflow",
   });
-
-  await BrowserTestUtils.waitForCondition(() => {
-    return Glean.tabgroup.tabInteractions.new.testGetValue() !== null;
-  }, "Wait for tab_interactions.new to be recorded");
   Assert.equal(
-    Glean.tabgroup.tabInteractions.new.testGetValue(),
+    Glean.tabgroup.groupInteractions.open_tabmenu.testGetValue(),
     1,
-    "tab_interactions.new was recorded"
+    "`open_tabmenu` metric should increment"
   );
 
-  info("Test that moving a tab within a group calls tab_interactions.reorder");
-  win.gBrowser.moveTabTo(group.tabs[0], { tabIndex: 3, isUserTriggered: true });
-  await BrowserTestUtils.waitForCondition(() => {
-    return Glean.tabgroup.tabInteractions.reorder.testGetValue() !== null;
-  }, "Wait for tab_interactions.reorder to be recorded");
   Assert.equal(
-    Glean.tabgroup.tabInteractions.reorder.testGetValue(),
-    1,
-    "tab_interactions.reorder was recorded"
+    Glean.tabgroup.groupInteractions.ungroup.testGetValue(),
+    null,
+    "tab group ungroup count should start unset"
   );
+  info("opening tab group context menu and ungrouping it");
 
-  info(
-    "Test that duplicating a tab within a group calls tab_interactions.duplicate"
-  );
-  win.gBrowser.duplicateTab(group.tabs[0], true, { index: 2 });
-  await BrowserTestUtils.waitForCondition(() => {
-    return Glean.tabgroup.tabInteractions.duplicate.testGetValue() !== null;
-  }, "Wait for tab_interactions.duplicate to be recorded");
+  tabGroupContextMenu = await openTabGroupContextMenu(group);
+
+  tabGroupRemoved = BrowserTestUtils.waitForEvent(group, "TabGroupRemoved");
+  win.document.getElementById("tabGroupEditor_ungroupTabs").click();
+  await tabGroupRemoved;
   Assert.equal(
-    Glean.tabgroup.tabInteractions.duplicate.testGetValue(),
+    Glean.tabgroup.groupInteractions.ungroup.testGetValue(),
     1,
-    "tab_interactions.duplicate was recorded"
+    "tab group ungroup count should have increased because a tab group was ungrouped"
+  );
+  const ungroupEvents = Glean.tabgroup.ungroup.testGetValue();
+  Assert.ok(ungroupEvents, "an `ungroup` event should have been recorded");
+  Assert.deepEqual(
+    ungroupEvents[0].extra,
+    { source: "tab_group" },
+    "ungroup event should have come from the tab group context menu"
   );
 
-  info(
-    "Test that closing a tab using the tab's close button calls tab_interactions.close_tabstrip"
+  await resetTelemetry();
+});
+
+add_task(async function test_cancelTabGroupCreation_ungroupTabsEvent() {
+  await resetTelemetry();
+
+  let tab = BrowserTestUtils.addTab(win.gBrowser, "https://example.com");
+
+  let tabGroupCreateByUser = BrowserTestUtils.waitForEvent(
+    win.gBrowser.tabContainer,
+    "TabGroupCreateByUser"
+  );
+  let tabGroupContextOpen = BrowserTestUtils.waitForPopupEvent(
+    win.gBrowser.tabGroupMenu,
+    "shown"
+  );
+  win.gBrowser.addTabGroup([tab], {
+    isUserTriggered: true,
+    telemetryUserCreateSource: "test-source",
+  });
+  await Promise.all([tabGroupCreateByUser, tabGroupContextOpen]);
+
+  Assert.ok(
+    win.gBrowser.tabGroupMenu.createMode,
+    "tab group context menu should be in create mode"
   );
-  group.tabs.at(-1).querySelector(".tab-close-button").click();
+
+  info("hit Escape key in order to cancel/undo tab group creation");
+  let tabGroupContextClosed = BrowserTestUtils.waitForPopupEvent(
+    win.gBrowser.tabGroupMenu,
+    "hidden"
+  );
+  EventUtils.synthesizeKey("KEY_Escape", {}, win);
+  await tabGroupContextClosed;
+
   await BrowserTestUtils.waitForCondition(() => {
-    return (
-      Glean.tabgroup.tabInteractions.close_tabstrip.testGetValue() !== null
-    );
-  }, "Wait for tab_interactions.close_tabstrip to be recorded");
+    return Glean.tabgroup.ungroup.testGetValue() != null;
+  }, "wait until an ungroup event is recorded");
+
+  let [ungroupEvent] = Glean.tabgroup.ungroup.testGetValue();
+  Assert.deepEqual(
+    ungroupEvent.extra,
+    { source: "cancel_create" },
+    "ungroup event should be from canceling group creation"
+  );
   Assert.equal(
-    Glean.tabgroup.tabInteractions.close_tabstrip.testGetValue(),
-    1,
-    "tab_interactions.close_tabstrip was recorded"
+    Glean.tabgroup.groupInteractions.ungroup.testGetValue(),
+    null,
+    "tab group interactions ungroup count should not be increased when canceling tab group creation"
   );
 
-  info(
-    "Test that closing a tab from the tab overflow menu calls tab_interactions.close_tabmenu"
+  await BrowserTestUtils.removeTab(tab);
+
+  await resetTelemetry();
+});
+
+/* Test that no "add tab to group" events are fired when moving tabs
+ * but the tab does not enter or leave a group */
+add_task(async function test_noGroupEventWhenNotMovingToGroup() {
+  await resetTelemetry();
+
+  // `tabgroup.add_tab` is disabled by default and enabled by server knobs,
+  // so this test needs to enable it manually in order to test it.
+  Services.fog.applyServerKnobsConfig(
+    JSON.stringify({
+      metrics_enabled: {
+        "tabgroup.add_tab": true,
+      },
+    })
+  );
+
+  let tab = await addTabTo(win.gBrowser, "about:blank");
+  Assert.equal(
+    Glean.tabgroup.addTab.testGetValue(),
+    null,
+    "Sanity check: no add tab to group events recorded"
   );
-  await openTabsMenu();
-  win.document
-    .querySelector(".all-tabs-item.grouped .all-tabs-close-button")
-    .click();
-  await BrowserTestUtils.waitForCondition(() => {
-    return Glean.tabgroup.tabInteractions.close_tabmenu.testGetValue() !== null;
-  }, "Wait for tab_interactions.close_tabmenu to be recorded");
+
+  win.gBrowser.moveTabTo(tab, { tabIndex: 0, isUserTriggered: true });
+
+  /* eslint-disable mozilla/no-arbitrary-setTimeout */
+  await new Promise(r => setTimeout(r, 300));
+
   Assert.equal(
-    Glean.tabgroup.tabInteractions.close_tabmenu.testGetValue(),
-    1,
-    "tab_interactions.close_tabmenu was recorded"
+    Glean.tabgroup.addTab.testGetValue(),
+    null,
+    "No add tab to group event recorded when moving tabs not within a group"
   );
-  await closeTabsMenu();
+
+  BrowserTestUtils.removeTab(tab);
 
-  await removeTabGroup(group);
   await resetTelemetry();
 });
