@@ -81,7 +81,7 @@ add_UITour_task(async function test_info_buttons_1() {
   );
   is(
     buttons.children[0].getAttribute("image"),
-    "",
+    null,
     "Text should have no image"
   );
   is(buttons.children[0].className, "", "Text should have no class");
@@ -94,7 +94,7 @@ add_UITour_task(async function test_info_buttons_1() {
   );
   is(
     buttons.children[1].getAttribute("image"),
-    "",
+    null,
     "Link should have no image"
   );
   is(buttons.children[1].className, "button-link", "Check link class");
@@ -107,7 +107,7 @@ add_UITour_task(async function test_info_buttons_1() {
   );
   is(
     buttons.children[2].getAttribute("image"),
-    "",
+    null,
     "First button should have no image"
   );
   is(buttons.children[2].className, "", "Button 1 should have no class");
@@ -173,7 +173,7 @@ add_UITour_task(async function test_info_buttons_2() {
   );
   is(
     buttons.children[1].getAttribute("image"),
-    "",
+    null,
     "Link should have no image"
   );
   ok(
@@ -188,7 +188,7 @@ add_UITour_task(async function test_info_buttons_2() {
   );
   is(
     buttons.children[2].getAttribute("image"),
-    "",
+    null,
     "First button should have no image"
   );
 
@@ -270,23 +270,16 @@ add_UITour_task(async function test_info_target_callback() {
 add_UITour_task(async function test_getConfiguration_selectedSearchEngine() {
   let engine = await Services.search.getDefault();
   let data = await getConfigurationPromise("selectedSearchEngine");
-  is(
-    data.searchEngineIdentifier,
-    engine.identifier,
-    "Correct engine identifier"
-  );
+  is(data.searchEngineIdentifier, engine.id, "Correct engine identifier");
 });
 
 add_UITour_task(async function test_setSearchTerm() {
   // Place the search bar in the navigation toolbar temporarily.
-  await SpecialPowers.pushPrefEnv({
-    set: [["browser.search.widget.inNavBar", true]],
-  });
+  let searchbar = await gCUITestUtils.addSearchBar();
 
   const TERM = "UITour Search Term";
   await gContentAPI.setSearchTerm(TERM);
 
-  let searchbar = document.getElementById("searchbar");
   // The UITour gets to the searchbar element through a promise, so the value setting
   // only happens after a tick.
   await waitForConditionPromise(
@@ -294,18 +287,15 @@ add_UITour_task(async function test_setSearchTerm() {
     "Correct term set"
   );
 
-  await SpecialPowers.popPrefEnv();
+  gCUITestUtils.removeSearchBar();
 });
 
 add_UITour_task(async function test_clearSearchTerm() {
   // Place the search bar in the navigation toolbar temporarily.
-  await SpecialPowers.pushPrefEnv({
-    set: [["browser.search.widget.inNavBar", true]],
-  });
+  let searchbar = await gCUITestUtils.addSearchBar();
 
   await gContentAPI.setSearchTerm("");
 
-  let searchbar = document.getElementById("searchbar");
   // The UITour gets to the searchbar element through a promise, so the value setting
   // only happens after a tick.
   await waitForConditionPromise(
@@ -313,5 +303,5 @@ add_UITour_task(async function test_clearSearchTerm() {
     "Search term cleared"
   );
 
-  await SpecialPowers.popPrefEnv();
+  gCUITestUtils.removeSearchBar();
 });
