@@ -5,11 +5,10 @@
 
 var gTestTab;
 var gContentAPI;
-var gContentWindow;
 
 add_task(setup_UITourTest);
 
-add_task(async function setup() {
+add_setup(async function () {
   await SpecialPowers.pushPrefEnv({
     set: [
       ["browser.contentblocking.database.enabled", false],
@@ -33,7 +32,7 @@ add_UITour_task(async function test_openProtectionReport() {
   await aboutProtectionsLoaded;
   // When the graph is built it means the messaging has finished,
   // we can close the tab.
-  await SpecialPowers.spawn(gBrowser.selectedBrowser, [], async function() {
+  await SpecialPowers.spawn(gBrowser.selectedBrowser, [], async function () {
     await ContentTaskUtils.waitForCondition(() => {
       let bars = content.document.querySelectorAll(".graph-bar");
       return bars.length;
